/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleAccessContextManagerGcpUserAccessBindingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Access level that a user must have to be granted access. Only one access level is supported, not multiple. This repeated field must have exactly one element. Example: "accessPolicies/9522/accessLevels/device_trusted"
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#access_levels GoogleAccessContextManagerGcpUserAccessBinding#access_levels}
    */
    readonly accessLevels?: string[];
    /**
    * Required. Immutable. Google Group id whose members are subject to this binding's restrictions. See "id" in the G Suite Directory API's Groups resource. If a group's email address/alias is changed, this resource will continue to point at the changed group. This field does not accept group email addresses or aliases. Example: "01d520gv4vjcrht"
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#group_key GoogleAccessContextManagerGcpUserAccessBinding#group_key}
    */
    readonly groupKey: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#id GoogleAccessContextManagerGcpUserAccessBinding#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Required. ID of the parent organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#organization_id GoogleAccessContextManagerGcpUserAccessBinding#organization_id}
    */
    readonly organizationId: string;
    /**
    * session_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#session_settings GoogleAccessContextManagerGcpUserAccessBinding#session_settings}
    */
    readonly sessionSettings?: GoogleAccessContextManagerGcpUserAccessBindingSessionSettings;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#timeouts GoogleAccessContextManagerGcpUserAccessBinding#timeouts}
    */
    readonly timeouts?: GoogleAccessContextManagerGcpUserAccessBindingTimeouts;
}
export interface GoogleAccessContextManagerGcpUserAccessBindingSessionSettings {
    /**
    * Optional. How long a user is allowed to take between actions before a new access token must be issued. Only set for Google Cloud apps.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#max_inactivity GoogleAccessContextManagerGcpUserAccessBinding#max_inactivity}
    */
    readonly maxInactivity?: string;
    /**
    * Optional. The session length. Setting this field to zero is equal to disabling session. Also can set infinite session by flipping the enabled bit to false below. If useOidcMaxAge is true, for OIDC apps, the session length will be the minimum of this field and OIDC max_age param.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#session_length GoogleAccessContextManagerGcpUserAccessBinding#session_length}
    */
    readonly sessionLength?: string;
    /**
    * Optional. This field enables or disables Google Cloud session length. When false, all fields set above will be disregarded and the session length is basically infinite.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#session_length_enabled GoogleAccessContextManagerGcpUserAccessBinding#session_length_enabled}
    */
    readonly sessionLengthEnabled?: boolean | cdktf.IResolvable;
    /**
    * Optional. The session challenges proposed to users when the Google Cloud session length is up. Possible values: ["LOGIN", "SECURITY_KEY", "PASSWORD"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#session_reauth_method GoogleAccessContextManagerGcpUserAccessBinding#session_reauth_method}
    */
    readonly sessionReauthMethod?: string;
    /**
    * Optional. Only useful for OIDC apps. When false, the OIDC max_age param, if passed in the authentication request will be ignored. When true, the re-auth period will be the minimum of the sessionLength field and the max_age OIDC param.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#use_oidc_max_age GoogleAccessContextManagerGcpUserAccessBinding#use_oidc_max_age}
    */
    readonly useOidcMaxAge?: boolean | cdktf.IResolvable;
}
export declare function googleAccessContextManagerGcpUserAccessBindingSessionSettingsToTerraform(struct?: GoogleAccessContextManagerGcpUserAccessBindingSessionSettingsOutputReference | GoogleAccessContextManagerGcpUserAccessBindingSessionSettings): any;
export declare function googleAccessContextManagerGcpUserAccessBindingSessionSettingsToHclTerraform(struct?: GoogleAccessContextManagerGcpUserAccessBindingSessionSettingsOutputReference | GoogleAccessContextManagerGcpUserAccessBindingSessionSettings): any;
export declare class GoogleAccessContextManagerGcpUserAccessBindingSessionSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleAccessContextManagerGcpUserAccessBindingSessionSettings | undefined;
    set internalValue(value: GoogleAccessContextManagerGcpUserAccessBindingSessionSettings | undefined);
    private _maxInactivity?;
    get maxInactivity(): string;
    set maxInactivity(value: string);
    resetMaxInactivity(): void;
    get maxInactivityInput(): string | undefined;
    private _sessionLength?;
    get sessionLength(): string;
    set sessionLength(value: string);
    resetSessionLength(): void;
    get sessionLengthInput(): string | undefined;
    private _sessionLengthEnabled?;
    get sessionLengthEnabled(): boolean | cdktf.IResolvable;
    set sessionLengthEnabled(value: boolean | cdktf.IResolvable);
    resetSessionLengthEnabled(): void;
    get sessionLengthEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _sessionReauthMethod?;
    get sessionReauthMethod(): string;
    set sessionReauthMethod(value: string);
    resetSessionReauthMethod(): void;
    get sessionReauthMethodInput(): string | undefined;
    private _useOidcMaxAge?;
    get useOidcMaxAge(): boolean | cdktf.IResolvable;
    set useOidcMaxAge(value: boolean | cdktf.IResolvable);
    resetUseOidcMaxAge(): void;
    get useOidcMaxAgeInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleAccessContextManagerGcpUserAccessBindingTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#create GoogleAccessContextManagerGcpUserAccessBinding#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#delete GoogleAccessContextManagerGcpUserAccessBinding#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#update GoogleAccessContextManagerGcpUserAccessBinding#update}
    */
    readonly update?: string;
}
export declare function googleAccessContextManagerGcpUserAccessBindingTimeoutsToTerraform(struct?: GoogleAccessContextManagerGcpUserAccessBindingTimeouts | cdktf.IResolvable): any;
export declare function googleAccessContextManagerGcpUserAccessBindingTimeoutsToHclTerraform(struct?: GoogleAccessContextManagerGcpUserAccessBindingTimeouts | cdktf.IResolvable): any;
export declare class GoogleAccessContextManagerGcpUserAccessBindingTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleAccessContextManagerGcpUserAccessBindingTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleAccessContextManagerGcpUserAccessBindingTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding google_access_context_manager_gcp_user_access_binding}
*/
export declare class GoogleAccessContextManagerGcpUserAccessBinding extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_access_context_manager_gcp_user_access_binding";
    /**
    * Generates CDKTF code for importing a GoogleAccessContextManagerGcpUserAccessBinding resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleAccessContextManagerGcpUserAccessBinding to import
    * @param importFromId The id of the existing GoogleAccessContextManagerGcpUserAccessBinding that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleAccessContextManagerGcpUserAccessBinding to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_access_context_manager_gcp_user_access_binding google_access_context_manager_gcp_user_access_binding} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleAccessContextManagerGcpUserAccessBindingConfig
    */
    constructor(scope: Construct, id: string, config: GoogleAccessContextManagerGcpUserAccessBindingConfig);
    private _accessLevels?;
    get accessLevels(): string[];
    set accessLevels(value: string[]);
    resetAccessLevels(): void;
    get accessLevelsInput(): string[] | undefined;
    private _groupKey?;
    get groupKey(): string;
    set groupKey(value: string);
    get groupKeyInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _organizationId?;
    get organizationId(): string;
    set organizationId(value: string);
    get organizationIdInput(): string | undefined;
    private _sessionSettings;
    get sessionSettings(): GoogleAccessContextManagerGcpUserAccessBindingSessionSettingsOutputReference;
    putSessionSettings(value: GoogleAccessContextManagerGcpUserAccessBindingSessionSettings): void;
    resetSessionSettings(): void;
    get sessionSettingsInput(): GoogleAccessContextManagerGcpUserAccessBindingSessionSettings | undefined;
    private _timeouts;
    get timeouts(): GoogleAccessContextManagerGcpUserAccessBindingTimeoutsOutputReference;
    putTimeouts(value: GoogleAccessContextManagerGcpUserAccessBindingTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleAccessContextManagerGcpUserAccessBindingTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
