/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleBackupDrBackupPlanAssociationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The BP with which resource needs to be created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#backup_plan GoogleBackupDrBackupPlanAssociation#backup_plan}
    */
    readonly backupPlan: string;
    /**
    * The id of backupplan association
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#backup_plan_association_id GoogleBackupDrBackupPlanAssociation#backup_plan_association_id}
    */
    readonly backupPlanAssociationId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#id GoogleBackupDrBackupPlanAssociation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location for the backupplan association
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#location GoogleBackupDrBackupPlanAssociation#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#project GoogleBackupDrBackupPlanAssociation#project}
    */
    readonly project?: string;
    /**
    * The resource for which BPA needs to be created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#resource GoogleBackupDrBackupPlanAssociation#resource}
    */
    readonly resource: string;
    /**
    * The resource type of workload on which backupplan is applied
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#resource_type GoogleBackupDrBackupPlanAssociation#resource_type}
    */
    readonly resourceType: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#timeouts GoogleBackupDrBackupPlanAssociation#timeouts}
    */
    readonly timeouts?: GoogleBackupDrBackupPlanAssociationTimeouts;
}
export interface GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupError {
}
export declare function googleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupErrorToTerraform(struct?: GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupError): any;
export declare function googleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupErrorToHclTerraform(struct?: GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupError): any;
export declare class GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupErrorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupError | undefined;
    set internalValue(value: GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupError | undefined);
    get code(): number;
    get message(): string;
}
export declare class GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupErrorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupErrorOutputReference;
}
export interface GoogleBackupDrBackupPlanAssociationRulesConfigInfo {
}
export declare function googleBackupDrBackupPlanAssociationRulesConfigInfoToTerraform(struct?: GoogleBackupDrBackupPlanAssociationRulesConfigInfo): any;
export declare function googleBackupDrBackupPlanAssociationRulesConfigInfoToHclTerraform(struct?: GoogleBackupDrBackupPlanAssociationRulesConfigInfo): any;
export declare class GoogleBackupDrBackupPlanAssociationRulesConfigInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBackupDrBackupPlanAssociationRulesConfigInfo | undefined;
    set internalValue(value: GoogleBackupDrBackupPlanAssociationRulesConfigInfo | undefined);
    private _lastBackupError;
    get lastBackupError(): GoogleBackupDrBackupPlanAssociationRulesConfigInfoLastBackupErrorList;
    get lastBackupState(): string;
    get ruleId(): string;
}
export declare class GoogleBackupDrBackupPlanAssociationRulesConfigInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBackupDrBackupPlanAssociationRulesConfigInfoOutputReference;
}
export interface GoogleBackupDrBackupPlanAssociationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#create GoogleBackupDrBackupPlanAssociation#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#delete GoogleBackupDrBackupPlanAssociation#delete}
    */
    readonly delete?: string;
}
export declare function googleBackupDrBackupPlanAssociationTimeoutsToTerraform(struct?: GoogleBackupDrBackupPlanAssociationTimeouts | cdktf.IResolvable): any;
export declare function googleBackupDrBackupPlanAssociationTimeoutsToHclTerraform(struct?: GoogleBackupDrBackupPlanAssociationTimeouts | cdktf.IResolvable): any;
export declare class GoogleBackupDrBackupPlanAssociationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBackupDrBackupPlanAssociationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBackupDrBackupPlanAssociationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association google_backup_dr_backup_plan_association}
*/
export declare class GoogleBackupDrBackupPlanAssociation extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_backup_dr_backup_plan_association";
    /**
    * Generates CDKTF code for importing a GoogleBackupDrBackupPlanAssociation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleBackupDrBackupPlanAssociation to import
    * @param importFromId The id of the existing GoogleBackupDrBackupPlanAssociation that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleBackupDrBackupPlanAssociation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_backup_dr_backup_plan_association google_backup_dr_backup_plan_association} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleBackupDrBackupPlanAssociationConfig
    */
    constructor(scope: Construct, id: string, config: GoogleBackupDrBackupPlanAssociationConfig);
    private _backupPlan?;
    get backupPlan(): string;
    set backupPlan(value: string);
    get backupPlanInput(): string | undefined;
    private _backupPlanAssociationId?;
    get backupPlanAssociationId(): string;
    set backupPlanAssociationId(value: string);
    get backupPlanAssociationIdInput(): string | undefined;
    get createTime(): string;
    get dataSource(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastSuccessfulBackupConsistencyTime(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _resource?;
    get resource(): string;
    set resource(value: string);
    get resourceInput(): string | undefined;
    private _resourceType?;
    get resourceType(): string;
    set resourceType(value: string);
    get resourceTypeInput(): string | undefined;
    private _rulesConfigInfo;
    get rulesConfigInfo(): GoogleBackupDrBackupPlanAssociationRulesConfigInfoList;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleBackupDrBackupPlanAssociationTimeoutsOutputReference;
    putTimeouts(value: GoogleBackupDrBackupPlanAssociationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleBackupDrBackupPlanAssociationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
