/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleChronicleRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Policy to determine if the rule should be deleted forcefully.
    * If deletion_policy = "FORCE", any retrohunts and any detections associated with the rule
    * will also be deleted. If deletion_policy = "DEFAULT", the call will only succeed if the
    * rule has no associated retrohunts, including completed retrohunts, and no
    * associated detections. Regardless of this field's value, the rule
    * deployment associated with this rule will also be deleted.
    * Possible values: DEFAULT, FORCE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#deletion_policy GoogleChronicleRule#deletion_policy}
    */
    readonly deletionPolicy?: string;
    /**
    * The etag for this rule.
    * If this is provided on update, the request will succeed if and only if it
    * matches the server-computed value, and will fail with an ABORTED error
    * otherwise.
    * Populated in BASIC view and FULL view.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#etag GoogleChronicleRule#etag}
    */
    readonly etag?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#id GoogleChronicleRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier for the Chronicle instance, which is the same as the customer ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#instance GoogleChronicleRule#instance}
    */
    readonly instance: string;
    /**
    * The location of the resource. This is the geographical region where the Chronicle instance resides, such as "us" or "europe-west2".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#location GoogleChronicleRule#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#project GoogleChronicleRule#project}
    */
    readonly project?: string;
    /**
    * Rule Id is the ID of the Rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#rule_id GoogleChronicleRule#rule_id}
    */
    readonly ruleId?: string;
    /**
    * Resource name of the DataAccessScope bound to this rule.
    * Populated in BASIC view and FULL view.
    * If reference lists are used in the rule, validations will be performed
    * against this scope to ensure that the reference lists are compatible with
    * both the user's and the rule's scopes.
    * The scope should be in the format:
    * "projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope}".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#scope GoogleChronicleRule#scope}
    */
    readonly scope?: string;
    /**
    * The YARA-L content of the rule.
    * Populated in FULL view.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#text GoogleChronicleRule#text}
    */
    readonly text?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#timeouts GoogleChronicleRule#timeouts}
    */
    readonly timeouts?: GoogleChronicleRuleTimeouts;
}
export interface GoogleChronicleRuleCompilationDiagnosticsPosition {
}
export declare function googleChronicleRuleCompilationDiagnosticsPositionToTerraform(struct?: GoogleChronicleRuleCompilationDiagnosticsPosition): any;
export declare function googleChronicleRuleCompilationDiagnosticsPositionToHclTerraform(struct?: GoogleChronicleRuleCompilationDiagnosticsPosition): any;
export declare class GoogleChronicleRuleCompilationDiagnosticsPositionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleRuleCompilationDiagnosticsPosition | undefined;
    set internalValue(value: GoogleChronicleRuleCompilationDiagnosticsPosition | undefined);
    get endColumn(): number;
    get endLine(): number;
    get startColumn(): number;
    get startLine(): number;
}
export declare class GoogleChronicleRuleCompilationDiagnosticsPositionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleRuleCompilationDiagnosticsPositionOutputReference;
}
export interface GoogleChronicleRuleCompilationDiagnostics {
}
export declare function googleChronicleRuleCompilationDiagnosticsToTerraform(struct?: GoogleChronicleRuleCompilationDiagnostics): any;
export declare function googleChronicleRuleCompilationDiagnosticsToHclTerraform(struct?: GoogleChronicleRuleCompilationDiagnostics): any;
export declare class GoogleChronicleRuleCompilationDiagnosticsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleRuleCompilationDiagnostics | undefined;
    set internalValue(value: GoogleChronicleRuleCompilationDiagnostics | undefined);
    get message(): string;
    private _position;
    get position(): GoogleChronicleRuleCompilationDiagnosticsPositionList;
    get severity(): string;
    get uri(): string;
}
export declare class GoogleChronicleRuleCompilationDiagnosticsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleRuleCompilationDiagnosticsOutputReference;
}
export interface GoogleChronicleRuleSeverity {
}
export declare function googleChronicleRuleSeverityToTerraform(struct?: GoogleChronicleRuleSeverity): any;
export declare function googleChronicleRuleSeverityToHclTerraform(struct?: GoogleChronicleRuleSeverity): any;
export declare class GoogleChronicleRuleSeverityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleRuleSeverity | undefined;
    set internalValue(value: GoogleChronicleRuleSeverity | undefined);
    get displayName(): string;
}
export declare class GoogleChronicleRuleSeverityList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleRuleSeverityOutputReference;
}
export interface GoogleChronicleRuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#create GoogleChronicleRule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#delete GoogleChronicleRule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#update GoogleChronicleRule#update}
    */
    readonly update?: string;
}
export declare function googleChronicleRuleTimeoutsToTerraform(struct?: GoogleChronicleRuleTimeouts | cdktf.IResolvable): any;
export declare function googleChronicleRuleTimeoutsToHclTerraform(struct?: GoogleChronicleRuleTimeouts | cdktf.IResolvable): any;
export declare class GoogleChronicleRuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleRuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleChronicleRuleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule google_chronicle_rule}
*/
export declare class GoogleChronicleRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_chronicle_rule";
    /**
    * Generates CDKTF code for importing a GoogleChronicleRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleChronicleRule to import
    * @param importFromId The id of the existing GoogleChronicleRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleChronicleRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_rule google_chronicle_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleChronicleRuleConfig
    */
    constructor(scope: Construct, id: string, config: GoogleChronicleRuleConfig);
    get allowedRunFrequencies(): string[];
    get author(): string;
    private _compilationDiagnostics;
    get compilationDiagnostics(): GoogleChronicleRuleCompilationDiagnosticsList;
    get compilationState(): string;
    get createTime(): string;
    get dataTables(): string[];
    private _deletionPolicy?;
    get deletionPolicy(): string;
    set deletionPolicy(value: string);
    resetDeletionPolicy(): void;
    get deletionPolicyInput(): string | undefined;
    get displayName(): string;
    private _etag?;
    get etag(): string;
    set etag(value: string);
    resetEtag(): void;
    get etagInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _metadata;
    get metadata(): cdktf.StringMap;
    get name(): string;
    get nearRealTimeLiveRuleEligible(): cdktf.IResolvable;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get referenceLists(): string[];
    get revisionCreateTime(): string;
    get revisionId(): string;
    private _ruleId?;
    get ruleId(): string;
    set ruleId(value: string);
    resetRuleId(): void;
    get ruleIdInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _severity;
    get severity(): GoogleChronicleRuleSeverityList;
    private _text?;
    get text(): string;
    set text(value: string);
    resetText(): void;
    get textInput(): string | undefined;
    get type(): string;
    private _timeouts;
    get timeouts(): GoogleChronicleRuleTimeoutsOutputReference;
    putTimeouts(value: GoogleChronicleRuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleChronicleRuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
