/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleChronicleWatchlistConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Description of the watchlist.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#description GoogleChronicleWatchlist#description}
    */
    readonly description?: string;
    /**
    * Required. Display name of the watchlist.
    * Note that it must be at least one character and less than 63 characters
    * (https://google.aip.dev/148).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#display_name GoogleChronicleWatchlist#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#id GoogleChronicleWatchlist#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The unique identifier for the Chronicle instance, which is the same as the customer ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#instance GoogleChronicleWatchlist#instance}
    */
    readonly instance: string;
    /**
    * The location of the resource. This is the geographical region where the Chronicle instance resides, such as "us" or "europe-west2".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#location GoogleChronicleWatchlist#location}
    */
    readonly location: string;
    /**
    * Optional. Weight applied to the risk score for entities
    * in this watchlist.
    * The default is 1.0 if it is not specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#multiplying_factor GoogleChronicleWatchlist#multiplying_factor}
    */
    readonly multiplyingFactor?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#project GoogleChronicleWatchlist#project}
    */
    readonly project?: string;
    /**
    * Optional. The ID to use for the watchlist,
    * which will become the final component of the watchlist's resource name.
    * This value should be 4-63 characters, and valid characters
    * are /a-z-/.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#watchlist_id GoogleChronicleWatchlist#watchlist_id}
    */
    readonly watchlistId?: string;
    /**
    * entity_population_mechanism block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#entity_population_mechanism GoogleChronicleWatchlist#entity_population_mechanism}
    */
    readonly entityPopulationMechanism: GoogleChronicleWatchlistEntityPopulationMechanism;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#timeouts GoogleChronicleWatchlist#timeouts}
    */
    readonly timeouts?: GoogleChronicleWatchlistTimeouts;
    /**
    * watchlist_user_preferences block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#watchlist_user_preferences GoogleChronicleWatchlist#watchlist_user_preferences}
    */
    readonly watchlistUserPreferences?: GoogleChronicleWatchlistWatchlistUserPreferences;
}
export interface GoogleChronicleWatchlistEntityCount {
}
export declare function googleChronicleWatchlistEntityCountToTerraform(struct?: GoogleChronicleWatchlistEntityCount): any;
export declare function googleChronicleWatchlistEntityCountToHclTerraform(struct?: GoogleChronicleWatchlistEntityCount): any;
export declare class GoogleChronicleWatchlistEntityCountOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleChronicleWatchlistEntityCount | undefined;
    set internalValue(value: GoogleChronicleWatchlistEntityCount | undefined);
    get asset(): number;
    get user(): number;
}
export declare class GoogleChronicleWatchlistEntityCountList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleChronicleWatchlistEntityCountOutputReference;
}
export interface GoogleChronicleWatchlistEntityPopulationMechanismManual {
}
export declare function googleChronicleWatchlistEntityPopulationMechanismManualToTerraform(struct?: GoogleChronicleWatchlistEntityPopulationMechanismManualOutputReference | GoogleChronicleWatchlistEntityPopulationMechanismManual): any;
export declare function googleChronicleWatchlistEntityPopulationMechanismManualToHclTerraform(struct?: GoogleChronicleWatchlistEntityPopulationMechanismManualOutputReference | GoogleChronicleWatchlistEntityPopulationMechanismManual): any;
export declare class GoogleChronicleWatchlistEntityPopulationMechanismManualOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleWatchlistEntityPopulationMechanismManual | undefined;
    set internalValue(value: GoogleChronicleWatchlistEntityPopulationMechanismManual | undefined);
}
export interface GoogleChronicleWatchlistEntityPopulationMechanism {
    /**
    * manual block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#manual GoogleChronicleWatchlist#manual}
    */
    readonly manual?: GoogleChronicleWatchlistEntityPopulationMechanismManual;
}
export declare function googleChronicleWatchlistEntityPopulationMechanismToTerraform(struct?: GoogleChronicleWatchlistEntityPopulationMechanismOutputReference | GoogleChronicleWatchlistEntityPopulationMechanism): any;
export declare function googleChronicleWatchlistEntityPopulationMechanismToHclTerraform(struct?: GoogleChronicleWatchlistEntityPopulationMechanismOutputReference | GoogleChronicleWatchlistEntityPopulationMechanism): any;
export declare class GoogleChronicleWatchlistEntityPopulationMechanismOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleWatchlistEntityPopulationMechanism | undefined;
    set internalValue(value: GoogleChronicleWatchlistEntityPopulationMechanism | undefined);
    private _manual;
    get manual(): GoogleChronicleWatchlistEntityPopulationMechanismManualOutputReference;
    putManual(value: GoogleChronicleWatchlistEntityPopulationMechanismManual): void;
    resetManual(): void;
    get manualInput(): GoogleChronicleWatchlistEntityPopulationMechanismManual | undefined;
}
export interface GoogleChronicleWatchlistTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#create GoogleChronicleWatchlist#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#delete GoogleChronicleWatchlist#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#update GoogleChronicleWatchlist#update}
    */
    readonly update?: string;
}
export declare function googleChronicleWatchlistTimeoutsToTerraform(struct?: GoogleChronicleWatchlistTimeouts | cdktf.IResolvable): any;
export declare function googleChronicleWatchlistTimeoutsToHclTerraform(struct?: GoogleChronicleWatchlistTimeouts | cdktf.IResolvable): any;
export declare class GoogleChronicleWatchlistTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleWatchlistTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleChronicleWatchlistTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleChronicleWatchlistWatchlistUserPreferences {
    /**
    * Optional. Whether the watchlist is pinned on the dashboard.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#pinned GoogleChronicleWatchlist#pinned}
    */
    readonly pinned?: boolean | cdktf.IResolvable;
}
export declare function googleChronicleWatchlistWatchlistUserPreferencesToTerraform(struct?: GoogleChronicleWatchlistWatchlistUserPreferencesOutputReference | GoogleChronicleWatchlistWatchlistUserPreferences): any;
export declare function googleChronicleWatchlistWatchlistUserPreferencesToHclTerraform(struct?: GoogleChronicleWatchlistWatchlistUserPreferencesOutputReference | GoogleChronicleWatchlistWatchlistUserPreferences): any;
export declare class GoogleChronicleWatchlistWatchlistUserPreferencesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleChronicleWatchlistWatchlistUserPreferences | undefined;
    set internalValue(value: GoogleChronicleWatchlistWatchlistUserPreferences | undefined);
    private _pinned?;
    get pinned(): boolean | cdktf.IResolvable;
    set pinned(value: boolean | cdktf.IResolvable);
    resetPinned(): void;
    get pinnedInput(): boolean | cdktf.IResolvable | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist google_chronicle_watchlist}
*/
export declare class GoogleChronicleWatchlist extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_chronicle_watchlist";
    /**
    * Generates CDKTF code for importing a GoogleChronicleWatchlist resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleChronicleWatchlist to import
    * @param importFromId The id of the existing GoogleChronicleWatchlist that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleChronicleWatchlist to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_chronicle_watchlist google_chronicle_watchlist} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleChronicleWatchlistConfig
    */
    constructor(scope: Construct, id: string, config: GoogleChronicleWatchlistConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _entityCount;
    get entityCount(): GoogleChronicleWatchlistEntityCountList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _multiplyingFactor?;
    get multiplyingFactor(): number;
    set multiplyingFactor(value: number);
    resetMultiplyingFactor(): void;
    get multiplyingFactorInput(): number | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get updateTime(): string;
    private _watchlistId?;
    get watchlistId(): string;
    set watchlistId(value: string);
    resetWatchlistId(): void;
    get watchlistIdInput(): string | undefined;
    private _entityPopulationMechanism;
    get entityPopulationMechanism(): GoogleChronicleWatchlistEntityPopulationMechanismOutputReference;
    putEntityPopulationMechanism(value: GoogleChronicleWatchlistEntityPopulationMechanism): void;
    get entityPopulationMechanismInput(): GoogleChronicleWatchlistEntityPopulationMechanism | undefined;
    private _timeouts;
    get timeouts(): GoogleChronicleWatchlistTimeoutsOutputReference;
    putTimeouts(value: GoogleChronicleWatchlistTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleChronicleWatchlistTimeouts | undefined;
    private _watchlistUserPreferences;
    get watchlistUserPreferences(): GoogleChronicleWatchlistWatchlistUserPreferencesOutputReference;
    putWatchlistUserPreferences(value: GoogleChronicleWatchlistWatchlistUserPreferences): void;
    resetWatchlistUserPreferences(): void;
    get watchlistUserPreferencesInput(): GoogleChronicleWatchlistWatchlistUserPreferences | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
