/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleColabRuntimeTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
    * The description of the Runtime Template.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#description GoogleColabRuntimeTemplate#description}
    */
    readonly description?: string;
    /**
    * Required. The display name of the Runtime Template.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#display_name GoogleColabRuntimeTemplate#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#id GoogleColabRuntimeTemplate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels to identify and group the runtime template.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#labels GoogleColabRuntimeTemplate#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location for the resource: https://cloud.google.com/colab/docs/locations
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#location GoogleColabRuntimeTemplate#location}
    */
    readonly location: string;
    /**
    * The resource name of the Runtime Template
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#name GoogleColabRuntimeTemplate#name}
    */
    readonly name?: string;
    /**
    * Applies the given Compute Engine tags to the runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#network_tags GoogleColabRuntimeTemplate#network_tags}
    */
    readonly networkTags?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#project GoogleColabRuntimeTemplate#project}
    */
    readonly project?: string;
    /**
    * data_persistent_disk_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#data_persistent_disk_spec GoogleColabRuntimeTemplate#data_persistent_disk_spec}
    */
    readonly dataPersistentDiskSpec?: GoogleColabRuntimeTemplateDataPersistentDiskSpec;
    /**
    * encryption_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#encryption_spec GoogleColabRuntimeTemplate#encryption_spec}
    */
    readonly encryptionSpec?: GoogleColabRuntimeTemplateEncryptionSpec;
    /**
    * euc_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#euc_config GoogleColabRuntimeTemplate#euc_config}
    */
    readonly eucConfig?: GoogleColabRuntimeTemplateEucConfig;
    /**
    * idle_shutdown_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#idle_shutdown_config GoogleColabRuntimeTemplate#idle_shutdown_config}
    */
    readonly idleShutdownConfig?: GoogleColabRuntimeTemplateIdleShutdownConfig;
    /**
    * machine_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#machine_spec GoogleColabRuntimeTemplate#machine_spec}
    */
    readonly machineSpec?: GoogleColabRuntimeTemplateMachineSpec;
    /**
    * network_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#network_spec GoogleColabRuntimeTemplate#network_spec}
    */
    readonly networkSpec?: GoogleColabRuntimeTemplateNetworkSpec;
    /**
    * shielded_vm_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#shielded_vm_config GoogleColabRuntimeTemplate#shielded_vm_config}
    */
    readonly shieldedVmConfig?: GoogleColabRuntimeTemplateShieldedVmConfig;
    /**
    * software_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#software_config GoogleColabRuntimeTemplate#software_config}
    */
    readonly softwareConfig?: GoogleColabRuntimeTemplateSoftwareConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#timeouts GoogleColabRuntimeTemplate#timeouts}
    */
    readonly timeouts?: GoogleColabRuntimeTemplateTimeouts;
}
export interface GoogleColabRuntimeTemplateDataPersistentDiskSpec {
    /**
    * The disk size of the runtime in GB. If specified, the diskType must also be specified. The minimum size is 10GB and the maximum is 65536GB.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#disk_size_gb GoogleColabRuntimeTemplate#disk_size_gb}
    */
    readonly diskSizeGb?: string;
    /**
    * The type of the persistent disk.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#disk_type GoogleColabRuntimeTemplate#disk_type}
    */
    readonly diskType?: string;
}
export declare function googleColabRuntimeTemplateDataPersistentDiskSpecToTerraform(struct?: GoogleColabRuntimeTemplateDataPersistentDiskSpecOutputReference | GoogleColabRuntimeTemplateDataPersistentDiskSpec): any;
export declare function googleColabRuntimeTemplateDataPersistentDiskSpecToHclTerraform(struct?: GoogleColabRuntimeTemplateDataPersistentDiskSpecOutputReference | GoogleColabRuntimeTemplateDataPersistentDiskSpec): any;
export declare class GoogleColabRuntimeTemplateDataPersistentDiskSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateDataPersistentDiskSpec | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateDataPersistentDiskSpec | undefined);
    private _diskSizeGb?;
    get diskSizeGb(): string;
    set diskSizeGb(value: string);
    resetDiskSizeGb(): void;
    get diskSizeGbInput(): string | undefined;
    private _diskType?;
    get diskType(): string;
    set diskType(value: string);
    resetDiskType(): void;
    get diskTypeInput(): string | undefined;
}
export interface GoogleColabRuntimeTemplateEncryptionSpec {
    /**
    * The Cloud KMS encryption key (customer-managed encryption key) used to protect the runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#kms_key_name GoogleColabRuntimeTemplate#kms_key_name}
    */
    readonly kmsKeyName?: string;
}
export declare function googleColabRuntimeTemplateEncryptionSpecToTerraform(struct?: GoogleColabRuntimeTemplateEncryptionSpecOutputReference | GoogleColabRuntimeTemplateEncryptionSpec): any;
export declare function googleColabRuntimeTemplateEncryptionSpecToHclTerraform(struct?: GoogleColabRuntimeTemplateEncryptionSpecOutputReference | GoogleColabRuntimeTemplateEncryptionSpec): any;
export declare class GoogleColabRuntimeTemplateEncryptionSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateEncryptionSpec | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateEncryptionSpec | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    resetKmsKeyName(): void;
    get kmsKeyNameInput(): string | undefined;
}
export interface GoogleColabRuntimeTemplateEucConfig {
    /**
    * Disable end user credential access for the runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#euc_disabled GoogleColabRuntimeTemplate#euc_disabled}
    */
    readonly eucDisabled?: boolean | cdktf.IResolvable;
}
export declare function googleColabRuntimeTemplateEucConfigToTerraform(struct?: GoogleColabRuntimeTemplateEucConfigOutputReference | GoogleColabRuntimeTemplateEucConfig): any;
export declare function googleColabRuntimeTemplateEucConfigToHclTerraform(struct?: GoogleColabRuntimeTemplateEucConfigOutputReference | GoogleColabRuntimeTemplateEucConfig): any;
export declare class GoogleColabRuntimeTemplateEucConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateEucConfig | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateEucConfig | undefined);
    private _eucDisabled?;
    get eucDisabled(): boolean | cdktf.IResolvable;
    set eucDisabled(value: boolean | cdktf.IResolvable);
    resetEucDisabled(): void;
    get eucDisabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleColabRuntimeTemplateIdleShutdownConfig {
    /**
    * The duration after which the runtime is automatically shut down. An input of 0s disables the idle shutdown feature, and a valid range is [10m, 24h].
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#idle_timeout GoogleColabRuntimeTemplate#idle_timeout}
    */
    readonly idleTimeout?: string;
}
export declare function googleColabRuntimeTemplateIdleShutdownConfigToTerraform(struct?: GoogleColabRuntimeTemplateIdleShutdownConfigOutputReference | GoogleColabRuntimeTemplateIdleShutdownConfig): any;
export declare function googleColabRuntimeTemplateIdleShutdownConfigToHclTerraform(struct?: GoogleColabRuntimeTemplateIdleShutdownConfigOutputReference | GoogleColabRuntimeTemplateIdleShutdownConfig): any;
export declare class GoogleColabRuntimeTemplateIdleShutdownConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateIdleShutdownConfig | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateIdleShutdownConfig | undefined);
    private _idleTimeout?;
    get idleTimeout(): string;
    set idleTimeout(value: string);
    resetIdleTimeout(): void;
    get idleTimeoutInput(): string | undefined;
}
export interface GoogleColabRuntimeTemplateMachineSpec {
    /**
    * The number of accelerators used by the runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#accelerator_count GoogleColabRuntimeTemplate#accelerator_count}
    */
    readonly acceleratorCount?: number;
    /**
    * The type of hardware accelerator used by the runtime. If specified, acceleratorCount must also be specified.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#accelerator_type GoogleColabRuntimeTemplate#accelerator_type}
    */
    readonly acceleratorType?: string;
    /**
    * The Compute Engine machine type selected for the runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#machine_type GoogleColabRuntimeTemplate#machine_type}
    */
    readonly machineType?: string;
}
export declare function googleColabRuntimeTemplateMachineSpecToTerraform(struct?: GoogleColabRuntimeTemplateMachineSpecOutputReference | GoogleColabRuntimeTemplateMachineSpec): any;
export declare function googleColabRuntimeTemplateMachineSpecToHclTerraform(struct?: GoogleColabRuntimeTemplateMachineSpecOutputReference | GoogleColabRuntimeTemplateMachineSpec): any;
export declare class GoogleColabRuntimeTemplateMachineSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateMachineSpec | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateMachineSpec | undefined);
    private _acceleratorCount?;
    get acceleratorCount(): number;
    set acceleratorCount(value: number);
    resetAcceleratorCount(): void;
    get acceleratorCountInput(): number | undefined;
    private _acceleratorType?;
    get acceleratorType(): string;
    set acceleratorType(value: string);
    resetAcceleratorType(): void;
    get acceleratorTypeInput(): string | undefined;
    private _machineType?;
    get machineType(): string;
    set machineType(value: string);
    resetMachineType(): void;
    get machineTypeInput(): string | undefined;
}
export interface GoogleColabRuntimeTemplateNetworkSpec {
    /**
    * Enable public internet access for the runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#enable_internet_access GoogleColabRuntimeTemplate#enable_internet_access}
    */
    readonly enableInternetAccess?: boolean | cdktf.IResolvable;
    /**
    * The name of the VPC that this runtime is in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#network GoogleColabRuntimeTemplate#network}
    */
    readonly network?: string;
    /**
    * The name of the subnetwork that this runtime is in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#subnetwork GoogleColabRuntimeTemplate#subnetwork}
    */
    readonly subnetwork?: string;
}
export declare function googleColabRuntimeTemplateNetworkSpecToTerraform(struct?: GoogleColabRuntimeTemplateNetworkSpecOutputReference | GoogleColabRuntimeTemplateNetworkSpec): any;
export declare function googleColabRuntimeTemplateNetworkSpecToHclTerraform(struct?: GoogleColabRuntimeTemplateNetworkSpecOutputReference | GoogleColabRuntimeTemplateNetworkSpec): any;
export declare class GoogleColabRuntimeTemplateNetworkSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateNetworkSpec | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateNetworkSpec | undefined);
    private _enableInternetAccess?;
    get enableInternetAccess(): boolean | cdktf.IResolvable;
    set enableInternetAccess(value: boolean | cdktf.IResolvable);
    resetEnableInternetAccess(): void;
    get enableInternetAccessInput(): boolean | cdktf.IResolvable | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _subnetwork?;
    get subnetwork(): string;
    set subnetwork(value: string);
    resetSubnetwork(): void;
    get subnetworkInput(): string | undefined;
}
export interface GoogleColabRuntimeTemplateShieldedVmConfig {
    /**
    * Enables secure boot for the runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#enable_secure_boot GoogleColabRuntimeTemplate#enable_secure_boot}
    */
    readonly enableSecureBoot?: boolean | cdktf.IResolvable;
}
export declare function googleColabRuntimeTemplateShieldedVmConfigToTerraform(struct?: GoogleColabRuntimeTemplateShieldedVmConfigOutputReference | GoogleColabRuntimeTemplateShieldedVmConfig): any;
export declare function googleColabRuntimeTemplateShieldedVmConfigToHclTerraform(struct?: GoogleColabRuntimeTemplateShieldedVmConfigOutputReference | GoogleColabRuntimeTemplateShieldedVmConfig): any;
export declare class GoogleColabRuntimeTemplateShieldedVmConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateShieldedVmConfig | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateShieldedVmConfig | undefined);
    private _enableSecureBoot?;
    get enableSecureBoot(): boolean | cdktf.IResolvable;
    set enableSecureBoot(value: boolean | cdktf.IResolvable);
    resetEnableSecureBoot(): void;
    get enableSecureBootInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleColabRuntimeTemplateSoftwareConfigEnv {
    /**
    * Name of the environment variable. Must be a valid C identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#name GoogleColabRuntimeTemplate#name}
    */
    readonly name?: string;
    /**
    * Variables that reference a $(VAR_NAME) are expanded using the previous defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. The $(VAR_NAME) syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped references will never be expanded, regardless of whether the variable exists or not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#value GoogleColabRuntimeTemplate#value}
    */
    readonly value?: string;
}
export declare function googleColabRuntimeTemplateSoftwareConfigEnvToTerraform(struct?: GoogleColabRuntimeTemplateSoftwareConfigEnv | cdktf.IResolvable): any;
export declare function googleColabRuntimeTemplateSoftwareConfigEnvToHclTerraform(struct?: GoogleColabRuntimeTemplateSoftwareConfigEnv | cdktf.IResolvable): any;
export declare class GoogleColabRuntimeTemplateSoftwareConfigEnvOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleColabRuntimeTemplateSoftwareConfigEnv | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateSoftwareConfigEnv | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class GoogleColabRuntimeTemplateSoftwareConfigEnvList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleColabRuntimeTemplateSoftwareConfigEnv[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleColabRuntimeTemplateSoftwareConfigEnvOutputReference;
}
export interface GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig {
    /**
    * Post startup script to run after runtime is started.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#post_startup_script GoogleColabRuntimeTemplate#post_startup_script}
    */
    readonly postStartupScript?: string;
    /**
    * Post startup script behavior that defines download and execution behavior. Possible values: ["RUN_ONCE", "RUN_EVERY_START", "DOWNLOAD_AND_RUN_EVERY_START"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#post_startup_script_behavior GoogleColabRuntimeTemplate#post_startup_script_behavior}
    */
    readonly postStartupScriptBehavior?: string;
    /**
    * Post startup script url to download. Example: https://bucket/script.sh.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#post_startup_script_url GoogleColabRuntimeTemplate#post_startup_script_url}
    */
    readonly postStartupScriptUrl?: string;
}
export declare function googleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfigToTerraform(struct?: GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfigOutputReference | GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig): any;
export declare function googleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfigToHclTerraform(struct?: GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfigOutputReference | GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig): any;
export declare class GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig | undefined);
    private _postStartupScript?;
    get postStartupScript(): string;
    set postStartupScript(value: string);
    resetPostStartupScript(): void;
    get postStartupScriptInput(): string | undefined;
    private _postStartupScriptBehavior?;
    get postStartupScriptBehavior(): string;
    set postStartupScriptBehavior(value: string);
    resetPostStartupScriptBehavior(): void;
    get postStartupScriptBehaviorInput(): string | undefined;
    private _postStartupScriptUrl?;
    get postStartupScriptUrl(): string;
    set postStartupScriptUrl(value: string);
    resetPostStartupScriptUrl(): void;
    get postStartupScriptUrlInput(): string | undefined;
}
export interface GoogleColabRuntimeTemplateSoftwareConfig {
    /**
    * env block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#env GoogleColabRuntimeTemplate#env}
    */
    readonly env?: GoogleColabRuntimeTemplateSoftwareConfigEnv[] | cdktf.IResolvable;
    /**
    * post_startup_script_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#post_startup_script_config GoogleColabRuntimeTemplate#post_startup_script_config}
    */
    readonly postStartupScriptConfig?: GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig;
}
export declare function googleColabRuntimeTemplateSoftwareConfigToTerraform(struct?: GoogleColabRuntimeTemplateSoftwareConfigOutputReference | GoogleColabRuntimeTemplateSoftwareConfig): any;
export declare function googleColabRuntimeTemplateSoftwareConfigToHclTerraform(struct?: GoogleColabRuntimeTemplateSoftwareConfigOutputReference | GoogleColabRuntimeTemplateSoftwareConfig): any;
export declare class GoogleColabRuntimeTemplateSoftwareConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateSoftwareConfig | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateSoftwareConfig | undefined);
    private _env;
    get env(): GoogleColabRuntimeTemplateSoftwareConfigEnvList;
    putEnv(value: GoogleColabRuntimeTemplateSoftwareConfigEnv[] | cdktf.IResolvable): void;
    resetEnv(): void;
    get envInput(): cdktf.IResolvable | GoogleColabRuntimeTemplateSoftwareConfigEnv[] | undefined;
    private _postStartupScriptConfig;
    get postStartupScriptConfig(): GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfigOutputReference;
    putPostStartupScriptConfig(value: GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig): void;
    resetPostStartupScriptConfig(): void;
    get postStartupScriptConfigInput(): GoogleColabRuntimeTemplateSoftwareConfigPostStartupScriptConfig | undefined;
}
export interface GoogleColabRuntimeTemplateTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#create GoogleColabRuntimeTemplate#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#delete GoogleColabRuntimeTemplate#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#update GoogleColabRuntimeTemplate#update}
    */
    readonly update?: string;
}
export declare function googleColabRuntimeTemplateTimeoutsToTerraform(struct?: GoogleColabRuntimeTemplateTimeouts | cdktf.IResolvable): any;
export declare function googleColabRuntimeTemplateTimeoutsToHclTerraform(struct?: GoogleColabRuntimeTemplateTimeouts | cdktf.IResolvable): any;
export declare class GoogleColabRuntimeTemplateTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleColabRuntimeTemplateTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleColabRuntimeTemplateTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template google_colab_runtime_template}
*/
export declare class GoogleColabRuntimeTemplate extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_colab_runtime_template";
    /**
    * Generates CDKTF code for importing a GoogleColabRuntimeTemplate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleColabRuntimeTemplate to import
    * @param importFromId The id of the existing GoogleColabRuntimeTemplate that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleColabRuntimeTemplate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_colab_runtime_template google_colab_runtime_template} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleColabRuntimeTemplateConfig
    */
    constructor(scope: Construct, id: string, config: GoogleColabRuntimeTemplateConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _networkTags?;
    get networkTags(): string[];
    set networkTags(value: string[]);
    resetNetworkTags(): void;
    get networkTagsInput(): string[] | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _dataPersistentDiskSpec;
    get dataPersistentDiskSpec(): GoogleColabRuntimeTemplateDataPersistentDiskSpecOutputReference;
    putDataPersistentDiskSpec(value: GoogleColabRuntimeTemplateDataPersistentDiskSpec): void;
    resetDataPersistentDiskSpec(): void;
    get dataPersistentDiskSpecInput(): GoogleColabRuntimeTemplateDataPersistentDiskSpec | undefined;
    private _encryptionSpec;
    get encryptionSpec(): GoogleColabRuntimeTemplateEncryptionSpecOutputReference;
    putEncryptionSpec(value: GoogleColabRuntimeTemplateEncryptionSpec): void;
    resetEncryptionSpec(): void;
    get encryptionSpecInput(): GoogleColabRuntimeTemplateEncryptionSpec | undefined;
    private _eucConfig;
    get eucConfig(): GoogleColabRuntimeTemplateEucConfigOutputReference;
    putEucConfig(value: GoogleColabRuntimeTemplateEucConfig): void;
    resetEucConfig(): void;
    get eucConfigInput(): GoogleColabRuntimeTemplateEucConfig | undefined;
    private _idleShutdownConfig;
    get idleShutdownConfig(): GoogleColabRuntimeTemplateIdleShutdownConfigOutputReference;
    putIdleShutdownConfig(value: GoogleColabRuntimeTemplateIdleShutdownConfig): void;
    resetIdleShutdownConfig(): void;
    get idleShutdownConfigInput(): GoogleColabRuntimeTemplateIdleShutdownConfig | undefined;
    private _machineSpec;
    get machineSpec(): GoogleColabRuntimeTemplateMachineSpecOutputReference;
    putMachineSpec(value: GoogleColabRuntimeTemplateMachineSpec): void;
    resetMachineSpec(): void;
    get machineSpecInput(): GoogleColabRuntimeTemplateMachineSpec | undefined;
    private _networkSpec;
    get networkSpec(): GoogleColabRuntimeTemplateNetworkSpecOutputReference;
    putNetworkSpec(value: GoogleColabRuntimeTemplateNetworkSpec): void;
    resetNetworkSpec(): void;
    get networkSpecInput(): GoogleColabRuntimeTemplateNetworkSpec | undefined;
    private _shieldedVmConfig;
    get shieldedVmConfig(): GoogleColabRuntimeTemplateShieldedVmConfigOutputReference;
    putShieldedVmConfig(value: GoogleColabRuntimeTemplateShieldedVmConfig): void;
    resetShieldedVmConfig(): void;
    get shieldedVmConfigInput(): GoogleColabRuntimeTemplateShieldedVmConfig | undefined;
    private _softwareConfig;
    get softwareConfig(): GoogleColabRuntimeTemplateSoftwareConfigOutputReference;
    putSoftwareConfig(value: GoogleColabRuntimeTemplateSoftwareConfig): void;
    resetSoftwareConfig(): void;
    get softwareConfigInput(): GoogleColabRuntimeTemplateSoftwareConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleColabRuntimeTemplateTimeoutsOutputReference;
    putTimeouts(value: GoogleColabRuntimeTemplateTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleColabRuntimeTemplateTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
