/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDeveloperConnectAccountConnectorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Required. The ID to use for the AccountConnector, which will become the final
    * component of the AccountConnector's resource name. Its format should adhere
    * to https://google.aip.dev/122#resource-id-segments Names must be unique
    * per-project per-location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#account_connector_id GoogleDeveloperConnectAccountConnector#account_connector_id}
    */
    readonly accountConnectorId: string;
    /**
    * Optional. Allows users to store small amounts of arbitrary data.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#annotations GoogleDeveloperConnectAccountConnector#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#id GoogleDeveloperConnectAccountConnector#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Labels as key value pairs
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#labels GoogleDeveloperConnectAccountConnector#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#location GoogleDeveloperConnectAccountConnector#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#project GoogleDeveloperConnectAccountConnector#project}
    */
    readonly project?: string;
    /**
    * provider_oauth_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#provider_oauth_config GoogleDeveloperConnectAccountConnector#provider_oauth_config}
    */
    readonly providerOauthConfig?: GoogleDeveloperConnectAccountConnectorProviderOauthConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#timeouts GoogleDeveloperConnectAccountConnector#timeouts}
    */
    readonly timeouts?: GoogleDeveloperConnectAccountConnectorTimeouts;
}
export interface GoogleDeveloperConnectAccountConnectorProviderOauthConfig {
    /**
    * Required. User selected scopes to apply to the Oauth config
    * In the event of changing scopes, user records under AccountConnector will
    * be deleted and users will re-auth again.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#scopes GoogleDeveloperConnectAccountConnector#scopes}
    */
    readonly scopes: string[];
    /**
    * List of providers that are owned by Developer Connect.
    *
    * Possible values:
    * GITHUB
    * GITLAB
    * GOOGLE
    * SENTRY
    * ROVO
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#system_provider_id GoogleDeveloperConnectAccountConnector#system_provider_id}
    */
    readonly systemProviderId?: string;
}
export declare function googleDeveloperConnectAccountConnectorProviderOauthConfigToTerraform(struct?: GoogleDeveloperConnectAccountConnectorProviderOauthConfigOutputReference | GoogleDeveloperConnectAccountConnectorProviderOauthConfig): any;
export declare function googleDeveloperConnectAccountConnectorProviderOauthConfigToHclTerraform(struct?: GoogleDeveloperConnectAccountConnectorProviderOauthConfigOutputReference | GoogleDeveloperConnectAccountConnectorProviderOauthConfig): any;
export declare class GoogleDeveloperConnectAccountConnectorProviderOauthConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectAccountConnectorProviderOauthConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectAccountConnectorProviderOauthConfig | undefined);
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    get scopesInput(): string[] | undefined;
    private _systemProviderId?;
    get systemProviderId(): string;
    set systemProviderId(value: string);
    resetSystemProviderId(): void;
    get systemProviderIdInput(): string | undefined;
}
export interface GoogleDeveloperConnectAccountConnectorTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#create GoogleDeveloperConnectAccountConnector#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#delete GoogleDeveloperConnectAccountConnector#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#update GoogleDeveloperConnectAccountConnector#update}
    */
    readonly update?: string;
}
export declare function googleDeveloperConnectAccountConnectorTimeoutsToTerraform(struct?: GoogleDeveloperConnectAccountConnectorTimeouts | cdktf.IResolvable): any;
export declare function googleDeveloperConnectAccountConnectorTimeoutsToHclTerraform(struct?: GoogleDeveloperConnectAccountConnectorTimeouts | cdktf.IResolvable): any;
export declare class GoogleDeveloperConnectAccountConnectorTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectAccountConnectorTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDeveloperConnectAccountConnectorTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector google_developer_connect_account_connector}
*/
export declare class GoogleDeveloperConnectAccountConnector extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_developer_connect_account_connector";
    /**
    * Generates CDKTF code for importing a GoogleDeveloperConnectAccountConnector resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDeveloperConnectAccountConnector to import
    * @param importFromId The id of the existing GoogleDeveloperConnectAccountConnector that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDeveloperConnectAccountConnector to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_account_connector google_developer_connect_account_connector} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDeveloperConnectAccountConnectorConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDeveloperConnectAccountConnectorConfig);
    private _accountConnectorId?;
    get accountConnectorId(): string;
    set accountConnectorId(value: string);
    get accountConnectorIdInput(): string | undefined;
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    get oauthStartUri(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _providerOauthConfig;
    get providerOauthConfig(): GoogleDeveloperConnectAccountConnectorProviderOauthConfigOutputReference;
    putProviderOauthConfig(value: GoogleDeveloperConnectAccountConnectorProviderOauthConfig): void;
    resetProviderOauthConfig(): void;
    get providerOauthConfigInput(): GoogleDeveloperConnectAccountConnectorProviderOauthConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleDeveloperConnectAccountConnectorTimeoutsOutputReference;
    putTimeouts(value: GoogleDeveloperConnectAccountConnectorTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDeveloperConnectAccountConnectorTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
