/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDeveloperConnectConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Allows clients to store small amounts of arbitrary data.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#annotations GoogleDeveloperConnectConnection#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Required. Id of the requesting object
    * If auto-generating Id server-side, remove this field and
    * connection_id from the method_signature of Create RPC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#connection_id GoogleDeveloperConnectConnection#connection_id}
    */
    readonly connectionId: string;
    /**
    * Optional. If disabled is set to true, functionality is disabled for this connection.
    * Repository based API methods and webhooks processing for repositories in
    * this connection will be disabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#disabled GoogleDeveloperConnectConnection#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * Optional. This checksum is computed by the server based on the value of other
    * fields, and may be sent on update and delete requests to ensure the
    * client has an up-to-date value before proceeding.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#etag GoogleDeveloperConnectConnection#etag}
    */
    readonly etag?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#id GoogleDeveloperConnectConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Labels as key value pairs
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#labels GoogleDeveloperConnectConnection#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#location GoogleDeveloperConnectConnection#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#project GoogleDeveloperConnectConnection#project}
    */
    readonly project?: string;
    /**
    * bitbucket_cloud_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#bitbucket_cloud_config GoogleDeveloperConnectConnection#bitbucket_cloud_config}
    */
    readonly bitbucketCloudConfig?: GoogleDeveloperConnectConnectionBitbucketCloudConfig;
    /**
    * bitbucket_data_center_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#bitbucket_data_center_config GoogleDeveloperConnectConnection#bitbucket_data_center_config}
    */
    readonly bitbucketDataCenterConfig?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfig;
    /**
    * crypto_key_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#crypto_key_config GoogleDeveloperConnectConnection#crypto_key_config}
    */
    readonly cryptoKeyConfig?: GoogleDeveloperConnectConnectionCryptoKeyConfig;
    /**
    * github_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#github_config GoogleDeveloperConnectConnection#github_config}
    */
    readonly githubConfig?: GoogleDeveloperConnectConnectionGithubConfig;
    /**
    * github_enterprise_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#github_enterprise_config GoogleDeveloperConnectConnection#github_enterprise_config}
    */
    readonly githubEnterpriseConfig?: GoogleDeveloperConnectConnectionGithubEnterpriseConfig;
    /**
    * gitlab_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#gitlab_config GoogleDeveloperConnectConnection#gitlab_config}
    */
    readonly gitlabConfig?: GoogleDeveloperConnectConnectionGitlabConfig;
    /**
    * gitlab_enterprise_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#gitlab_enterprise_config GoogleDeveloperConnectConnection#gitlab_enterprise_config}
    */
    readonly gitlabEnterpriseConfig?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#timeouts GoogleDeveloperConnectConnection#timeouts}
    */
    readonly timeouts?: GoogleDeveloperConnectConnectionTimeouts;
}
export interface GoogleDeveloperConnectConnectionInstallationState {
}
export declare function googleDeveloperConnectConnectionInstallationStateToTerraform(struct?: GoogleDeveloperConnectConnectionInstallationState): any;
export declare function googleDeveloperConnectConnectionInstallationStateToHclTerraform(struct?: GoogleDeveloperConnectConnectionInstallationState): any;
export declare class GoogleDeveloperConnectConnectionInstallationStateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDeveloperConnectConnectionInstallationState | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionInstallationState | undefined);
    get actionUri(): string;
    get message(): string;
    get stage(): string;
}
export declare class GoogleDeveloperConnectConnectionInstallationStateList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDeveloperConnectConnectionInstallationStateOutputReference;
}
export interface GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionBitbucketCloudConfig {
    /**
    * Required. Immutable. SecretManager resource containing the webhook secret used to verify webhook
    * events, formatted as 'projects/* /secrets/* /versions/*'. This is used to
    * validate and create webhooks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#webhook_secret_secret_version GoogleDeveloperConnectConnection#webhook_secret_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly webhookSecretSecretVersion: string;
    /**
    * Required. The Bitbucket Cloud Workspace ID to be connected to Google Cloud Platform.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#workspace GoogleDeveloperConnectConnection#workspace}
    */
    readonly workspace: string;
    /**
    * authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#authorizer_credential GoogleDeveloperConnectConnection#authorizer_credential}
    */
    readonly authorizerCredential: GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential;
    /**
    * read_authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#read_authorizer_credential GoogleDeveloperConnectConnection#read_authorizer_credential}
    */
    readonly readAuthorizerCredential: GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential;
}
export declare function googleDeveloperConnectConnectionBitbucketCloudConfigToTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketCloudConfigOutputReference | GoogleDeveloperConnectConnectionBitbucketCloudConfig): any;
export declare function googleDeveloperConnectConnectionBitbucketCloudConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketCloudConfigOutputReference | GoogleDeveloperConnectConnectionBitbucketCloudConfig): any;
export declare class GoogleDeveloperConnectConnectionBitbucketCloudConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionBitbucketCloudConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionBitbucketCloudConfig | undefined);
    private _webhookSecretSecretVersion?;
    get webhookSecretSecretVersion(): string;
    set webhookSecretSecretVersion(value: string);
    get webhookSecretSecretVersionInput(): string | undefined;
    private _workspace?;
    get workspace(): string;
    set workspace(value: string);
    get workspaceInput(): string | undefined;
    private _authorizerCredential;
    get authorizerCredential(): GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredentialOutputReference;
    putAuthorizerCredential(value: GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential): void;
    get authorizerCredentialInput(): GoogleDeveloperConnectConnectionBitbucketCloudConfigAuthorizerCredential | undefined;
    private _readAuthorizerCredential;
    get readAuthorizerCredential(): GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredentialOutputReference;
    putReadAuthorizerCredential(value: GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential): void;
    get readAuthorizerCredentialInput(): GoogleDeveloperConnectConnectionBitbucketCloudConfigReadAuthorizerCredential | undefined;
}
export interface GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig {
    /**
    * Required. The Service Directory service name.
    * Format:
    * projects/{project}/locations/{location}/namespaces/{namespace}/services/{service}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#service GoogleDeveloperConnectConnection#service}
    */
    readonly service: string;
}
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfigToTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfigOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig): any;
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfigOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig): any;
export declare class GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig | undefined);
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
}
export interface GoogleDeveloperConnectConnectionBitbucketDataCenterConfig {
    /**
    * Required. The URI of the Bitbucket Data Center host this connection is for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#host_uri GoogleDeveloperConnectConnection#host_uri}
    */
    readonly hostUri: string;
    /**
    * Optional. SSL certificate authority to trust when making requests to Bitbucket Data
    * Center.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#ssl_ca_certificate GoogleDeveloperConnectConnection#ssl_ca_certificate}
    */
    readonly sslCaCertificate?: string;
    /**
    * Required. Immutable. SecretManager resource containing the webhook secret used to verify webhook
    * events, formatted as 'projects/* /secrets/* /versions/*'. This is used to
    * validate webhooks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#webhook_secret_secret_version GoogleDeveloperConnectConnection#webhook_secret_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly webhookSecretSecretVersion: string;
    /**
    * authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#authorizer_credential GoogleDeveloperConnectConnection#authorizer_credential}
    */
    readonly authorizerCredential: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential;
    /**
    * read_authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#read_authorizer_credential GoogleDeveloperConnectConnection#read_authorizer_credential}
    */
    readonly readAuthorizerCredential: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential;
    /**
    * service_directory_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#service_directory_config GoogleDeveloperConnectConnection#service_directory_config}
    */
    readonly serviceDirectoryConfig?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig;
}
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigToTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfig): any;
export declare function googleDeveloperConnectConnectionBitbucketDataCenterConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigOutputReference | GoogleDeveloperConnectConnectionBitbucketDataCenterConfig): any;
export declare class GoogleDeveloperConnectConnectionBitbucketDataCenterConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfig | undefined);
    private _hostUri?;
    get hostUri(): string;
    set hostUri(value: string);
    get hostUriInput(): string | undefined;
    get serverVersion(): string;
    private _sslCaCertificate?;
    get sslCaCertificate(): string;
    set sslCaCertificate(value: string);
    resetSslCaCertificate(): void;
    get sslCaCertificateInput(): string | undefined;
    private _webhookSecretSecretVersion?;
    get webhookSecretSecretVersion(): string;
    set webhookSecretSecretVersion(value: string);
    get webhookSecretSecretVersionInput(): string | undefined;
    private _authorizerCredential;
    get authorizerCredential(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredentialOutputReference;
    putAuthorizerCredential(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential): void;
    get authorizerCredentialInput(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigAuthorizerCredential | undefined;
    private _readAuthorizerCredential;
    get readAuthorizerCredential(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredentialOutputReference;
    putReadAuthorizerCredential(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential): void;
    get readAuthorizerCredentialInput(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigReadAuthorizerCredential | undefined;
    private _serviceDirectoryConfig;
    get serviceDirectoryConfig(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfigOutputReference;
    putServiceDirectoryConfig(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig): void;
    resetServiceDirectoryConfig(): void;
    get serviceDirectoryConfigInput(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigServiceDirectoryConfig | undefined;
}
export interface GoogleDeveloperConnectConnectionCryptoKeyConfig {
    /**
    * Required. The name of the key which is used to encrypt/decrypt customer data. For key
    * in Cloud KMS, the key should be in the format of
    * 'projects/* /locations/* /keyRings/* /cryptoKeys/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#key_reference GoogleDeveloperConnectConnection#key_reference}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly keyReference: string;
}
export declare function googleDeveloperConnectConnectionCryptoKeyConfigToTerraform(struct?: GoogleDeveloperConnectConnectionCryptoKeyConfigOutputReference | GoogleDeveloperConnectConnectionCryptoKeyConfig): any;
export declare function googleDeveloperConnectConnectionCryptoKeyConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionCryptoKeyConfigOutputReference | GoogleDeveloperConnectConnectionCryptoKeyConfig): any;
export declare class GoogleDeveloperConnectConnectionCryptoKeyConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionCryptoKeyConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionCryptoKeyConfig | undefined);
    private _keyReference?;
    get keyReference(): string;
    set keyReference(value: string);
    get keyReferenceInput(): string | undefined;
}
export interface GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the OAuth token that authorizes
    * the connection. Format: 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#oauth_token_secret_version GoogleDeveloperConnectConnection#oauth_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly oauthTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionGithubConfigAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionGithubConfigAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential | undefined);
    private _oauthTokenSecretVersion?;
    get oauthTokenSecretVersion(): string;
    set oauthTokenSecretVersion(value: string);
    get oauthTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionGithubConfig {
    /**
    * Optional. GitHub App installation id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#app_installation_id GoogleDeveloperConnectConnection#app_installation_id}
    */
    readonly appInstallationId?: string;
    /**
    * Required. Immutable. The GitHub Application that was installed to the GitHub user or
    * organization.
    * Possible values:
    * GIT_HUB_APP_UNSPECIFIED
    * DEVELOPER_CONNECT
    * FIREBASE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#github_app GoogleDeveloperConnectConnection#github_app}
    */
    readonly githubApp: string;
    /**
    * authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#authorizer_credential GoogleDeveloperConnectConnection#authorizer_credential}
    */
    readonly authorizerCredential?: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential;
}
export declare function googleDeveloperConnectConnectionGithubConfigToTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigOutputReference | GoogleDeveloperConnectConnectionGithubConfig): any;
export declare function googleDeveloperConnectConnectionGithubConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigOutputReference | GoogleDeveloperConnectConnectionGithubConfig): any;
export declare class GoogleDeveloperConnectConnectionGithubConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGithubConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGithubConfig | undefined);
    private _appInstallationId?;
    get appInstallationId(): string;
    set appInstallationId(value: string);
    resetAppInstallationId(): void;
    get appInstallationIdInput(): string | undefined;
    private _githubApp?;
    get githubApp(): string;
    set githubApp(value: string);
    get githubAppInput(): string | undefined;
    get installationUri(): string;
    private _authorizerCredential;
    get authorizerCredential(): GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference;
    putAuthorizerCredential(value: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential): void;
    resetAuthorizerCredential(): void;
    get authorizerCredentialInput(): GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential | undefined;
}
export interface GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig {
    /**
    * Required. The Service Directory service name.
    * Format:
    * projects/{project}/locations/{location}/namespaces/{namespace}/services/{service}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#service GoogleDeveloperConnectConnection#service}
    */
    readonly service: string;
}
export declare function googleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfigToTerraform(struct?: GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfigOutputReference | GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig): any;
export declare function googleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfigOutputReference | GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig): any;
export declare class GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig | undefined);
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
}
export interface GoogleDeveloperConnectConnectionGithubEnterpriseConfig {
    /**
    * Optional. ID of the GitHub App created from the manifest.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#app_id GoogleDeveloperConnectConnection#app_id}
    */
    readonly appId?: string;
    /**
    * Optional. ID of the installation of the GitHub App.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#app_installation_id GoogleDeveloperConnectConnection#app_installation_id}
    */
    readonly appInstallationId?: string;
    /**
    * Required. The URI of the GitHub Enterprise host this connection is for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#host_uri GoogleDeveloperConnectConnection#host_uri}
    */
    readonly hostUri: string;
    /**
    * Optional. SecretManager resource containing the private key of the GitHub App,
    * formatted as 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#private_key_secret_version GoogleDeveloperConnectConnection#private_key_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly privateKeySecretVersion?: string;
    /**
    * Optional. SSL certificate to use for requests to GitHub Enterprise.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#ssl_ca_certificate GoogleDeveloperConnectConnection#ssl_ca_certificate}
    */
    readonly sslCaCertificate?: string;
    /**
    * Optional. SecretManager resource containing the webhook secret of the GitHub App,
    * formatted as 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#webhook_secret_secret_version GoogleDeveloperConnectConnection#webhook_secret_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly webhookSecretSecretVersion?: string;
    /**
    * service_directory_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#service_directory_config GoogleDeveloperConnectConnection#service_directory_config}
    */
    readonly serviceDirectoryConfig?: GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig;
}
export declare function googleDeveloperConnectConnectionGithubEnterpriseConfigToTerraform(struct?: GoogleDeveloperConnectConnectionGithubEnterpriseConfigOutputReference | GoogleDeveloperConnectConnectionGithubEnterpriseConfig): any;
export declare function googleDeveloperConnectConnectionGithubEnterpriseConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionGithubEnterpriseConfigOutputReference | GoogleDeveloperConnectConnectionGithubEnterpriseConfig): any;
export declare class GoogleDeveloperConnectConnectionGithubEnterpriseConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGithubEnterpriseConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGithubEnterpriseConfig | undefined);
    private _appId?;
    get appId(): string;
    set appId(value: string);
    resetAppId(): void;
    get appIdInput(): string | undefined;
    private _appInstallationId?;
    get appInstallationId(): string;
    set appInstallationId(value: string);
    resetAppInstallationId(): void;
    get appInstallationIdInput(): string | undefined;
    get appSlug(): string;
    private _hostUri?;
    get hostUri(): string;
    set hostUri(value: string);
    get hostUriInput(): string | undefined;
    get installationUri(): string;
    private _privateKeySecretVersion?;
    get privateKeySecretVersion(): string;
    set privateKeySecretVersion(value: string);
    resetPrivateKeySecretVersion(): void;
    get privateKeySecretVersionInput(): string | undefined;
    get serverVersion(): string;
    private _sslCaCertificate?;
    get sslCaCertificate(): string;
    set sslCaCertificate(value: string);
    resetSslCaCertificate(): void;
    get sslCaCertificateInput(): string | undefined;
    private _webhookSecretSecretVersion?;
    get webhookSecretSecretVersion(): string;
    set webhookSecretSecretVersion(value: string);
    resetWebhookSecretSecretVersion(): void;
    get webhookSecretSecretVersionInput(): string | undefined;
    private _serviceDirectoryConfig;
    get serviceDirectoryConfig(): GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfigOutputReference;
    putServiceDirectoryConfig(value: GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig): void;
    resetServiceDirectoryConfig(): void;
    get serviceDirectoryConfigInput(): GoogleDeveloperConnectConnectionGithubEnterpriseConfigServiceDirectoryConfig | undefined;
}
export interface GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionGitlabConfigAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionGitlabConfigAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionGitlabConfig {
    /**
    * Required. Immutable. SecretManager resource containing the webhook secret of a GitLab project,
    * formatted as 'projects/* /secrets/* /versions/*'. This is used to validate
    * webhooks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#webhook_secret_secret_version GoogleDeveloperConnectConnection#webhook_secret_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly webhookSecretSecretVersion: string;
    /**
    * authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#authorizer_credential GoogleDeveloperConnectConnection#authorizer_credential}
    */
    readonly authorizerCredential: GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential;
    /**
    * read_authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#read_authorizer_credential GoogleDeveloperConnectConnection#read_authorizer_credential}
    */
    readonly readAuthorizerCredential: GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential;
}
export declare function googleDeveloperConnectConnectionGitlabConfigToTerraform(struct?: GoogleDeveloperConnectConnectionGitlabConfigOutputReference | GoogleDeveloperConnectConnectionGitlabConfig): any;
export declare function googleDeveloperConnectConnectionGitlabConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionGitlabConfigOutputReference | GoogleDeveloperConnectConnectionGitlabConfig): any;
export declare class GoogleDeveloperConnectConnectionGitlabConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGitlabConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGitlabConfig | undefined);
    private _webhookSecretSecretVersion?;
    get webhookSecretSecretVersion(): string;
    set webhookSecretSecretVersion(value: string);
    get webhookSecretSecretVersionInput(): string | undefined;
    private _authorizerCredential;
    get authorizerCredential(): GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredentialOutputReference;
    putAuthorizerCredential(value: GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential): void;
    get authorizerCredentialInput(): GoogleDeveloperConnectConnectionGitlabConfigAuthorizerCredential | undefined;
    private _readAuthorizerCredential;
    get readAuthorizerCredential(): GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredentialOutputReference;
    putReadAuthorizerCredential(value: GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential): void;
    get readAuthorizerCredentialInput(): GoogleDeveloperConnectConnectionGitlabConfigReadAuthorizerCredential | undefined;
}
export interface GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the user token that authorizes
    * the Developer Connect connection. Format:
    * 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#user_token_secret_version GoogleDeveloperConnectConnection#user_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly userTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential | undefined);
    private _userTokenSecretVersion?;
    get userTokenSecretVersion(): string;
    set userTokenSecretVersion(value: string);
    get userTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig {
    /**
    * Required. The Service Directory service name.
    * Format:
    * projects/{project}/locations/{location}/namespaces/{namespace}/services/{service}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#service GoogleDeveloperConnectConnection#service}
    */
    readonly service: string;
}
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfigToTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfigOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig): any;
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfigOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig): any;
export declare class GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig | undefined);
    private _service?;
    get service(): string;
    set service(value: string);
    get serviceInput(): string | undefined;
}
export interface GoogleDeveloperConnectConnectionGitlabEnterpriseConfig {
    /**
    * Required. The URI of the GitLab Enterprise host this connection is for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#host_uri GoogleDeveloperConnectConnection#host_uri}
    */
    readonly hostUri: string;
    /**
    * Optional. SSL Certificate Authority certificate to use for requests to GitLab
    * Enterprise instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#ssl_ca_certificate GoogleDeveloperConnectConnection#ssl_ca_certificate}
    */
    readonly sslCaCertificate?: string;
    /**
    * Required. Immutable. SecretManager resource containing the webhook secret of a GitLab project,
    * formatted as 'projects/* /secrets/* /versions/*'. This is used to validate
    * webhooks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#webhook_secret_secret_version GoogleDeveloperConnectConnection#webhook_secret_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly webhookSecretSecretVersion: string;
    /**
    * authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#authorizer_credential GoogleDeveloperConnectConnection#authorizer_credential}
    */
    readonly authorizerCredential: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential;
    /**
    * read_authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#read_authorizer_credential GoogleDeveloperConnectConnection#read_authorizer_credential}
    */
    readonly readAuthorizerCredential: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential;
    /**
    * service_directory_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#service_directory_config GoogleDeveloperConnectConnection#service_directory_config}
    */
    readonly serviceDirectoryConfig?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig;
}
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigToTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfig): any;
export declare function googleDeveloperConnectConnectionGitlabEnterpriseConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigOutputReference | GoogleDeveloperConnectConnectionGitlabEnterpriseConfig): any;
export declare class GoogleDeveloperConnectConnectionGitlabEnterpriseConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfig | undefined);
    private _hostUri?;
    get hostUri(): string;
    set hostUri(value: string);
    get hostUriInput(): string | undefined;
    get serverVersion(): string;
    private _sslCaCertificate?;
    get sslCaCertificate(): string;
    set sslCaCertificate(value: string);
    resetSslCaCertificate(): void;
    get sslCaCertificateInput(): string | undefined;
    private _webhookSecretSecretVersion?;
    get webhookSecretSecretVersion(): string;
    set webhookSecretSecretVersion(value: string);
    get webhookSecretSecretVersionInput(): string | undefined;
    private _authorizerCredential;
    get authorizerCredential(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredentialOutputReference;
    putAuthorizerCredential(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential): void;
    get authorizerCredentialInput(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigAuthorizerCredential | undefined;
    private _readAuthorizerCredential;
    get readAuthorizerCredential(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredentialOutputReference;
    putReadAuthorizerCredential(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential): void;
    get readAuthorizerCredentialInput(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigReadAuthorizerCredential | undefined;
    private _serviceDirectoryConfig;
    get serviceDirectoryConfig(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfigOutputReference;
    putServiceDirectoryConfig(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig): void;
    resetServiceDirectoryConfig(): void;
    get serviceDirectoryConfigInput(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigServiceDirectoryConfig | undefined;
}
export interface GoogleDeveloperConnectConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#create GoogleDeveloperConnectConnection#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#delete GoogleDeveloperConnectConnection#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#update GoogleDeveloperConnectConnection#update}
    */
    readonly update?: string;
}
export declare function googleDeveloperConnectConnectionTimeoutsToTerraform(struct?: GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable): any;
export declare function googleDeveloperConnectConnectionTimeoutsToHclTerraform(struct?: GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable): any;
export declare class GoogleDeveloperConnectConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection google_developer_connect_connection}
*/
export declare class GoogleDeveloperConnectConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_developer_connect_connection";
    /**
    * Generates CDKTF code for importing a GoogleDeveloperConnectConnection resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDeveloperConnectConnection to import
    * @param importFromId The id of the existing GoogleDeveloperConnectConnection that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDeveloperConnectConnection to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_developer_connect_connection google_developer_connect_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDeveloperConnectConnectionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDeveloperConnectConnectionConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _connectionId?;
    get connectionId(): string;
    set connectionId(value: string);
    get connectionIdInput(): string | undefined;
    get createTime(): string;
    get deleteTime(): string;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _etag?;
    get etag(): string;
    set etag(value: string);
    resetEtag(): void;
    get etagInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _installationState;
    get installationState(): GoogleDeveloperConnectConnectionInstallationStateList;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _bitbucketCloudConfig;
    get bitbucketCloudConfig(): GoogleDeveloperConnectConnectionBitbucketCloudConfigOutputReference;
    putBitbucketCloudConfig(value: GoogleDeveloperConnectConnectionBitbucketCloudConfig): void;
    resetBitbucketCloudConfig(): void;
    get bitbucketCloudConfigInput(): GoogleDeveloperConnectConnectionBitbucketCloudConfig | undefined;
    private _bitbucketDataCenterConfig;
    get bitbucketDataCenterConfig(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfigOutputReference;
    putBitbucketDataCenterConfig(value: GoogleDeveloperConnectConnectionBitbucketDataCenterConfig): void;
    resetBitbucketDataCenterConfig(): void;
    get bitbucketDataCenterConfigInput(): GoogleDeveloperConnectConnectionBitbucketDataCenterConfig | undefined;
    private _cryptoKeyConfig;
    get cryptoKeyConfig(): GoogleDeveloperConnectConnectionCryptoKeyConfigOutputReference;
    putCryptoKeyConfig(value: GoogleDeveloperConnectConnectionCryptoKeyConfig): void;
    resetCryptoKeyConfig(): void;
    get cryptoKeyConfigInput(): GoogleDeveloperConnectConnectionCryptoKeyConfig | undefined;
    private _githubConfig;
    get githubConfig(): GoogleDeveloperConnectConnectionGithubConfigOutputReference;
    putGithubConfig(value: GoogleDeveloperConnectConnectionGithubConfig): void;
    resetGithubConfig(): void;
    get githubConfigInput(): GoogleDeveloperConnectConnectionGithubConfig | undefined;
    private _githubEnterpriseConfig;
    get githubEnterpriseConfig(): GoogleDeveloperConnectConnectionGithubEnterpriseConfigOutputReference;
    putGithubEnterpriseConfig(value: GoogleDeveloperConnectConnectionGithubEnterpriseConfig): void;
    resetGithubEnterpriseConfig(): void;
    get githubEnterpriseConfigInput(): GoogleDeveloperConnectConnectionGithubEnterpriseConfig | undefined;
    private _gitlabConfig;
    get gitlabConfig(): GoogleDeveloperConnectConnectionGitlabConfigOutputReference;
    putGitlabConfig(value: GoogleDeveloperConnectConnectionGitlabConfig): void;
    resetGitlabConfig(): void;
    get gitlabConfigInput(): GoogleDeveloperConnectConnectionGitlabConfig | undefined;
    private _gitlabEnterpriseConfig;
    get gitlabEnterpriseConfig(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfigOutputReference;
    putGitlabEnterpriseConfig(value: GoogleDeveloperConnectConnectionGitlabEnterpriseConfig): void;
    resetGitlabEnterpriseConfig(): void;
    get gitlabEnterpriseConfigInput(): GoogleDeveloperConnectConnectionGitlabEnterpriseConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleDeveloperConnectConnectionTimeoutsOutputReference;
    putTimeouts(value: GoogleDeveloperConnectConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDeveloperConnectConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
