/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleGeminiRepositoryGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Required. Id of the Code Repository Index.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#code_repository_index GoogleGeminiRepositoryGroup#code_repository_index}
    */
    readonly codeRepositoryIndex: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#id GoogleGeminiRepositoryGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Labels as key value pairs.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#labels GoogleGeminiRepositoryGroup#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of the Code Repository Index, for example 'us-central1'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#location GoogleGeminiRepositoryGroup#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#project GoogleGeminiRepositoryGroup#project}
    */
    readonly project?: string;
    /**
    * Required. Id of the Repository Group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#repository_group_id GoogleGeminiRepositoryGroup#repository_group_id}
    */
    readonly repositoryGroupId: string;
    /**
    * repositories block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#repositories GoogleGeminiRepositoryGroup#repositories}
    */
    readonly repositories: GoogleGeminiRepositoryGroupRepositories[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#timeouts GoogleGeminiRepositoryGroup#timeouts}
    */
    readonly timeouts?: GoogleGeminiRepositoryGroupTimeouts;
}
export interface GoogleGeminiRepositoryGroupRepositories {
    /**
    * Required. The Git branch pattern used for indexing in RE2 syntax.
    * See https://github.com/google/re2/wiki/syntax for syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#branch_pattern GoogleGeminiRepositoryGroup#branch_pattern}
    */
    readonly branchPattern: string;
    /**
    * Required. The DeveloperConnect repository full resource name, relative resource name
    * or resource URL to be indexed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#resource GoogleGeminiRepositoryGroup#resource}
    */
    readonly resource: string;
}
export declare function googleGeminiRepositoryGroupRepositoriesToTerraform(struct?: GoogleGeminiRepositoryGroupRepositories | cdktf.IResolvable): any;
export declare function googleGeminiRepositoryGroupRepositoriesToHclTerraform(struct?: GoogleGeminiRepositoryGroupRepositories | cdktf.IResolvable): any;
export declare class GoogleGeminiRepositoryGroupRepositoriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGeminiRepositoryGroupRepositories | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGeminiRepositoryGroupRepositories | cdktf.IResolvable | undefined);
    private _branchPattern?;
    get branchPattern(): string;
    set branchPattern(value: string);
    get branchPatternInput(): string | undefined;
    private _resource?;
    get resource(): string;
    set resource(value: string);
    get resourceInput(): string | undefined;
}
export declare class GoogleGeminiRepositoryGroupRepositoriesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleGeminiRepositoryGroupRepositories[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGeminiRepositoryGroupRepositoriesOutputReference;
}
export interface GoogleGeminiRepositoryGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#create GoogleGeminiRepositoryGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#delete GoogleGeminiRepositoryGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#update GoogleGeminiRepositoryGroup#update}
    */
    readonly update?: string;
}
export declare function googleGeminiRepositoryGroupTimeoutsToTerraform(struct?: GoogleGeminiRepositoryGroupTimeouts | cdktf.IResolvable): any;
export declare function googleGeminiRepositoryGroupTimeoutsToHclTerraform(struct?: GoogleGeminiRepositoryGroupTimeouts | cdktf.IResolvable): any;
export declare class GoogleGeminiRepositoryGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGeminiRepositoryGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGeminiRepositoryGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group google_gemini_repository_group}
*/
export declare class GoogleGeminiRepositoryGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gemini_repository_group";
    /**
    * Generates CDKTF code for importing a GoogleGeminiRepositoryGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleGeminiRepositoryGroup to import
    * @param importFromId The id of the existing GoogleGeminiRepositoryGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleGeminiRepositoryGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gemini_repository_group google_gemini_repository_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleGeminiRepositoryGroupConfig
    */
    constructor(scope: Construct, id: string, config: GoogleGeminiRepositoryGroupConfig);
    private _codeRepositoryIndex?;
    get codeRepositoryIndex(): string;
    set codeRepositoryIndex(value: string);
    get codeRepositoryIndexInput(): string | undefined;
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _repositoryGroupId?;
    get repositoryGroupId(): string;
    set repositoryGroupId(value: string);
    get repositoryGroupIdInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _repositories;
    get repositories(): GoogleGeminiRepositoryGroupRepositoriesList;
    putRepositories(value: GoogleGeminiRepositoryGroupRepositories[] | cdktf.IResolvable): void;
    get repositoriesInput(): cdktf.IResolvable | GoogleGeminiRepositoryGroupRepositories[] | undefined;
    private _timeouts;
    get timeouts(): GoogleGeminiRepositoryGroupTimeoutsOutputReference;
    putTimeouts(value: GoogleGeminiRepositoryGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleGeminiRepositoryGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
