/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleGkeonpremVmwareAdminClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Annotations on the VMware Admin Cluster.
    * This field has the same restrictions as Kubernetes annotations.
    * The total size of all keys and values combined is limited to 256k.
    * Key can have 2 segments: prefix (optional) and name (required),
    * separated by a slash (/).
    * Prefix must be a DNS subdomain.
    * Name must be 63 characters or less, begin and end with alphanumerics,
    * with dashes (-), underscores (_), dots (.), and alphanumerics between.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#annotations GoogleGkeonpremVmwareAdminCluster#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * The bootstrap cluster this VMware admin cluster belongs to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#bootstrap_cluster_membership GoogleGkeonpremVmwareAdminCluster#bootstrap_cluster_membership}
    */
    readonly bootstrapClusterMembership?: string;
    /**
    * A human readable description of this VMware admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#description GoogleGkeonpremVmwareAdminCluster#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#id GoogleGkeonpremVmwareAdminCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The OS image type for the VMware admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#image_type GoogleGkeonpremVmwareAdminCluster#image_type}
    */
    readonly imageType?: string;
    /**
    * The location of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#location GoogleGkeonpremVmwareAdminCluster#location}
    */
    readonly location: string;
    /**
    * The VMware admin cluster resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#name GoogleGkeonpremVmwareAdminCluster#name}
    */
    readonly name: string;
    /**
    * The Anthos clusters on the VMware version for the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#on_prem_version GoogleGkeonpremVmwareAdminCluster#on_prem_version}
    */
    readonly onPremVersion?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#project GoogleGkeonpremVmwareAdminCluster#project}
    */
    readonly project?: string;
    /**
    * addon_node block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#addon_node GoogleGkeonpremVmwareAdminCluster#addon_node}
    */
    readonly addonNode?: GoogleGkeonpremVmwareAdminClusterAddonNode;
    /**
    * anti_affinity_groups block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#anti_affinity_groups GoogleGkeonpremVmwareAdminCluster#anti_affinity_groups}
    */
    readonly antiAffinityGroups?: GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups;
    /**
    * authorization block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#authorization GoogleGkeonpremVmwareAdminCluster#authorization}
    */
    readonly authorization?: GoogleGkeonpremVmwareAdminClusterAuthorization;
    /**
    * auto_repair_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#auto_repair_config GoogleGkeonpremVmwareAdminCluster#auto_repair_config}
    */
    readonly autoRepairConfig?: GoogleGkeonpremVmwareAdminClusterAutoRepairConfig;
    /**
    * control_plane_node block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#control_plane_node GoogleGkeonpremVmwareAdminCluster#control_plane_node}
    */
    readonly controlPlaneNode?: GoogleGkeonpremVmwareAdminClusterControlPlaneNode;
    /**
    * load_balancer block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#load_balancer GoogleGkeonpremVmwareAdminCluster#load_balancer}
    */
    readonly loadBalancer?: GoogleGkeonpremVmwareAdminClusterLoadBalancer;
    /**
    * network_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#network_config GoogleGkeonpremVmwareAdminCluster#network_config}
    */
    readonly networkConfig: GoogleGkeonpremVmwareAdminClusterNetworkConfig;
    /**
    * platform_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#platform_config GoogleGkeonpremVmwareAdminCluster#platform_config}
    */
    readonly platformConfig?: GoogleGkeonpremVmwareAdminClusterPlatformConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#timeouts GoogleGkeonpremVmwareAdminCluster#timeouts}
    */
    readonly timeouts?: GoogleGkeonpremVmwareAdminClusterTimeouts;
    /**
    * vcenter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#vcenter GoogleGkeonpremVmwareAdminCluster#vcenter}
    */
    readonly vcenter?: GoogleGkeonpremVmwareAdminClusterVcenter;
}
export interface GoogleGkeonpremVmwareAdminClusterFleet {
}
export declare function googleGkeonpremVmwareAdminClusterFleetToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterFleet): any;
export declare function googleGkeonpremVmwareAdminClusterFleetToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterFleet): any;
export declare class GoogleGkeonpremVmwareAdminClusterFleetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterFleet | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterFleet | undefined);
    get membership(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterFleetList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterFleetOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterStatusConditions {
}
export declare function googleGkeonpremVmwareAdminClusterStatusConditionsToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterStatusConditions): any;
export declare function googleGkeonpremVmwareAdminClusterStatusConditionsToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterStatusConditions): any;
export declare class GoogleGkeonpremVmwareAdminClusterStatusConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterStatusConditions | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterStatusConditions | undefined);
    get lastTransitionTime(): string;
    get message(): string;
    get reason(): string;
    get state(): string;
    get type(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterStatusConditionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterStatusConditionsOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterStatus {
}
export declare function googleGkeonpremVmwareAdminClusterStatusToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterStatus): any;
export declare function googleGkeonpremVmwareAdminClusterStatusToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterStatus): any;
export declare class GoogleGkeonpremVmwareAdminClusterStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterStatus | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterStatus | undefined);
    private _conditions;
    get conditions(): GoogleGkeonpremVmwareAdminClusterStatusConditionsList;
    get errorMessage(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterStatusOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig {
    /**
    * Whether to enable controle plane node auto resizing.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#enabled GoogleGkeonpremVmwareAdminCluster#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfigOutputReference | GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig): any;
export declare function googleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfigOutputReference | GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterAddonNode {
    /**
    * auto_resize_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#auto_resize_config GoogleGkeonpremVmwareAdminCluster#auto_resize_config}
    */
    readonly autoResizeConfig?: GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig;
}
export declare function googleGkeonpremVmwareAdminClusterAddonNodeToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAddonNodeOutputReference | GoogleGkeonpremVmwareAdminClusterAddonNode): any;
export declare function googleGkeonpremVmwareAdminClusterAddonNodeToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAddonNodeOutputReference | GoogleGkeonpremVmwareAdminClusterAddonNode): any;
export declare class GoogleGkeonpremVmwareAdminClusterAddonNodeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterAddonNode | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterAddonNode | undefined);
    private _autoResizeConfig;
    get autoResizeConfig(): GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfigOutputReference;
    putAutoResizeConfig(value: GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig): void;
    resetAutoResizeConfig(): void;
    get autoResizeConfigInput(): GoogleGkeonpremVmwareAdminClusterAddonNodeAutoResizeConfig | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups {
    /**
    * Spread nodes across at least three physical hosts (requires at least three
    * hosts).
    * Enabled by default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#aag_config_disabled GoogleGkeonpremVmwareAdminCluster#aag_config_disabled}
    */
    readonly aagConfigDisabled: boolean | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterAntiAffinityGroupsToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAntiAffinityGroupsOutputReference | GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups): any;
export declare function googleGkeonpremVmwareAdminClusterAntiAffinityGroupsToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAntiAffinityGroupsOutputReference | GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups): any;
export declare class GoogleGkeonpremVmwareAdminClusterAntiAffinityGroupsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups | undefined);
    private _aagConfigDisabled?;
    get aagConfigDisabled(): boolean | cdktf.IResolvable;
    set aagConfigDisabled(value: boolean | cdktf.IResolvable);
    get aagConfigDisabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers {
    /**
    * The name of the user, e.g. 'my-gcp-id@gmail.com'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#username GoogleGkeonpremVmwareAdminCluster#username}
    */
    readonly username: string;
}
export declare function googleGkeonpremVmwareAdminClusterAuthorizationViewerUsersToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers | cdktf.IResolvable): any;
export declare function googleGkeonpremVmwareAdminClusterAuthorizationViewerUsersToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers | cdktf.IResolvable): any;
export declare class GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers | cdktf.IResolvable | undefined);
    private _username?;
    get username(): string;
    set username(value: string);
    get usernameInput(): string | undefined;
}
export declare class GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsersOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterAuthorization {
    /**
    * viewer_users block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#viewer_users GoogleGkeonpremVmwareAdminCluster#viewer_users}
    */
    readonly viewerUsers?: GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers[] | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterAuthorizationToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAuthorizationOutputReference | GoogleGkeonpremVmwareAdminClusterAuthorization): any;
export declare function googleGkeonpremVmwareAdminClusterAuthorizationToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAuthorizationOutputReference | GoogleGkeonpremVmwareAdminClusterAuthorization): any;
export declare class GoogleGkeonpremVmwareAdminClusterAuthorizationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterAuthorization | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterAuthorization | undefined);
    private _viewerUsers;
    get viewerUsers(): GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsersList;
    putViewerUsers(value: GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers[] | cdktf.IResolvable): void;
    resetViewerUsers(): void;
    get viewerUsersInput(): cdktf.IResolvable | GoogleGkeonpremVmwareAdminClusterAuthorizationViewerUsers[] | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterAutoRepairConfig {
    /**
    * Whether auto repair is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#enabled GoogleGkeonpremVmwareAdminCluster#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterAutoRepairConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAutoRepairConfigOutputReference | GoogleGkeonpremVmwareAdminClusterAutoRepairConfig): any;
export declare function googleGkeonpremVmwareAdminClusterAutoRepairConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterAutoRepairConfigOutputReference | GoogleGkeonpremVmwareAdminClusterAutoRepairConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterAutoRepairConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterAutoRepairConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterAutoRepairConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterControlPlaneNode {
    /**
    * The number of vCPUs for the control-plane node of the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#cpus GoogleGkeonpremVmwareAdminCluster#cpus}
    */
    readonly cpus?: number;
    /**
    * The number of mebibytes of memory for the control-plane node of the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#memory GoogleGkeonpremVmwareAdminCluster#memory}
    */
    readonly memory?: number;
    /**
    * The number of control plane nodes for this VMware admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#replicas GoogleGkeonpremVmwareAdminCluster#replicas}
    */
    readonly replicas?: number;
}
export declare function googleGkeonpremVmwareAdminClusterControlPlaneNodeToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterControlPlaneNodeOutputReference | GoogleGkeonpremVmwareAdminClusterControlPlaneNode): any;
export declare function googleGkeonpremVmwareAdminClusterControlPlaneNodeToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterControlPlaneNodeOutputReference | GoogleGkeonpremVmwareAdminClusterControlPlaneNode): any;
export declare class GoogleGkeonpremVmwareAdminClusterControlPlaneNodeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterControlPlaneNode | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterControlPlaneNode | undefined);
    private _cpus?;
    get cpus(): number;
    set cpus(value: number);
    resetCpus(): void;
    get cpusInput(): number | undefined;
    private _memory?;
    get memory(): number;
    set memory(value: number);
    resetMemory(): void;
    get memoryInput(): number | undefined;
    private _replicas?;
    get replicas(): number;
    set replicas(value: number);
    resetReplicas(): void;
    get replicasInput(): number | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config {
    /**
    * The load balancer's IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#address GoogleGkeonpremVmwareAdminCluster#address}
    */
    readonly address?: string;
    /**
    * he preexisting partition to be used by the load balancer. T
    * his partition is usually created for the admin cluster for example:
    * 'my-f5-admin-partition'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#partition GoogleGkeonpremVmwareAdminCluster#partition}
    */
    readonly partition?: string;
    /**
    * The pool name. Only necessary, if using SNAT.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#snat_pool GoogleGkeonpremVmwareAdminCluster#snat_pool}
    */
    readonly snatPool?: string;
}
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerF5ConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerF5ConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config): any;
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerF5ConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerF5ConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config): any;
export declare class GoogleGkeonpremVmwareAdminClusterLoadBalancerF5ConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config | undefined);
    private _address?;
    get address(): string;
    set address(value: string);
    resetAddress(): void;
    get addressInput(): string | undefined;
    private _partition?;
    get partition(): string;
    set partition(value: string);
    resetPartition(): void;
    get partitionInput(): string | undefined;
    private _snatPool?;
    get snatPool(): string;
    set snatPool(value: string);
    resetSnatPool(): void;
    get snatPoolInput(): string | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig {
    /**
    * NodePort for add-ons server in the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#addons_node_port GoogleGkeonpremVmwareAdminCluster#addons_node_port}
    */
    readonly addonsNodePort?: number;
    /**
    * NodePort for control plane service. The Kubernetes API server in the admin
    * cluster is implemented as a Service of type NodePort (ex. 30968).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#control_plane_node_port GoogleGkeonpremVmwareAdminCluster#control_plane_node_port}
    */
    readonly controlPlaneNodePort?: number;
    /**
    * NodePort for ingress service's http. The ingress service in the admin
    * cluster is implemented as a Service of type NodePort (ex. 32527).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ingress_http_node_port GoogleGkeonpremVmwareAdminCluster#ingress_http_node_port}
    */
    readonly ingressHttpNodePort?: number;
    /**
    * NodePort for ingress service's https. The ingress service in the admin
    * cluster is implemented as a Service of type NodePort (ex. 30139).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ingress_https_node_port GoogleGkeonpremVmwareAdminCluster#ingress_https_node_port}
    */
    readonly ingressHttpsNodePort?: number;
    /**
    * NodePort for konnectivity server service running as a sidecar in each
    * kube-apiserver pod (ex. 30564).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#konnectivity_server_node_port GoogleGkeonpremVmwareAdminCluster#konnectivity_server_node_port}
    */
    readonly konnectivityServerNodePort?: number;
}
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig): any;
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig | undefined);
    private _addonsNodePort?;
    get addonsNodePort(): number;
    set addonsNodePort(value: number);
    resetAddonsNodePort(): void;
    get addonsNodePortInput(): number | undefined;
    private _controlPlaneNodePort?;
    get controlPlaneNodePort(): number;
    set controlPlaneNodePort(value: number);
    resetControlPlaneNodePort(): void;
    get controlPlaneNodePortInput(): number | undefined;
    private _ingressHttpNodePort?;
    get ingressHttpNodePort(): number;
    set ingressHttpNodePort(value: number);
    resetIngressHttpNodePort(): void;
    get ingressHttpNodePortInput(): number | undefined;
    private _ingressHttpsNodePort?;
    get ingressHttpsNodePort(): number;
    set ingressHttpsNodePort(value: number);
    resetIngressHttpsNodePort(): void;
    get ingressHttpsNodePortInput(): number | undefined;
    private _konnectivityServerNodePort?;
    get konnectivityServerNodePort(): number;
    set konnectivityServerNodePort(value: number);
    resetKonnectivityServerNodePort(): void;
    get konnectivityServerNodePortInput(): number | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig {
    /**
    * Metal LB is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#enabled GoogleGkeonpremVmwareAdminCluster#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig): any;
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig {
    /**
    * The VIP to configure the load balancer for add-ons.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#addons_vip GoogleGkeonpremVmwareAdminCluster#addons_vip}
    */
    readonly addonsVip?: string;
    /**
    * The VIP which you previously set aside for the Kubernetes
    * API of this VMware Admin Cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#control_plane_vip GoogleGkeonpremVmwareAdminCluster#control_plane_vip}
    */
    readonly controlPlaneVip: string;
}
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerVipConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig): any;
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerVipConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfigOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig | undefined);
    private _addonsVip?;
    get addonsVip(): string;
    set addonsVip(value: string);
    resetAddonsVip(): void;
    get addonsVipInput(): string | undefined;
    private _controlPlaneVip?;
    get controlPlaneVip(): string;
    set controlPlaneVip(value: string);
    get controlPlaneVipInput(): string | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterLoadBalancer {
    /**
    * f5_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#f5_config GoogleGkeonpremVmwareAdminCluster#f5_config}
    */
    readonly f5Config?: GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config;
    /**
    * manual_lb_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#manual_lb_config GoogleGkeonpremVmwareAdminCluster#manual_lb_config}
    */
    readonly manualLbConfig?: GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig;
    /**
    * metal_lb_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#metal_lb_config GoogleGkeonpremVmwareAdminCluster#metal_lb_config}
    */
    readonly metalLbConfig?: GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig;
    /**
    * vip_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#vip_config GoogleGkeonpremVmwareAdminCluster#vip_config}
    */
    readonly vipConfig: GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig;
}
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancer): any;
export declare function googleGkeonpremVmwareAdminClusterLoadBalancerToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterLoadBalancerOutputReference | GoogleGkeonpremVmwareAdminClusterLoadBalancer): any;
export declare class GoogleGkeonpremVmwareAdminClusterLoadBalancerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterLoadBalancer | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterLoadBalancer | undefined);
    private _f5Config;
    get f5Config(): GoogleGkeonpremVmwareAdminClusterLoadBalancerF5ConfigOutputReference;
    putF5Config(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config): void;
    resetF5Config(): void;
    get f5ConfigInput(): GoogleGkeonpremVmwareAdminClusterLoadBalancerF5Config | undefined;
    private _manualLbConfig;
    get manualLbConfig(): GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfigOutputReference;
    putManualLbConfig(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig): void;
    resetManualLbConfig(): void;
    get manualLbConfigInput(): GoogleGkeonpremVmwareAdminClusterLoadBalancerManualLbConfig | undefined;
    private _metalLbConfig;
    get metalLbConfig(): GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfigOutputReference;
    putMetalLbConfig(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig): void;
    resetMetalLbConfig(): void;
    get metalLbConfigInput(): GoogleGkeonpremVmwareAdminClusterLoadBalancerMetalLbConfig | undefined;
    private _vipConfig;
    get vipConfig(): GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfigOutputReference;
    putVipConfig(value: GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig): void;
    get vipConfigInput(): GoogleGkeonpremVmwareAdminClusterLoadBalancerVipConfig | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig {
    /**
    * enabled is a flag to mark if DHCP IP allocation is
    * used for VMware admin clusters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#enabled GoogleGkeonpremVmwareAdminCluster#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps {
    /**
    * Hostname of the machine. VM's name will be used if this field is empty.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#hostname GoogleGkeonpremVmwareAdminCluster#hostname}
    */
    readonly hostname?: string;
    /**
    * IP could be an IP address (like 1.2.3.4) or a CIDR (like 1.2.3.0/24).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ip GoogleGkeonpremVmwareAdminCluster#ip}
    */
    readonly ip: string;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIpsToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps | cdktf.IResolvable): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIpsToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps | cdktf.IResolvable): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIpsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps | cdktf.IResolvable | undefined);
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    resetHostname(): void;
    get hostnameInput(): string | undefined;
    private _ip?;
    get ip(): string;
    set ip(value: string);
    get ipInput(): string | undefined;
}
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIpsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIpsOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock {
    /**
    * The network gateway used by the VMware Admin Cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#gateway GoogleGkeonpremVmwareAdminCluster#gateway}
    */
    readonly gateway: string;
    /**
    * The netmask used by the VMware Admin Cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#netmask GoogleGkeonpremVmwareAdminCluster#netmask}
    */
    readonly netmask: string;
    /**
    * ips block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ips GoogleGkeonpremVmwareAdminCluster#ips}
    */
    readonly ips: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps[] | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock | undefined);
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _netmask?;
    get netmask(): string;
    set netmask(value: string);
    get netmaskInput(): string | undefined;
    private _ips;
    get ips(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIpsList;
    putIps(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps[] | cdktf.IResolvable): void;
    get ipsInput(): cdktf.IResolvable | GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockIps[] | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig {
    /**
    * control_plane_ip_block block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#control_plane_ip_block GoogleGkeonpremVmwareAdminCluster#control_plane_ip_block}
    */
    readonly controlPlaneIpBlock?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig | undefined);
    private _controlPlaneIpBlock;
    get controlPlaneIpBlock(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlockOutputReference;
    putControlPlaneIpBlock(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock): void;
    resetControlPlaneIpBlock(): void;
    get controlPlaneIpBlockInput(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigControlPlaneIpBlock | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig {
    /**
    * DNS search domains.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#dns_search_domains GoogleGkeonpremVmwareAdminCluster#dns_search_domains}
    */
    readonly dnsSearchDomains?: string[];
    /**
    * DNS servers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#dns_servers GoogleGkeonpremVmwareAdminCluster#dns_servers}
    */
    readonly dnsServers?: string[];
    /**
    * NTP servers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ntp_servers GoogleGkeonpremVmwareAdminCluster#ntp_servers}
    */
    readonly ntpServers?: string[];
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHostConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigHostConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig | undefined);
    private _dnsSearchDomains?;
    get dnsSearchDomains(): string[];
    set dnsSearchDomains(value: string[]);
    resetDnsSearchDomains(): void;
    get dnsSearchDomainsInput(): string[] | undefined;
    private _dnsServers?;
    get dnsServers(): string[];
    set dnsServers(value: string[]);
    resetDnsServers(): void;
    get dnsServersInput(): string[] | undefined;
    private _ntpServers?;
    get ntpServers(): string[];
    set ntpServers(value: string[]);
    resetNtpServers(): void;
    get ntpServersInput(): string[] | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps {
    /**
    * Hostname of the machine. VM's name will be used if this field is empty.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#hostname GoogleGkeonpremVmwareAdminCluster#hostname}
    */
    readonly hostname?: string;
    /**
    * IP could be an IP address (like 1.2.3.4) or a CIDR (like 1.2.3.0/24).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ip GoogleGkeonpremVmwareAdminCluster#ip}
    */
    readonly ip: string;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIpsToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps | cdktf.IResolvable): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIpsToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps | cdktf.IResolvable): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIpsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps | cdktf.IResolvable | undefined);
    private _hostname?;
    get hostname(): string;
    set hostname(value: string);
    resetHostname(): void;
    get hostnameInput(): string | undefined;
    private _ip?;
    get ip(): string;
    set ip(value: string);
    get ipInput(): string | undefined;
}
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIpsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIpsOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks {
    /**
    * The network gateway used by the VMware Admin Cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#gateway GoogleGkeonpremVmwareAdminCluster#gateway}
    */
    readonly gateway: string;
    /**
    * The netmask used by the VMware Admin Cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#netmask GoogleGkeonpremVmwareAdminCluster#netmask}
    */
    readonly netmask: string;
    /**
    * ips block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ips GoogleGkeonpremVmwareAdminCluster#ips}
    */
    readonly ips: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps[] | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks | cdktf.IResolvable): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks | cdktf.IResolvable): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks | cdktf.IResolvable | undefined);
    private _gateway?;
    get gateway(): string;
    set gateway(value: string);
    get gatewayInput(): string | undefined;
    private _netmask?;
    get netmask(): string;
    set netmask(value: string);
    get netmaskInput(): string | undefined;
    private _ips;
    get ips(): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIpsList;
    putIps(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps[] | cdktf.IResolvable): void;
    get ipsInput(): cdktf.IResolvable | GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksIps[] | undefined;
}
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig {
    /**
    * ip_blocks block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ip_blocks GoogleGkeonpremVmwareAdminCluster#ip_blocks}
    */
    readonly ipBlocks?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks[] | cdktf.IResolvable;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig | undefined);
    private _ipBlocks;
    get ipBlocks(): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocksList;
    putIpBlocks(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks[] | cdktf.IResolvable): void;
    resetIpBlocks(): void;
    get ipBlocksInput(): cdktf.IResolvable | GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigIpBlocks[] | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterNetworkConfig {
    /**
    * All pods in the cluster are assigned an RFC1918 IPv4 address from these ranges.
    * Only a single range is supported. This field cannot be changed after creation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#pod_address_cidr_blocks GoogleGkeonpremVmwareAdminCluster#pod_address_cidr_blocks}
    */
    readonly podAddressCidrBlocks: string[];
    /**
    * All services in the cluster are assigned an RFC1918 IPv4 address
    * from these ranges. Only a single range is supported.. This field
    * cannot be changed after creation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#service_address_cidr_blocks GoogleGkeonpremVmwareAdminCluster#service_address_cidr_blocks}
    */
    readonly serviceAddressCidrBlocks: string[];
    /**
    * vcenter_network specifies vCenter network name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#vcenter_network GoogleGkeonpremVmwareAdminCluster#vcenter_network}
    */
    readonly vcenterNetwork?: string;
    /**
    * dhcp_ip_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#dhcp_ip_config GoogleGkeonpremVmwareAdminCluster#dhcp_ip_config}
    */
    readonly dhcpIpConfig?: GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig;
    /**
    * ha_control_plane_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ha_control_plane_config GoogleGkeonpremVmwareAdminCluster#ha_control_plane_config}
    */
    readonly haControlPlaneConfig?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig;
    /**
    * host_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#host_config GoogleGkeonpremVmwareAdminCluster#host_config}
    */
    readonly hostConfig?: GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig;
    /**
    * static_ip_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#static_ip_config GoogleGkeonpremVmwareAdminCluster#static_ip_config}
    */
    readonly staticIpConfig?: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig;
}
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfig): any;
export declare function googleGkeonpremVmwareAdminClusterNetworkConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterNetworkConfigOutputReference | GoogleGkeonpremVmwareAdminClusterNetworkConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterNetworkConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterNetworkConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterNetworkConfig | undefined);
    private _podAddressCidrBlocks?;
    get podAddressCidrBlocks(): string[];
    set podAddressCidrBlocks(value: string[]);
    get podAddressCidrBlocksInput(): string[] | undefined;
    private _serviceAddressCidrBlocks?;
    get serviceAddressCidrBlocks(): string[];
    set serviceAddressCidrBlocks(value: string[]);
    get serviceAddressCidrBlocksInput(): string[] | undefined;
    private _vcenterNetwork?;
    get vcenterNetwork(): string;
    set vcenterNetwork(value: string);
    resetVcenterNetwork(): void;
    get vcenterNetworkInput(): string | undefined;
    private _dhcpIpConfig;
    get dhcpIpConfig(): GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfigOutputReference;
    putDhcpIpConfig(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig): void;
    resetDhcpIpConfig(): void;
    get dhcpIpConfigInput(): GoogleGkeonpremVmwareAdminClusterNetworkConfigDhcpIpConfig | undefined;
    private _haControlPlaneConfig;
    get haControlPlaneConfig(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfigOutputReference;
    putHaControlPlaneConfig(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig): void;
    resetHaControlPlaneConfig(): void;
    get haControlPlaneConfigInput(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHaControlPlaneConfig | undefined;
    private _hostConfig;
    get hostConfig(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfigOutputReference;
    putHostConfig(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig): void;
    resetHostConfig(): void;
    get hostConfigInput(): GoogleGkeonpremVmwareAdminClusterNetworkConfigHostConfig | undefined;
    private _staticIpConfig;
    get staticIpConfig(): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfigOutputReference;
    putStaticIpConfig(value: GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig): void;
    resetStaticIpConfig(): void;
    get staticIpConfigInput(): GoogleGkeonpremVmwareAdminClusterNetworkConfigStaticIpConfig | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditions {
}
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditionsToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditions): any;
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditionsToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditions): any;
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditions | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditions | undefined);
    get lastTransitionTime(): string;
    get message(): string;
    get reason(): string;
    get state(): string;
    get type(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditionsOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatus {
}
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatus): any;
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatus): any;
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatus | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatus | undefined);
    private _conditions;
    get conditions(): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusConditionsList;
    get errorMessage(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterPlatformConfigBundles {
}
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigBundlesToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundles): any;
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigBundlesToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundles): any;
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundles | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterPlatformConfigBundles | undefined);
    private _status;
    get status(): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesStatusList;
    get version(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditions {
}
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigStatusConditionsToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditions): any;
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigStatusConditionsToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditions): any;
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditions | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditions | undefined);
    get lastTransitionTime(): string;
    get message(): string;
    get reason(): string;
    get state(): string;
    get type(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditionsOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterPlatformConfigStatus {
}
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigStatusToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigStatus): any;
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigStatusToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigStatus): any;
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterPlatformConfigStatus | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterPlatformConfigStatus | undefined);
    private _conditions;
    get conditions(): GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusConditionsList;
    get errorMessage(): string;
}
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusOutputReference;
}
export interface GoogleGkeonpremVmwareAdminClusterPlatformConfig {
    /**
    * The required platform version e.g. 1.13.1.
    * If the current platform version is lower than the target version,
    * the platform version will be updated to the target version.
    * If the target version is not installed in the platform
    * (bundle versions), download the target version bundle.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#required_platform_version GoogleGkeonpremVmwareAdminCluster#required_platform_version}
    */
    readonly requiredPlatformVersion?: string;
}
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigOutputReference | GoogleGkeonpremVmwareAdminClusterPlatformConfig): any;
export declare function googleGkeonpremVmwareAdminClusterPlatformConfigToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterPlatformConfigOutputReference | GoogleGkeonpremVmwareAdminClusterPlatformConfig): any;
export declare class GoogleGkeonpremVmwareAdminClusterPlatformConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterPlatformConfig | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterPlatformConfig | undefined);
    private _bundles;
    get bundles(): GoogleGkeonpremVmwareAdminClusterPlatformConfigBundlesList;
    get platformVersion(): string;
    private _requiredPlatformVersion?;
    get requiredPlatformVersion(): string;
    set requiredPlatformVersion(value: string);
    resetRequiredPlatformVersion(): void;
    get requiredPlatformVersionInput(): string | undefined;
    private _status;
    get status(): GoogleGkeonpremVmwareAdminClusterPlatformConfigStatusList;
}
export interface GoogleGkeonpremVmwareAdminClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#create GoogleGkeonpremVmwareAdminCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#delete GoogleGkeonpremVmwareAdminCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#update GoogleGkeonpremVmwareAdminCluster#update}
    */
    readonly update?: string;
}
export declare function googleGkeonpremVmwareAdminClusterTimeoutsToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterTimeouts | cdktf.IResolvable): any;
export declare function googleGkeonpremVmwareAdminClusterTimeoutsToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterTimeouts | cdktf.IResolvable): any;
export declare class GoogleGkeonpremVmwareAdminClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleGkeonpremVmwareAdminClusterVcenter {
    /**
    * The vCenter IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#address GoogleGkeonpremVmwareAdminCluster#address}
    */
    readonly address?: string;
    /**
    * Contains the vCenter CA certificate public key for SSL verification.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#ca_cert_data GoogleGkeonpremVmwareAdminCluster#ca_cert_data}
    */
    readonly caCertData?: string;
    /**
    * The name of the vCenter cluster for the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#cluster GoogleGkeonpremVmwareAdminCluster#cluster}
    */
    readonly cluster?: string;
    /**
    * The name of the virtual machine disk (VMDK) for the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#data_disk GoogleGkeonpremVmwareAdminCluster#data_disk}
    */
    readonly dataDisk?: string;
    /**
    * The name of the vCenter datacenter for the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#datacenter GoogleGkeonpremVmwareAdminCluster#datacenter}
    */
    readonly datacenter?: string;
    /**
    * The name of the vCenter datastore for the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#datastore GoogleGkeonpremVmwareAdminCluster#datastore}
    */
    readonly datastore?: string;
    /**
    * The name of the vCenter folder for the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#folder GoogleGkeonpremVmwareAdminCluster#folder}
    */
    readonly folder?: string;
    /**
    * The name of the vCenter resource pool for the admin cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#resource_pool GoogleGkeonpremVmwareAdminCluster#resource_pool}
    */
    readonly resourcePool?: string;
    /**
    * The name of the vCenter storage policy for the user cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#storage_policy_name GoogleGkeonpremVmwareAdminCluster#storage_policy_name}
    */
    readonly storagePolicyName?: string;
}
export declare function googleGkeonpremVmwareAdminClusterVcenterToTerraform(struct?: GoogleGkeonpremVmwareAdminClusterVcenterOutputReference | GoogleGkeonpremVmwareAdminClusterVcenter): any;
export declare function googleGkeonpremVmwareAdminClusterVcenterToHclTerraform(struct?: GoogleGkeonpremVmwareAdminClusterVcenterOutputReference | GoogleGkeonpremVmwareAdminClusterVcenter): any;
export declare class GoogleGkeonpremVmwareAdminClusterVcenterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeonpremVmwareAdminClusterVcenter | undefined;
    set internalValue(value: GoogleGkeonpremVmwareAdminClusterVcenter | undefined);
    private _address?;
    get address(): string;
    set address(value: string);
    resetAddress(): void;
    get addressInput(): string | undefined;
    private _caCertData?;
    get caCertData(): string;
    set caCertData(value: string);
    resetCaCertData(): void;
    get caCertDataInput(): string | undefined;
    private _cluster?;
    get cluster(): string;
    set cluster(value: string);
    resetCluster(): void;
    get clusterInput(): string | undefined;
    private _dataDisk?;
    get dataDisk(): string;
    set dataDisk(value: string);
    resetDataDisk(): void;
    get dataDiskInput(): string | undefined;
    private _datacenter?;
    get datacenter(): string;
    set datacenter(value: string);
    resetDatacenter(): void;
    get datacenterInput(): string | undefined;
    private _datastore?;
    get datastore(): string;
    set datastore(value: string);
    resetDatastore(): void;
    get datastoreInput(): string | undefined;
    private _folder?;
    get folder(): string;
    set folder(value: string);
    resetFolder(): void;
    get folderInput(): string | undefined;
    private _resourcePool?;
    get resourcePool(): string;
    set resourcePool(value: string);
    resetResourcePool(): void;
    get resourcePoolInput(): string | undefined;
    private _storagePolicyName?;
    get storagePolicyName(): string;
    set storagePolicyName(value: string);
    resetStoragePolicyName(): void;
    get storagePolicyNameInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster google_gkeonprem_vmware_admin_cluster}
*/
export declare class GoogleGkeonpremVmwareAdminCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gkeonprem_vmware_admin_cluster";
    /**
    * Generates CDKTF code for importing a GoogleGkeonpremVmwareAdminCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleGkeonpremVmwareAdminCluster to import
    * @param importFromId The id of the existing GoogleGkeonpremVmwareAdminCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleGkeonpremVmwareAdminCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_gkeonprem_vmware_admin_cluster google_gkeonprem_vmware_admin_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleGkeonpremVmwareAdminClusterConfig
    */
    constructor(scope: Construct, id: string, config: GoogleGkeonpremVmwareAdminClusterConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _bootstrapClusterMembership?;
    get bootstrapClusterMembership(): string;
    set bootstrapClusterMembership(value: string);
    resetBootstrapClusterMembership(): void;
    get bootstrapClusterMembershipInput(): string | undefined;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    get enableAdvancedCluster(): cdktf.IResolvable;
    get endpoint(): string;
    get etag(): string;
    private _fleet;
    get fleet(): GoogleGkeonpremVmwareAdminClusterFleetList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _imageType?;
    get imageType(): string;
    set imageType(value: string);
    resetImageType(): void;
    get imageTypeInput(): string | undefined;
    get localName(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _onPremVersion?;
    get onPremVersion(): string;
    set onPremVersion(value: string);
    resetOnPremVersion(): void;
    get onPremVersionInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _status;
    get status(): GoogleGkeonpremVmwareAdminClusterStatusList;
    get uid(): string;
    get updateTime(): string;
    private _addonNode;
    get addonNode(): GoogleGkeonpremVmwareAdminClusterAddonNodeOutputReference;
    putAddonNode(value: GoogleGkeonpremVmwareAdminClusterAddonNode): void;
    resetAddonNode(): void;
    get addonNodeInput(): GoogleGkeonpremVmwareAdminClusterAddonNode | undefined;
    private _antiAffinityGroups;
    get antiAffinityGroups(): GoogleGkeonpremVmwareAdminClusterAntiAffinityGroupsOutputReference;
    putAntiAffinityGroups(value: GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups): void;
    resetAntiAffinityGroups(): void;
    get antiAffinityGroupsInput(): GoogleGkeonpremVmwareAdminClusterAntiAffinityGroups | undefined;
    private _authorization;
    get authorization(): GoogleGkeonpremVmwareAdminClusterAuthorizationOutputReference;
    putAuthorization(value: GoogleGkeonpremVmwareAdminClusterAuthorization): void;
    resetAuthorization(): void;
    get authorizationInput(): GoogleGkeonpremVmwareAdminClusterAuthorization | undefined;
    private _autoRepairConfig;
    get autoRepairConfig(): GoogleGkeonpremVmwareAdminClusterAutoRepairConfigOutputReference;
    putAutoRepairConfig(value: GoogleGkeonpremVmwareAdminClusterAutoRepairConfig): void;
    resetAutoRepairConfig(): void;
    get autoRepairConfigInput(): GoogleGkeonpremVmwareAdminClusterAutoRepairConfig | undefined;
    private _controlPlaneNode;
    get controlPlaneNode(): GoogleGkeonpremVmwareAdminClusterControlPlaneNodeOutputReference;
    putControlPlaneNode(value: GoogleGkeonpremVmwareAdminClusterControlPlaneNode): void;
    resetControlPlaneNode(): void;
    get controlPlaneNodeInput(): GoogleGkeonpremVmwareAdminClusterControlPlaneNode | undefined;
    private _loadBalancer;
    get loadBalancer(): GoogleGkeonpremVmwareAdminClusterLoadBalancerOutputReference;
    putLoadBalancer(value: GoogleGkeonpremVmwareAdminClusterLoadBalancer): void;
    resetLoadBalancer(): void;
    get loadBalancerInput(): GoogleGkeonpremVmwareAdminClusterLoadBalancer | undefined;
    private _networkConfig;
    get networkConfig(): GoogleGkeonpremVmwareAdminClusterNetworkConfigOutputReference;
    putNetworkConfig(value: GoogleGkeonpremVmwareAdminClusterNetworkConfig): void;
    get networkConfigInput(): GoogleGkeonpremVmwareAdminClusterNetworkConfig | undefined;
    private _platformConfig;
    get platformConfig(): GoogleGkeonpremVmwareAdminClusterPlatformConfigOutputReference;
    putPlatformConfig(value: GoogleGkeonpremVmwareAdminClusterPlatformConfig): void;
    resetPlatformConfig(): void;
    get platformConfigInput(): GoogleGkeonpremVmwareAdminClusterPlatformConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleGkeonpremVmwareAdminClusterTimeoutsOutputReference;
    putTimeouts(value: GoogleGkeonpremVmwareAdminClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleGkeonpremVmwareAdminClusterTimeouts | undefined;
    private _vcenter;
    get vcenter(): GoogleGkeonpremVmwareAdminClusterVcenterOutputReference;
    putVcenter(value: GoogleGkeonpremVmwareAdminClusterVcenter): void;
    resetVcenter(): void;
    get vcenterInput(): GoogleGkeonpremVmwareAdminClusterVcenter | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
