/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleManagedKafkaConnectClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID to use for the Connect Cluster, which will become the final component of the connect cluster's name. This value is structured like: 'my-connect-cluster-id'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#connect_cluster_id GoogleManagedKafkaConnectCluster#connect_cluster_id}
    */
    readonly connectClusterId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#id GoogleManagedKafkaConnectCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Kafka cluster this Kafka Connect cluster is attached to. Structured like: 'projects/PROJECT_ID/locations/LOCATION/clusters/CLUSTER_ID'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#kafka_cluster GoogleManagedKafkaConnectCluster#kafka_cluster}
    */
    readonly kafkaCluster: string;
    /**
    * List of label KEY=VALUE pairs to add. Keys must start with a lowercase character and contain only hyphens (-), underscores ( ), lowercase characters, and numbers. Values must contain only hyphens (-), underscores ( ), lowercase characters, and numbers.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#labels GoogleManagedKafkaConnectCluster#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * ID of the location of the Kafka Connect resource. See https://cloud.google.com/managed-kafka/docs/locations for a list of supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#location GoogleManagedKafkaConnectCluster#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#project GoogleManagedKafkaConnectCluster#project}
    */
    readonly project?: string;
    /**
    * capacity_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#capacity_config GoogleManagedKafkaConnectCluster#capacity_config}
    */
    readonly capacityConfig: GoogleManagedKafkaConnectClusterCapacityConfig;
    /**
    * gcp_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#gcp_config GoogleManagedKafkaConnectCluster#gcp_config}
    */
    readonly gcpConfig: GoogleManagedKafkaConnectClusterGcpConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#timeouts GoogleManagedKafkaConnectCluster#timeouts}
    */
    readonly timeouts?: GoogleManagedKafkaConnectClusterTimeouts;
}
export interface GoogleManagedKafkaConnectClusterCapacityConfig {
    /**
    * The memory to provision for the cluster in bytes. The CPU:memory ratio (vCPU:GiB) must be between 1:1 and 1:8. Minimum: 3221225472 (3 GiB).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#memory_bytes GoogleManagedKafkaConnectCluster#memory_bytes}
    */
    readonly memoryBytes: string;
    /**
    * The number of vCPUs to provision for the cluster. The minimum is 3.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#vcpu_count GoogleManagedKafkaConnectCluster#vcpu_count}
    */
    readonly vcpuCount: string;
}
export declare function googleManagedKafkaConnectClusterCapacityConfigToTerraform(struct?: GoogleManagedKafkaConnectClusterCapacityConfigOutputReference | GoogleManagedKafkaConnectClusterCapacityConfig): any;
export declare function googleManagedKafkaConnectClusterCapacityConfigToHclTerraform(struct?: GoogleManagedKafkaConnectClusterCapacityConfigOutputReference | GoogleManagedKafkaConnectClusterCapacityConfig): any;
export declare class GoogleManagedKafkaConnectClusterCapacityConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaConnectClusterCapacityConfig | undefined;
    set internalValue(value: GoogleManagedKafkaConnectClusterCapacityConfig | undefined);
    private _memoryBytes?;
    get memoryBytes(): string;
    set memoryBytes(value: string);
    get memoryBytesInput(): string | undefined;
    private _vcpuCount?;
    get vcpuCount(): string;
    set vcpuCount(value: string);
    get vcpuCountInput(): string | undefined;
}
export interface GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs {
    /**
    * Additional subnets may be specified. They may be in another region, but must be in the same VPC network. The Connect workers can communicate with network endpoints in either the primary or additional subnets.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#additional_subnets GoogleManagedKafkaConnectCluster#additional_subnets}
    */
    readonly additionalSubnets?: string[];
    /**
    * Additional DNS domain names from the subnet's network to be made visible to the Connect Cluster. When using MirrorMaker2, it's necessary to add the bootstrap address's dns domain name of the target cluster to make it visible to the connector. For example: my-kafka-cluster.us-central1.managedkafka.my-project.cloud.goog
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#dns_domain_names GoogleManagedKafkaConnectCluster#dns_domain_names}
    */
    readonly dnsDomainNames?: string[];
    /**
    * VPC subnet to make available to the Kafka Connect cluster. Structured like: projects/{project}/regions/{region}/subnetworks/{subnet_id}. It is used to create a Private Service Connect (PSC) interface for the Kafka Connect workers. It must be located in the same region as the Kafka Connect cluster. The CIDR range of the subnet must be within the IPv4 address ranges for private networks, as specified in RFC 1918. The primary subnet CIDR range must have a minimum size of /22 (1024 addresses).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#primary_subnet GoogleManagedKafkaConnectCluster#primary_subnet}
    */
    readonly primarySubnet: string;
}
export declare function googleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigsToTerraform(struct?: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable): any;
export declare function googleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigsToHclTerraform(struct?: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable): any;
export declare class GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable | undefined);
    private _additionalSubnets?;
    get additionalSubnets(): string[];
    set additionalSubnets(value: string[]);
    resetAdditionalSubnets(): void;
    get additionalSubnetsInput(): string[] | undefined;
    private _dnsDomainNames?;
    get dnsDomainNames(): string[];
    set dnsDomainNames(value: string[]);
    resetDnsDomainNames(): void;
    get dnsDomainNamesInput(): string[] | undefined;
    private _primarySubnet?;
    get primarySubnet(): string;
    set primarySubnet(value: string);
    get primarySubnetInput(): string | undefined;
}
export declare class GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigsOutputReference;
}
export interface GoogleManagedKafkaConnectClusterGcpConfigAccessConfig {
    /**
    * network_configs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#network_configs GoogleManagedKafkaConnectCluster#network_configs}
    */
    readonly networkConfigs: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs[] | cdktf.IResolvable;
}
export declare function googleManagedKafkaConnectClusterGcpConfigAccessConfigToTerraform(struct?: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigOutputReference | GoogleManagedKafkaConnectClusterGcpConfigAccessConfig): any;
export declare function googleManagedKafkaConnectClusterGcpConfigAccessConfigToHclTerraform(struct?: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigOutputReference | GoogleManagedKafkaConnectClusterGcpConfigAccessConfig): any;
export declare class GoogleManagedKafkaConnectClusterGcpConfigAccessConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaConnectClusterGcpConfigAccessConfig | undefined;
    set internalValue(value: GoogleManagedKafkaConnectClusterGcpConfigAccessConfig | undefined);
    private _networkConfigs;
    get networkConfigs(): GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigsList;
    putNetworkConfigs(value: GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs[] | cdktf.IResolvable): void;
    get networkConfigsInput(): cdktf.IResolvable | GoogleManagedKafkaConnectClusterGcpConfigAccessConfigNetworkConfigs[] | undefined;
}
export interface GoogleManagedKafkaConnectClusterGcpConfig {
    /**
    * access_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#access_config GoogleManagedKafkaConnectCluster#access_config}
    */
    readonly accessConfig: GoogleManagedKafkaConnectClusterGcpConfigAccessConfig;
}
export declare function googleManagedKafkaConnectClusterGcpConfigToTerraform(struct?: GoogleManagedKafkaConnectClusterGcpConfigOutputReference | GoogleManagedKafkaConnectClusterGcpConfig): any;
export declare function googleManagedKafkaConnectClusterGcpConfigToHclTerraform(struct?: GoogleManagedKafkaConnectClusterGcpConfigOutputReference | GoogleManagedKafkaConnectClusterGcpConfig): any;
export declare class GoogleManagedKafkaConnectClusterGcpConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaConnectClusterGcpConfig | undefined;
    set internalValue(value: GoogleManagedKafkaConnectClusterGcpConfig | undefined);
    private _accessConfig;
    get accessConfig(): GoogleManagedKafkaConnectClusterGcpConfigAccessConfigOutputReference;
    putAccessConfig(value: GoogleManagedKafkaConnectClusterGcpConfigAccessConfig): void;
    get accessConfigInput(): GoogleManagedKafkaConnectClusterGcpConfigAccessConfig | undefined;
}
export interface GoogleManagedKafkaConnectClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#create GoogleManagedKafkaConnectCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#delete GoogleManagedKafkaConnectCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#update GoogleManagedKafkaConnectCluster#update}
    */
    readonly update?: string;
}
export declare function googleManagedKafkaConnectClusterTimeoutsToTerraform(struct?: GoogleManagedKafkaConnectClusterTimeouts | cdktf.IResolvable): any;
export declare function googleManagedKafkaConnectClusterTimeoutsToHclTerraform(struct?: GoogleManagedKafkaConnectClusterTimeouts | cdktf.IResolvable): any;
export declare class GoogleManagedKafkaConnectClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaConnectClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleManagedKafkaConnectClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster google_managed_kafka_connect_cluster}
*/
export declare class GoogleManagedKafkaConnectCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_managed_kafka_connect_cluster";
    /**
    * Generates CDKTF code for importing a GoogleManagedKafkaConnectCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleManagedKafkaConnectCluster to import
    * @param importFromId The id of the existing GoogleManagedKafkaConnectCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleManagedKafkaConnectCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_managed_kafka_connect_cluster google_managed_kafka_connect_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleManagedKafkaConnectClusterConfig
    */
    constructor(scope: Construct, id: string, config: GoogleManagedKafkaConnectClusterConfig);
    private _connectClusterId?;
    get connectClusterId(): string;
    set connectClusterId(value: string);
    get connectClusterIdInput(): string | undefined;
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _kafkaCluster?;
    get kafkaCluster(): string;
    set kafkaCluster(value: string);
    get kafkaClusterInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _capacityConfig;
    get capacityConfig(): GoogleManagedKafkaConnectClusterCapacityConfigOutputReference;
    putCapacityConfig(value: GoogleManagedKafkaConnectClusterCapacityConfig): void;
    get capacityConfigInput(): GoogleManagedKafkaConnectClusterCapacityConfig | undefined;
    private _gcpConfig;
    get gcpConfig(): GoogleManagedKafkaConnectClusterGcpConfigOutputReference;
    putGcpConfig(value: GoogleManagedKafkaConnectClusterGcpConfig): void;
    get gcpConfigInput(): GoogleManagedKafkaConnectClusterGcpConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleManagedKafkaConnectClusterTimeoutsOutputReference;
    putTimeouts(value: GoogleManagedKafkaConnectClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleManagedKafkaConnectClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
