/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleMemorystoreInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Immutable. Authorization mode of the instance. Possible values:
    *  AUTH_DISABLED
    * IAM_AUTH
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#authorization_mode GoogleMemorystoreInstance#authorization_mode}
    */
    readonly authorizationMode?: string;
    /**
    * Optional. If set to true deletion of the instance will fail.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#deletion_protection_enabled GoogleMemorystoreInstance#deletion_protection_enabled}
    */
    readonly deletionProtectionEnabled?: boolean | cdktf.IResolvable;
    /**
    * Optional. User-provided engine configurations for the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#engine_configs GoogleMemorystoreInstance#engine_configs}
    */
    readonly engineConfigs?: {
        [key: string]: string;
    };
    /**
    * Optional. Engine version of the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#engine_version GoogleMemorystoreInstance#engine_version}
    */
    readonly engineVersion?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#id GoogleMemorystoreInstance#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Required. The ID to use for the instance, which will become the final component of
    * the instance's resource name.
    *
    * This value is subject to the following restrictions:
    *
    * * Must be 4-63 characters in length
    * * Must begin with a letter or digit
    * * Must contain only lowercase letters, digits, and hyphens
    * * Must not end with a hyphen
    * * Must be unique within a location
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#instance_id GoogleMemorystoreInstance#instance_id}
    */
    readonly instanceId: string;
    /**
    * Optional. Labels to represent user-provided metadata.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#labels GoogleMemorystoreInstance#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122. See documentation for resource type 'memorystore.googleapis.com/CertificateAuthority'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#location GoogleMemorystoreInstance#location}
    */
    readonly location: string;
    /**
    * Optional. cluster or cluster-disabled.
    *  Possible values:
    *  CLUSTER
    *  CLUSTER_DISABLED Possible values: ["CLUSTER", "CLUSTER_DISABLED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#mode GoogleMemorystoreInstance#mode}
    */
    readonly mode?: string;
    /**
    * Optional. Machine type for individual nodes of the instance.
    *  Possible values:
    *  SHARED_CORE_NANO
    * HIGHMEM_MEDIUM
    * HIGHMEM_XLARGE
    * STANDARD_SMALL
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#node_type GoogleMemorystoreInstance#node_type}
    */
    readonly nodeType?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#project GoogleMemorystoreInstance#project}
    */
    readonly project?: string;
    /**
    * Optional. Number of replica nodes per shard. If omitted the default is 0 replicas.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#replica_count GoogleMemorystoreInstance#replica_count}
    */
    readonly replicaCount?: number;
    /**
    * Required. Number of shards for the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#shard_count GoogleMemorystoreInstance#shard_count}
    */
    readonly shardCount: number;
    /**
    * Optional. Immutable. In-transit encryption mode of the instance.
    *  Possible values:
    *  TRANSIT_ENCRYPTION_DISABLED
    * SERVER_AUTHENTICATION
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#transit_encryption_mode GoogleMemorystoreInstance#transit_encryption_mode}
    */
    readonly transitEncryptionMode?: string;
    /**
    * automated_backup_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#automated_backup_config GoogleMemorystoreInstance#automated_backup_config}
    */
    readonly automatedBackupConfig?: GoogleMemorystoreInstanceAutomatedBackupConfig;
    /**
    * cross_instance_replication_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#cross_instance_replication_config GoogleMemorystoreInstance#cross_instance_replication_config}
    */
    readonly crossInstanceReplicationConfig?: GoogleMemorystoreInstanceCrossInstanceReplicationConfig;
    /**
    * desired_psc_auto_connections block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#desired_psc_auto_connections GoogleMemorystoreInstance#desired_psc_auto_connections}
    */
    readonly desiredPscAutoConnections?: GoogleMemorystoreInstanceDesiredPscAutoConnections[] | cdktf.IResolvable;
    /**
    * gcs_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#gcs_source GoogleMemorystoreInstance#gcs_source}
    */
    readonly gcsSource?: GoogleMemorystoreInstanceGcsSource;
    /**
    * maintenance_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#maintenance_policy GoogleMemorystoreInstance#maintenance_policy}
    */
    readonly maintenancePolicy?: GoogleMemorystoreInstanceMaintenancePolicy;
    /**
    * managed_backup_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#managed_backup_source GoogleMemorystoreInstance#managed_backup_source}
    */
    readonly managedBackupSource?: GoogleMemorystoreInstanceManagedBackupSource;
    /**
    * persistence_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#persistence_config GoogleMemorystoreInstance#persistence_config}
    */
    readonly persistenceConfig?: GoogleMemorystoreInstancePersistenceConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#timeouts GoogleMemorystoreInstance#timeouts}
    */
    readonly timeouts?: GoogleMemorystoreInstanceTimeouts;
    /**
    * zone_distribution_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#zone_distribution_config GoogleMemorystoreInstance#zone_distribution_config}
    */
    readonly zoneDistributionConfig?: GoogleMemorystoreInstanceZoneDistributionConfig;
}
export interface GoogleMemorystoreInstanceDiscoveryEndpoints {
}
export declare function googleMemorystoreInstanceDiscoveryEndpointsToTerraform(struct?: GoogleMemorystoreInstanceDiscoveryEndpoints): any;
export declare function googleMemorystoreInstanceDiscoveryEndpointsToHclTerraform(struct?: GoogleMemorystoreInstanceDiscoveryEndpoints): any;
export declare class GoogleMemorystoreInstanceDiscoveryEndpointsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceDiscoveryEndpoints | undefined;
    set internalValue(value: GoogleMemorystoreInstanceDiscoveryEndpoints | undefined);
    get address(): string;
    get network(): string;
    get port(): number;
}
export declare class GoogleMemorystoreInstanceDiscoveryEndpointsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceDiscoveryEndpointsOutputReference;
}
export interface GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnection {
}
export declare function googleMemorystoreInstanceEndpointsConnectionsPscAutoConnectionToTerraform(struct?: GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnection): any;
export declare function googleMemorystoreInstanceEndpointsConnectionsPscAutoConnectionToHclTerraform(struct?: GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnection): any;
export declare class GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnection | undefined;
    set internalValue(value: GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnection | undefined);
    get connectionType(): string;
    get forwardingRule(): string;
    get ipAddress(): string;
    get network(): string;
    get port(): number;
    get projectId(): string;
    get pscConnectionId(): string;
    get serviceAttachment(): string;
}
export declare class GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnectionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnectionOutputReference;
}
export interface GoogleMemorystoreInstanceEndpointsConnections {
}
export declare function googleMemorystoreInstanceEndpointsConnectionsToTerraform(struct?: GoogleMemorystoreInstanceEndpointsConnections): any;
export declare function googleMemorystoreInstanceEndpointsConnectionsToHclTerraform(struct?: GoogleMemorystoreInstanceEndpointsConnections): any;
export declare class GoogleMemorystoreInstanceEndpointsConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceEndpointsConnections | undefined;
    set internalValue(value: GoogleMemorystoreInstanceEndpointsConnections | undefined);
    private _pscAutoConnection;
    get pscAutoConnection(): GoogleMemorystoreInstanceEndpointsConnectionsPscAutoConnectionList;
}
export declare class GoogleMemorystoreInstanceEndpointsConnectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceEndpointsConnectionsOutputReference;
}
export interface GoogleMemorystoreInstanceEndpoints {
}
export declare function googleMemorystoreInstanceEndpointsToTerraform(struct?: GoogleMemorystoreInstanceEndpoints): any;
export declare function googleMemorystoreInstanceEndpointsToHclTerraform(struct?: GoogleMemorystoreInstanceEndpoints): any;
export declare class GoogleMemorystoreInstanceEndpointsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceEndpoints | undefined;
    set internalValue(value: GoogleMemorystoreInstanceEndpoints | undefined);
    private _connections;
    get connections(): GoogleMemorystoreInstanceEndpointsConnectionsList;
}
export declare class GoogleMemorystoreInstanceEndpointsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceEndpointsOutputReference;
}
export interface GoogleMemorystoreInstanceMaintenanceSchedule {
}
export declare function googleMemorystoreInstanceMaintenanceScheduleToTerraform(struct?: GoogleMemorystoreInstanceMaintenanceSchedule): any;
export declare function googleMemorystoreInstanceMaintenanceScheduleToHclTerraform(struct?: GoogleMemorystoreInstanceMaintenanceSchedule): any;
export declare class GoogleMemorystoreInstanceMaintenanceScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceMaintenanceSchedule | undefined;
    set internalValue(value: GoogleMemorystoreInstanceMaintenanceSchedule | undefined);
    get endTime(): string;
    get scheduleDeadlineTime(): string;
    get startTime(): string;
}
export declare class GoogleMemorystoreInstanceMaintenanceScheduleList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceMaintenanceScheduleOutputReference;
}
export interface GoogleMemorystoreInstanceNodeConfig {
}
export declare function googleMemorystoreInstanceNodeConfigToTerraform(struct?: GoogleMemorystoreInstanceNodeConfig): any;
export declare function googleMemorystoreInstanceNodeConfigToHclTerraform(struct?: GoogleMemorystoreInstanceNodeConfig): any;
export declare class GoogleMemorystoreInstanceNodeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceNodeConfig | undefined;
    set internalValue(value: GoogleMemorystoreInstanceNodeConfig | undefined);
    get sizeGb(): number;
}
export declare class GoogleMemorystoreInstanceNodeConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceNodeConfigOutputReference;
}
export interface GoogleMemorystoreInstancePscAttachmentDetails {
}
export declare function googleMemorystoreInstancePscAttachmentDetailsToTerraform(struct?: GoogleMemorystoreInstancePscAttachmentDetails): any;
export declare function googleMemorystoreInstancePscAttachmentDetailsToHclTerraform(struct?: GoogleMemorystoreInstancePscAttachmentDetails): any;
export declare class GoogleMemorystoreInstancePscAttachmentDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstancePscAttachmentDetails | undefined;
    set internalValue(value: GoogleMemorystoreInstancePscAttachmentDetails | undefined);
    get connectionType(): string;
    get serviceAttachment(): string;
}
export declare class GoogleMemorystoreInstancePscAttachmentDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstancePscAttachmentDetailsOutputReference;
}
export interface GoogleMemorystoreInstancePscAutoConnections {
}
export declare function googleMemorystoreInstancePscAutoConnectionsToTerraform(struct?: GoogleMemorystoreInstancePscAutoConnections): any;
export declare function googleMemorystoreInstancePscAutoConnectionsToHclTerraform(struct?: GoogleMemorystoreInstancePscAutoConnections): any;
export declare class GoogleMemorystoreInstancePscAutoConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstancePscAutoConnections | undefined;
    set internalValue(value: GoogleMemorystoreInstancePscAutoConnections | undefined);
    get connectionType(): string;
    get forwardingRule(): string;
    get ipAddress(): string;
    get network(): string;
    get port(): number;
    get projectId(): string;
    get pscConnectionId(): string;
    get pscConnectionStatus(): string;
    get serviceAttachment(): string;
}
export declare class GoogleMemorystoreInstancePscAutoConnectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstancePscAutoConnectionsOutputReference;
}
export interface GoogleMemorystoreInstanceStateInfoUpdateInfo {
}
export declare function googleMemorystoreInstanceStateInfoUpdateInfoToTerraform(struct?: GoogleMemorystoreInstanceStateInfoUpdateInfo): any;
export declare function googleMemorystoreInstanceStateInfoUpdateInfoToHclTerraform(struct?: GoogleMemorystoreInstanceStateInfoUpdateInfo): any;
export declare class GoogleMemorystoreInstanceStateInfoUpdateInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceStateInfoUpdateInfo | undefined;
    set internalValue(value: GoogleMemorystoreInstanceStateInfoUpdateInfo | undefined);
    get targetEngineVersion(): string;
    get targetNodeType(): string;
    get targetReplicaCount(): number;
    get targetShardCount(): number;
}
export declare class GoogleMemorystoreInstanceStateInfoUpdateInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceStateInfoUpdateInfoOutputReference;
}
export interface GoogleMemorystoreInstanceStateInfo {
}
export declare function googleMemorystoreInstanceStateInfoToTerraform(struct?: GoogleMemorystoreInstanceStateInfo): any;
export declare function googleMemorystoreInstanceStateInfoToHclTerraform(struct?: GoogleMemorystoreInstanceStateInfo): any;
export declare class GoogleMemorystoreInstanceStateInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceStateInfo | undefined;
    set internalValue(value: GoogleMemorystoreInstanceStateInfo | undefined);
    private _updateInfo;
    get updateInfo(): GoogleMemorystoreInstanceStateInfoUpdateInfoList;
}
export declare class GoogleMemorystoreInstanceStateInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceStateInfoOutputReference;
}
export interface GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime {
    /**
    * Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23.
    * An API may choose to allow the value "24:00:00" for scenarios like business closing time.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#hours GoogleMemorystoreInstance#hours}
    */
    readonly hours: number;
}
export declare function googleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTimeToTerraform(struct?: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference | GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime): any;
export declare function googleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTimeToHclTerraform(struct?: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference | GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime): any;
export declare class GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime | undefined;
    set internalValue(value: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime | undefined);
    private _hours?;
    get hours(): number;
    set hours(value: number);
    get hoursInput(): number | undefined;
}
export interface GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule {
    /**
    * start_time block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#start_time GoogleMemorystoreInstance#start_time}
    */
    readonly startTime: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime;
}
export declare function googleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleToTerraform(struct?: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleOutputReference | GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule): any;
export declare function googleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleToHclTerraform(struct?: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleOutputReference | GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule): any;
export declare class GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule | undefined;
    set internalValue(value: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule | undefined);
    private _startTime;
    get startTime(): GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTimeOutputReference;
    putStartTime(value: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime): void;
    get startTimeInput(): GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleStartTime | undefined;
}
export interface GoogleMemorystoreInstanceAutomatedBackupConfig {
    /**
    * How long to keep automated backups before the backups are deleted.
    * The value should be between 1 day and 365 days. If not specified, the default value is 35 days.
    * A duration in seconds with up to nine fractional digits, ending with 's'. Example: "3.5s". The default_value is "3024000s"
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#retention GoogleMemorystoreInstance#retention}
    */
    readonly retention: string;
    /**
    * fixed_frequency_schedule block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#fixed_frequency_schedule GoogleMemorystoreInstance#fixed_frequency_schedule}
    */
    readonly fixedFrequencySchedule: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule;
}
export declare function googleMemorystoreInstanceAutomatedBackupConfigToTerraform(struct?: GoogleMemorystoreInstanceAutomatedBackupConfigOutputReference | GoogleMemorystoreInstanceAutomatedBackupConfig): any;
export declare function googleMemorystoreInstanceAutomatedBackupConfigToHclTerraform(struct?: GoogleMemorystoreInstanceAutomatedBackupConfigOutputReference | GoogleMemorystoreInstanceAutomatedBackupConfig): any;
export declare class GoogleMemorystoreInstanceAutomatedBackupConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceAutomatedBackupConfig | undefined;
    set internalValue(value: GoogleMemorystoreInstanceAutomatedBackupConfig | undefined);
    private _retention?;
    get retention(): string;
    set retention(value: string);
    get retentionInput(): string | undefined;
    private _fixedFrequencySchedule;
    get fixedFrequencySchedule(): GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencyScheduleOutputReference;
    putFixedFrequencySchedule(value: GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule): void;
    get fixedFrequencyScheduleInput(): GoogleMemorystoreInstanceAutomatedBackupConfigFixedFrequencySchedule | undefined;
}
export interface GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstance {
}
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstanceToTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstance): any;
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstanceToHclTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstance): any;
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstanceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstance | undefined;
    set internalValue(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstance | undefined);
    get instance(): string;
    get uid(): string;
}
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstanceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstanceOutputReference;
}
export interface GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstance {
}
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstanceToTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstance): any;
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstanceToHclTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstance): any;
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstanceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstance | undefined;
    set internalValue(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstance | undefined);
    get instance(): string;
    get uid(): string;
}
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstanceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstanceOutputReference;
}
export interface GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembership {
}
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigMembershipToTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembership): any;
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigMembershipToHclTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembership): any;
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembership | undefined;
    set internalValue(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembership | undefined);
    private _primaryInstance;
    get primaryInstance(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipPrimaryInstanceList;
    private _secondaryInstance;
    get secondaryInstance(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipSecondaryInstanceList;
}
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipOutputReference;
}
export interface GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance {
    /**
    * The full resource path of the primary instance in the format: projects/{project}/locations/{region}/instances/{instance-id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#instance GoogleMemorystoreInstance#instance}
    */
    readonly instance?: string;
}
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstanceToTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstanceOutputReference | GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance): any;
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstanceToHclTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstanceOutputReference | GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance): any;
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstanceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance | undefined;
    set internalValue(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance | undefined);
    private _instance?;
    get instance(): string;
    set instance(value: string);
    resetInstance(): void;
    get instanceInput(): string | undefined;
    get uid(): string;
}
export interface GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances {
    /**
    * The full resource path of the Nth instance in the format: projects/{project}/locations/{region}/instance/{instance-id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#instance GoogleMemorystoreInstance#instance}
    */
    readonly instance?: string;
}
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstancesToTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances | cdktf.IResolvable): any;
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstancesToHclTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances | cdktf.IResolvable): any;
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstancesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances | cdktf.IResolvable | undefined);
    private _instance?;
    get instance(): string;
    set instance(value: string);
    resetInstance(): void;
    get instanceInput(): string | undefined;
    get uid(): string;
}
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstancesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstancesOutputReference;
}
export interface GoogleMemorystoreInstanceCrossInstanceReplicationConfig {
    /**
    * The instance role supports the following values:
    * 1. 'INSTANCE_ROLE_UNSPECIFIED': This is an independent instance that has never participated in cross instance replication. It allows both reads and writes.
    * 2. 'NONE': This is an independent instance that previously participated in cross instance replication(either as a 'PRIMARY' or 'SECONDARY' cluster). It allows both reads and writes.
    * 3. 'PRIMARY': This instance serves as the replication source for secondary instance that are replicating from it. Any data written to it is automatically replicated to its secondary clusters. It allows both reads and writes.
    * 4. 'SECONDARY': This instance replicates data from the primary instance. It allows only reads. Possible values: ["INSTANCE_ROLE_UNSPECIFIED", "NONE", "PRIMARY", "SECONDARY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#instance_role GoogleMemorystoreInstance#instance_role}
    */
    readonly instanceRole?: string;
    /**
    * primary_instance block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#primary_instance GoogleMemorystoreInstance#primary_instance}
    */
    readonly primaryInstance?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance;
    /**
    * secondary_instances block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#secondary_instances GoogleMemorystoreInstance#secondary_instances}
    */
    readonly secondaryInstances?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances[] | cdktf.IResolvable;
}
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigToTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigOutputReference | GoogleMemorystoreInstanceCrossInstanceReplicationConfig): any;
export declare function googleMemorystoreInstanceCrossInstanceReplicationConfigToHclTerraform(struct?: GoogleMemorystoreInstanceCrossInstanceReplicationConfigOutputReference | GoogleMemorystoreInstanceCrossInstanceReplicationConfig): any;
export declare class GoogleMemorystoreInstanceCrossInstanceReplicationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceCrossInstanceReplicationConfig | undefined;
    set internalValue(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfig | undefined);
    private _instanceRole?;
    get instanceRole(): string;
    set instanceRole(value: string);
    resetInstanceRole(): void;
    get instanceRoleInput(): string | undefined;
    private _membership;
    get membership(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigMembershipList;
    get updateTime(): string;
    private _primaryInstance;
    get primaryInstance(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstanceOutputReference;
    putPrimaryInstance(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance): void;
    resetPrimaryInstance(): void;
    get primaryInstanceInput(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigPrimaryInstance | undefined;
    private _secondaryInstances;
    get secondaryInstances(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstancesList;
    putSecondaryInstances(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances[] | cdktf.IResolvable): void;
    resetSecondaryInstances(): void;
    get secondaryInstancesInput(): cdktf.IResolvable | GoogleMemorystoreInstanceCrossInstanceReplicationConfigSecondaryInstances[] | undefined;
}
export interface GoogleMemorystoreInstanceDesiredPscAutoConnections {
    /**
    * Required. The consumer network where the IP address resides, in the form of
    * projects/{project_id}/global/networks/{network_id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#network GoogleMemorystoreInstance#network}
    */
    readonly network: string;
    /**
    * Required. The consumer project_id where the forwarding rule is created from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#project_id GoogleMemorystoreInstance#project_id}
    */
    readonly projectId: string;
}
export declare function googleMemorystoreInstanceDesiredPscAutoConnectionsToTerraform(struct?: GoogleMemorystoreInstanceDesiredPscAutoConnections | cdktf.IResolvable): any;
export declare function googleMemorystoreInstanceDesiredPscAutoConnectionsToHclTerraform(struct?: GoogleMemorystoreInstanceDesiredPscAutoConnections | cdktf.IResolvable): any;
export declare class GoogleMemorystoreInstanceDesiredPscAutoConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceDesiredPscAutoConnections | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleMemorystoreInstanceDesiredPscAutoConnections | cdktf.IResolvable | undefined);
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
}
export declare class GoogleMemorystoreInstanceDesiredPscAutoConnectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleMemorystoreInstanceDesiredPscAutoConnections[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceDesiredPscAutoConnectionsOutputReference;
}
export interface GoogleMemorystoreInstanceGcsSource {
    /**
    * URIs of the GCS objects to import.
    * Example: gs://bucket1/object1, gs//bucket2/folder2/object2
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#uris GoogleMemorystoreInstance#uris}
    */
    readonly uris: string[];
}
export declare function googleMemorystoreInstanceGcsSourceToTerraform(struct?: GoogleMemorystoreInstanceGcsSourceOutputReference | GoogleMemorystoreInstanceGcsSource): any;
export declare function googleMemorystoreInstanceGcsSourceToHclTerraform(struct?: GoogleMemorystoreInstanceGcsSourceOutputReference | GoogleMemorystoreInstanceGcsSource): any;
export declare class GoogleMemorystoreInstanceGcsSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceGcsSource | undefined;
    set internalValue(value: GoogleMemorystoreInstanceGcsSource | undefined);
    private _uris?;
    get uris(): string[];
    set uris(value: string[]);
    get urisInput(): string[] | undefined;
}
export interface GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime {
    /**
    * Hours of day in 24 hour format. Should be from 0 to 23.
    * An API may choose to allow the value "24:00:00" for scenarios like business closing time.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#hours GoogleMemorystoreInstance#hours}
    */
    readonly hours?: number;
    /**
    * Minutes of hour of day. Must be from 0 to 59.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#minutes GoogleMemorystoreInstance#minutes}
    */
    readonly minutes?: number;
    /**
    * Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#nanos GoogleMemorystoreInstance#nanos}
    */
    readonly nanos?: number;
    /**
    * Seconds of minutes of the time. Must normally be from 0 to 59.
    * An API may allow the value 60 if it allows leap-seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#seconds GoogleMemorystoreInstance#seconds}
    */
    readonly seconds?: number;
}
export declare function googleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeToTerraform(struct?: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference | GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime): any;
export declare function googleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeToHclTerraform(struct?: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference | GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime): any;
export declare class GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime | undefined;
    set internalValue(value: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime | undefined);
    private _hours?;
    get hours(): number;
    set hours(value: number);
    resetHours(): void;
    get hoursInput(): number | undefined;
    private _minutes?;
    get minutes(): number;
    set minutes(value: number);
    resetMinutes(): void;
    get minutesInput(): number | undefined;
    private _nanos?;
    get nanos(): number;
    set nanos(value: number);
    resetNanos(): void;
    get nanosInput(): number | undefined;
    private _seconds?;
    get seconds(): number;
    set seconds(value: number);
    resetSeconds(): void;
    get secondsInput(): number | undefined;
}
export interface GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow {
    /**
    * The day of week that maintenance updates occur.
    *
    * - DAY_OF_WEEK_UNSPECIFIED: The day of the week is unspecified.
    * - MONDAY: Monday
    * - TUESDAY: Tuesday
    * - WEDNESDAY: Wednesday
    * - THURSDAY: Thursday
    * - FRIDAY: Friday
    * - SATURDAY: Saturday
    * - SUNDAY: Sunday Possible values: ["DAY_OF_WEEK_UNSPECIFIED", "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#day GoogleMemorystoreInstance#day}
    */
    readonly day: string;
    /**
    * start_time block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#start_time GoogleMemorystoreInstance#start_time}
    */
    readonly startTime: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime;
}
export declare function googleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowToTerraform(struct?: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable): any;
export declare function googleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowToHclTerraform(struct?: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable): any;
export declare class GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow | cdktf.IResolvable | undefined);
    private _day?;
    get day(): string;
    set day(value: string);
    get dayInput(): string | undefined;
    get duration(): string;
    private _startTime;
    get startTime(): GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference;
    putStartTime(value: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime): void;
    get startTimeInput(): GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime | undefined;
}
export declare class GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference;
}
export interface GoogleMemorystoreInstanceMaintenancePolicy {
    /**
    * weekly_maintenance_window block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#weekly_maintenance_window GoogleMemorystoreInstance#weekly_maintenance_window}
    */
    readonly weeklyMaintenanceWindow?: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow[] | cdktf.IResolvable;
}
export declare function googleMemorystoreInstanceMaintenancePolicyToTerraform(struct?: GoogleMemorystoreInstanceMaintenancePolicyOutputReference | GoogleMemorystoreInstanceMaintenancePolicy): any;
export declare function googleMemorystoreInstanceMaintenancePolicyToHclTerraform(struct?: GoogleMemorystoreInstanceMaintenancePolicyOutputReference | GoogleMemorystoreInstanceMaintenancePolicy): any;
export declare class GoogleMemorystoreInstanceMaintenancePolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceMaintenancePolicy | undefined;
    set internalValue(value: GoogleMemorystoreInstanceMaintenancePolicy | undefined);
    get createTime(): string;
    get updateTime(): string;
    private _weeklyMaintenanceWindow;
    get weeklyMaintenanceWindow(): GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindowList;
    putWeeklyMaintenanceWindow(value: GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow[] | cdktf.IResolvable): void;
    resetWeeklyMaintenanceWindow(): void;
    get weeklyMaintenanceWindowInput(): cdktf.IResolvable | GoogleMemorystoreInstanceMaintenancePolicyWeeklyMaintenanceWindow[] | undefined;
}
export interface GoogleMemorystoreInstanceManagedBackupSource {
    /**
    * Example: //memorystore.googleapis.com/projects/{project}/locations/{location}/backups/{backupId}. In this case, it assumes the backup is under memorystore.googleapis.com.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#backup GoogleMemorystoreInstance#backup}
    */
    readonly backup: string;
}
export declare function googleMemorystoreInstanceManagedBackupSourceToTerraform(struct?: GoogleMemorystoreInstanceManagedBackupSourceOutputReference | GoogleMemorystoreInstanceManagedBackupSource): any;
export declare function googleMemorystoreInstanceManagedBackupSourceToHclTerraform(struct?: GoogleMemorystoreInstanceManagedBackupSourceOutputReference | GoogleMemorystoreInstanceManagedBackupSource): any;
export declare class GoogleMemorystoreInstanceManagedBackupSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceManagedBackupSource | undefined;
    set internalValue(value: GoogleMemorystoreInstanceManagedBackupSource | undefined);
    private _backup?;
    get backup(): string;
    set backup(value: string);
    get backupInput(): string | undefined;
}
export interface GoogleMemorystoreInstancePersistenceConfigAofConfig {
    /**
    * Optional. The fsync mode.
    *  Possible values:
    *  NEVER
    * EVERY_SEC
    * ALWAYS
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#append_fsync GoogleMemorystoreInstance#append_fsync}
    */
    readonly appendFsync?: string;
}
export declare function googleMemorystoreInstancePersistenceConfigAofConfigToTerraform(struct?: GoogleMemorystoreInstancePersistenceConfigAofConfigOutputReference | GoogleMemorystoreInstancePersistenceConfigAofConfig): any;
export declare function googleMemorystoreInstancePersistenceConfigAofConfigToHclTerraform(struct?: GoogleMemorystoreInstancePersistenceConfigAofConfigOutputReference | GoogleMemorystoreInstancePersistenceConfigAofConfig): any;
export declare class GoogleMemorystoreInstancePersistenceConfigAofConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstancePersistenceConfigAofConfig | undefined;
    set internalValue(value: GoogleMemorystoreInstancePersistenceConfigAofConfig | undefined);
    private _appendFsync?;
    get appendFsync(): string;
    set appendFsync(value: string);
    resetAppendFsync(): void;
    get appendFsyncInput(): string | undefined;
}
export interface GoogleMemorystoreInstancePersistenceConfigRdbConfig {
    /**
    * Optional. Period between RDB snapshots.
    *  Possible values:
    *  ONE_HOUR
    * SIX_HOURS
    * TWELVE_HOURS
    * TWENTY_FOUR_HOURS
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#rdb_snapshot_period GoogleMemorystoreInstance#rdb_snapshot_period}
    */
    readonly rdbSnapshotPeriod?: string;
    /**
    * Optional. Time that the first snapshot was/will be attempted, and to which future
    * snapshots will be aligned. If not provided, the current time will be
    * used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#rdb_snapshot_start_time GoogleMemorystoreInstance#rdb_snapshot_start_time}
    */
    readonly rdbSnapshotStartTime?: string;
}
export declare function googleMemorystoreInstancePersistenceConfigRdbConfigToTerraform(struct?: GoogleMemorystoreInstancePersistenceConfigRdbConfigOutputReference | GoogleMemorystoreInstancePersistenceConfigRdbConfig): any;
export declare function googleMemorystoreInstancePersistenceConfigRdbConfigToHclTerraform(struct?: GoogleMemorystoreInstancePersistenceConfigRdbConfigOutputReference | GoogleMemorystoreInstancePersistenceConfigRdbConfig): any;
export declare class GoogleMemorystoreInstancePersistenceConfigRdbConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstancePersistenceConfigRdbConfig | undefined;
    set internalValue(value: GoogleMemorystoreInstancePersistenceConfigRdbConfig | undefined);
    private _rdbSnapshotPeriod?;
    get rdbSnapshotPeriod(): string;
    set rdbSnapshotPeriod(value: string);
    resetRdbSnapshotPeriod(): void;
    get rdbSnapshotPeriodInput(): string | undefined;
    private _rdbSnapshotStartTime?;
    get rdbSnapshotStartTime(): string;
    set rdbSnapshotStartTime(value: string);
    resetRdbSnapshotStartTime(): void;
    get rdbSnapshotStartTimeInput(): string | undefined;
}
export interface GoogleMemorystoreInstancePersistenceConfig {
    /**
    * Optional. Current persistence mode.
    *  Possible values:
    * DISABLED
    * RDB
    * AOF Possible values: ["DISABLED", "RDB", "AOF"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#mode GoogleMemorystoreInstance#mode}
    */
    readonly mode?: string;
    /**
    * aof_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#aof_config GoogleMemorystoreInstance#aof_config}
    */
    readonly aofConfig?: GoogleMemorystoreInstancePersistenceConfigAofConfig;
    /**
    * rdb_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#rdb_config GoogleMemorystoreInstance#rdb_config}
    */
    readonly rdbConfig?: GoogleMemorystoreInstancePersistenceConfigRdbConfig;
}
export declare function googleMemorystoreInstancePersistenceConfigToTerraform(struct?: GoogleMemorystoreInstancePersistenceConfigOutputReference | GoogleMemorystoreInstancePersistenceConfig): any;
export declare function googleMemorystoreInstancePersistenceConfigToHclTerraform(struct?: GoogleMemorystoreInstancePersistenceConfigOutputReference | GoogleMemorystoreInstancePersistenceConfig): any;
export declare class GoogleMemorystoreInstancePersistenceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstancePersistenceConfig | undefined;
    set internalValue(value: GoogleMemorystoreInstancePersistenceConfig | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _aofConfig;
    get aofConfig(): GoogleMemorystoreInstancePersistenceConfigAofConfigOutputReference;
    putAofConfig(value: GoogleMemorystoreInstancePersistenceConfigAofConfig): void;
    resetAofConfig(): void;
    get aofConfigInput(): GoogleMemorystoreInstancePersistenceConfigAofConfig | undefined;
    private _rdbConfig;
    get rdbConfig(): GoogleMemorystoreInstancePersistenceConfigRdbConfigOutputReference;
    putRdbConfig(value: GoogleMemorystoreInstancePersistenceConfigRdbConfig): void;
    resetRdbConfig(): void;
    get rdbConfigInput(): GoogleMemorystoreInstancePersistenceConfigRdbConfig | undefined;
}
export interface GoogleMemorystoreInstanceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#create GoogleMemorystoreInstance#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#delete GoogleMemorystoreInstance#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#update GoogleMemorystoreInstance#update}
    */
    readonly update?: string;
}
export declare function googleMemorystoreInstanceTimeoutsToTerraform(struct?: GoogleMemorystoreInstanceTimeouts | cdktf.IResolvable): any;
export declare function googleMemorystoreInstanceTimeoutsToHclTerraform(struct?: GoogleMemorystoreInstanceTimeouts | cdktf.IResolvable): any;
export declare class GoogleMemorystoreInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleMemorystoreInstanceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleMemorystoreInstanceZoneDistributionConfig {
    /**
    * Optional. Current zone distribution mode. Defaults to MULTI_ZONE.
    *  Possible values:
    *  MULTI_ZONE
    * SINGLE_ZONE Possible values: ["MULTI_ZONE", "SINGLE_ZONE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#mode GoogleMemorystoreInstance#mode}
    */
    readonly mode?: string;
    /**
    * Optional. Defines zone where all resources will be allocated with SINGLE_ZONE mode.
    * Ignored for MULTI_ZONE mode.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#zone GoogleMemorystoreInstance#zone}
    */
    readonly zone?: string;
}
export declare function googleMemorystoreInstanceZoneDistributionConfigToTerraform(struct?: GoogleMemorystoreInstanceZoneDistributionConfigOutputReference | GoogleMemorystoreInstanceZoneDistributionConfig): any;
export declare function googleMemorystoreInstanceZoneDistributionConfigToHclTerraform(struct?: GoogleMemorystoreInstanceZoneDistributionConfigOutputReference | GoogleMemorystoreInstanceZoneDistributionConfig): any;
export declare class GoogleMemorystoreInstanceZoneDistributionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleMemorystoreInstanceZoneDistributionConfig | undefined;
    set internalValue(value: GoogleMemorystoreInstanceZoneDistributionConfig | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance google_memorystore_instance}
*/
export declare class GoogleMemorystoreInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_memorystore_instance";
    /**
    * Generates CDKTF code for importing a GoogleMemorystoreInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleMemorystoreInstance to import
    * @param importFromId The id of the existing GoogleMemorystoreInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleMemorystoreInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_memorystore_instance google_memorystore_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleMemorystoreInstanceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleMemorystoreInstanceConfig);
    private _authorizationMode?;
    get authorizationMode(): string;
    set authorizationMode(value: string);
    resetAuthorizationMode(): void;
    get authorizationModeInput(): string | undefined;
    get backupCollection(): string;
    get createTime(): string;
    private _deletionProtectionEnabled?;
    get deletionProtectionEnabled(): boolean | cdktf.IResolvable;
    set deletionProtectionEnabled(value: boolean | cdktf.IResolvable);
    resetDeletionProtectionEnabled(): void;
    get deletionProtectionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _discoveryEndpoints;
    get discoveryEndpoints(): GoogleMemorystoreInstanceDiscoveryEndpointsList;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _endpoints;
    get endpoints(): GoogleMemorystoreInstanceEndpointsList;
    private _engineConfigs?;
    get engineConfigs(): {
        [key: string]: string;
    };
    set engineConfigs(value: {
        [key: string]: string;
    });
    resetEngineConfigs(): void;
    get engineConfigsInput(): {
        [key: string]: string;
    } | undefined;
    private _engineVersion?;
    get engineVersion(): string;
    set engineVersion(value: string);
    resetEngineVersion(): void;
    get engineVersionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instanceId?;
    get instanceId(): string;
    set instanceId(value: string);
    get instanceIdInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _maintenanceSchedule;
    get maintenanceSchedule(): GoogleMemorystoreInstanceMaintenanceScheduleList;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    get name(): string;
    private _nodeConfig;
    get nodeConfig(): GoogleMemorystoreInstanceNodeConfigList;
    private _nodeType?;
    get nodeType(): string;
    set nodeType(value: string);
    resetNodeType(): void;
    get nodeTypeInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _pscAttachmentDetails;
    get pscAttachmentDetails(): GoogleMemorystoreInstancePscAttachmentDetailsList;
    private _pscAutoConnections;
    get pscAutoConnections(): GoogleMemorystoreInstancePscAutoConnectionsList;
    private _replicaCount?;
    get replicaCount(): number;
    set replicaCount(value: number);
    resetReplicaCount(): void;
    get replicaCountInput(): number | undefined;
    private _shardCount?;
    get shardCount(): number;
    set shardCount(value: number);
    get shardCountInput(): number | undefined;
    get state(): string;
    private _stateInfo;
    get stateInfo(): GoogleMemorystoreInstanceStateInfoList;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _transitEncryptionMode?;
    get transitEncryptionMode(): string;
    set transitEncryptionMode(value: string);
    resetTransitEncryptionMode(): void;
    get transitEncryptionModeInput(): string | undefined;
    get uid(): string;
    get updateTime(): string;
    private _automatedBackupConfig;
    get automatedBackupConfig(): GoogleMemorystoreInstanceAutomatedBackupConfigOutputReference;
    putAutomatedBackupConfig(value: GoogleMemorystoreInstanceAutomatedBackupConfig): void;
    resetAutomatedBackupConfig(): void;
    get automatedBackupConfigInput(): GoogleMemorystoreInstanceAutomatedBackupConfig | undefined;
    private _crossInstanceReplicationConfig;
    get crossInstanceReplicationConfig(): GoogleMemorystoreInstanceCrossInstanceReplicationConfigOutputReference;
    putCrossInstanceReplicationConfig(value: GoogleMemorystoreInstanceCrossInstanceReplicationConfig): void;
    resetCrossInstanceReplicationConfig(): void;
    get crossInstanceReplicationConfigInput(): GoogleMemorystoreInstanceCrossInstanceReplicationConfig | undefined;
    private _desiredPscAutoConnections;
    get desiredPscAutoConnections(): GoogleMemorystoreInstanceDesiredPscAutoConnectionsList;
    putDesiredPscAutoConnections(value: GoogleMemorystoreInstanceDesiredPscAutoConnections[] | cdktf.IResolvable): void;
    resetDesiredPscAutoConnections(): void;
    get desiredPscAutoConnectionsInput(): cdktf.IResolvable | GoogleMemorystoreInstanceDesiredPscAutoConnections[] | undefined;
    private _gcsSource;
    get gcsSource(): GoogleMemorystoreInstanceGcsSourceOutputReference;
    putGcsSource(value: GoogleMemorystoreInstanceGcsSource): void;
    resetGcsSource(): void;
    get gcsSourceInput(): GoogleMemorystoreInstanceGcsSource | undefined;
    private _maintenancePolicy;
    get maintenancePolicy(): GoogleMemorystoreInstanceMaintenancePolicyOutputReference;
    putMaintenancePolicy(value: GoogleMemorystoreInstanceMaintenancePolicy): void;
    resetMaintenancePolicy(): void;
    get maintenancePolicyInput(): GoogleMemorystoreInstanceMaintenancePolicy | undefined;
    private _managedBackupSource;
    get managedBackupSource(): GoogleMemorystoreInstanceManagedBackupSourceOutputReference;
    putManagedBackupSource(value: GoogleMemorystoreInstanceManagedBackupSource): void;
    resetManagedBackupSource(): void;
    get managedBackupSourceInput(): GoogleMemorystoreInstanceManagedBackupSource | undefined;
    private _persistenceConfig;
    get persistenceConfig(): GoogleMemorystoreInstancePersistenceConfigOutputReference;
    putPersistenceConfig(value: GoogleMemorystoreInstancePersistenceConfig): void;
    resetPersistenceConfig(): void;
    get persistenceConfigInput(): GoogleMemorystoreInstancePersistenceConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleMemorystoreInstanceTimeoutsOutputReference;
    putTimeouts(value: GoogleMemorystoreInstanceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleMemorystoreInstanceTimeouts | undefined;
    private _zoneDistributionConfig;
    get zoneDistributionConfig(): GoogleMemorystoreInstanceZoneDistributionConfigOutputReference;
    putZoneDistributionConfig(value: GoogleMemorystoreInstanceZoneDistributionConfig): void;
    resetZoneDistributionConfig(): void;
    get zoneDistributionConfigInput(): GoogleMemorystoreInstanceZoneDistributionConfig | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
