/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleNetworkManagementConnectivityTestConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether the analysis should skip firewall checking. Default value is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#bypass_firewall_checks GoogleNetworkManagementConnectivityTest#bypass_firewall_checks}
    */
    readonly bypassFirewallChecks?: boolean | cdktf.IResolvable;
    /**
    * The user-supplied description of the Connectivity Test.
    * Maximum of 512 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#description GoogleNetworkManagementConnectivityTest#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#id GoogleNetworkManagementConnectivityTest#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Resource labels to represent user-provided metadata.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#labels GoogleNetworkManagementConnectivityTest#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Unique name for the connectivity test.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#name GoogleNetworkManagementConnectivityTest#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#project GoogleNetworkManagementConnectivityTest#project}
    */
    readonly project?: string;
    /**
    * IP Protocol of the test. When not provided, "TCP" is assumed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#protocol GoogleNetworkManagementConnectivityTest#protocol}
    */
    readonly protocol?: string;
    /**
    * Other projects that may be relevant for reachability analysis.
    * This is applicable to scenarios where a test can cross project
    * boundaries.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#related_projects GoogleNetworkManagementConnectivityTest#related_projects}
    */
    readonly relatedProjects?: string[];
    /**
    * Whether run analysis for the return path from destination to source.
    * Default value is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#round_trip GoogleNetworkManagementConnectivityTest#round_trip}
    */
    readonly roundTrip?: boolean | cdktf.IResolvable;
    /**
    * destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#destination GoogleNetworkManagementConnectivityTest#destination}
    */
    readonly destination: GoogleNetworkManagementConnectivityTestDestination;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#source GoogleNetworkManagementConnectivityTest#source}
    */
    readonly source: GoogleNetworkManagementConnectivityTestSource;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#timeouts GoogleNetworkManagementConnectivityTest#timeouts}
    */
    readonly timeouts?: GoogleNetworkManagementConnectivityTestTimeouts;
}
export interface GoogleNetworkManagementConnectivityTestDestination {
    /**
    * A Cloud SQL instance URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#cloud_sql_instance GoogleNetworkManagementConnectivityTest#cloud_sql_instance}
    */
    readonly cloudSqlInstance?: string;
    /**
    * Forwarding rule URI. Forwarding rules are frontends for load balancers,
    * PSC endpoints, and Protocol Forwarding.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#forwarding_rule GoogleNetworkManagementConnectivityTest#forwarding_rule}
    */
    readonly forwardingRule?: string;
    /**
    * A DNS endpoint of Google Kubernetes Engine cluster control plane.
    * Requires gke_master_cluster to be set, can't be used simultaneoulsly with
    * ip_address or network. Applicable only to destination endpoint.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#fqdn GoogleNetworkManagementConnectivityTest#fqdn}
    */
    readonly fqdn?: string;
    /**
    * A cluster URI for Google Kubernetes Engine cluster control plane.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#gke_master_cluster GoogleNetworkManagementConnectivityTest#gke_master_cluster}
    */
    readonly gkeMasterCluster?: string;
    /**
    * A Compute Engine instance URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#instance GoogleNetworkManagementConnectivityTest#instance}
    */
    readonly instance?: string;
    /**
    * The IP address of the endpoint, which can be an external or internal IP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#ip_address GoogleNetworkManagementConnectivityTest#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * A VPC network URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#network GoogleNetworkManagementConnectivityTest#network}
    */
    readonly network?: string;
    /**
    * The IP protocol port of the endpoint. Only applicable when protocol is
    * TCP or UDP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#port GoogleNetworkManagementConnectivityTest#port}
    */
    readonly port?: number;
    /**
    * Project ID where the endpoint is located.
    * The project ID can be derived from the URI if you provide a endpoint or
    * network URI.
    * The following are two cases where you may need to provide the project ID:
    * 1. Only the IP address is specified, and the IP address is within a Google
    * Cloud project.
    * 2. When you are using Shared VPC and the IP address that you provide is
    * from the service project. In this case, the network that the IP address
    * resides in is defined in the host project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#project_id GoogleNetworkManagementConnectivityTest#project_id}
    */
    readonly projectId?: string;
    /**
    * A Redis Cluster URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#redis_cluster GoogleNetworkManagementConnectivityTest#redis_cluster}
    */
    readonly redisCluster?: string;
    /**
    * A Redis Instance URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#redis_instance GoogleNetworkManagementConnectivityTest#redis_instance}
    */
    readonly redisInstance?: string;
}
export declare function googleNetworkManagementConnectivityTestDestinationToTerraform(struct?: GoogleNetworkManagementConnectivityTestDestinationOutputReference | GoogleNetworkManagementConnectivityTestDestination): any;
export declare function googleNetworkManagementConnectivityTestDestinationToHclTerraform(struct?: GoogleNetworkManagementConnectivityTestDestinationOutputReference | GoogleNetworkManagementConnectivityTestDestination): any;
export declare class GoogleNetworkManagementConnectivityTestDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkManagementConnectivityTestDestination | undefined;
    set internalValue(value: GoogleNetworkManagementConnectivityTestDestination | undefined);
    private _cloudSqlInstance?;
    get cloudSqlInstance(): string;
    set cloudSqlInstance(value: string);
    resetCloudSqlInstance(): void;
    get cloudSqlInstanceInput(): string | undefined;
    private _forwardingRule?;
    get forwardingRule(): string;
    set forwardingRule(value: string);
    resetForwardingRule(): void;
    get forwardingRuleInput(): string | undefined;
    private _fqdn?;
    get fqdn(): string;
    set fqdn(value: string);
    resetFqdn(): void;
    get fqdnInput(): string | undefined;
    private _gkeMasterCluster?;
    get gkeMasterCluster(): string;
    set gkeMasterCluster(value: string);
    resetGkeMasterCluster(): void;
    get gkeMasterClusterInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    resetInstance(): void;
    get instanceInput(): string | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _redisCluster?;
    get redisCluster(): string;
    set redisCluster(value: string);
    resetRedisCluster(): void;
    get redisClusterInput(): string | undefined;
    private _redisInstance?;
    get redisInstance(): string;
    set redisInstance(value: string);
    resetRedisInstance(): void;
    get redisInstanceInput(): string | undefined;
}
export interface GoogleNetworkManagementConnectivityTestSourceAppEngineVersion {
    /**
    * An App Engine service version name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#uri GoogleNetworkManagementConnectivityTest#uri}
    */
    readonly uri?: string;
}
export declare function googleNetworkManagementConnectivityTestSourceAppEngineVersionToTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceAppEngineVersionOutputReference | GoogleNetworkManagementConnectivityTestSourceAppEngineVersion): any;
export declare function googleNetworkManagementConnectivityTestSourceAppEngineVersionToHclTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceAppEngineVersionOutputReference | GoogleNetworkManagementConnectivityTestSourceAppEngineVersion): any;
export declare class GoogleNetworkManagementConnectivityTestSourceAppEngineVersionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkManagementConnectivityTestSourceAppEngineVersion | undefined;
    set internalValue(value: GoogleNetworkManagementConnectivityTestSourceAppEngineVersion | undefined);
    private _uri?;
    get uri(): string;
    set uri(value: string);
    resetUri(): void;
    get uriInput(): string | undefined;
}
export interface GoogleNetworkManagementConnectivityTestSourceCloudFunction {
    /**
    * A Cloud Function name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#uri GoogleNetworkManagementConnectivityTest#uri}
    */
    readonly uri?: string;
}
export declare function googleNetworkManagementConnectivityTestSourceCloudFunctionToTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceCloudFunctionOutputReference | GoogleNetworkManagementConnectivityTestSourceCloudFunction): any;
export declare function googleNetworkManagementConnectivityTestSourceCloudFunctionToHclTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceCloudFunctionOutputReference | GoogleNetworkManagementConnectivityTestSourceCloudFunction): any;
export declare class GoogleNetworkManagementConnectivityTestSourceCloudFunctionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkManagementConnectivityTestSourceCloudFunction | undefined;
    set internalValue(value: GoogleNetworkManagementConnectivityTestSourceCloudFunction | undefined);
    private _uri?;
    get uri(): string;
    set uri(value: string);
    resetUri(): void;
    get uriInput(): string | undefined;
}
export interface GoogleNetworkManagementConnectivityTestSourceCloudRunRevision {
    /**
    * A Cloud Run revision URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#uri GoogleNetworkManagementConnectivityTest#uri}
    */
    readonly uri?: string;
}
export declare function googleNetworkManagementConnectivityTestSourceCloudRunRevisionToTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceCloudRunRevisionOutputReference | GoogleNetworkManagementConnectivityTestSourceCloudRunRevision): any;
export declare function googleNetworkManagementConnectivityTestSourceCloudRunRevisionToHclTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceCloudRunRevisionOutputReference | GoogleNetworkManagementConnectivityTestSourceCloudRunRevision): any;
export declare class GoogleNetworkManagementConnectivityTestSourceCloudRunRevisionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkManagementConnectivityTestSourceCloudRunRevision | undefined;
    set internalValue(value: GoogleNetworkManagementConnectivityTestSourceCloudRunRevision | undefined);
    private _uri?;
    get uri(): string;
    set uri(value: string);
    resetUri(): void;
    get uriInput(): string | undefined;
}
export interface GoogleNetworkManagementConnectivityTestSource {
    /**
    * A Cloud SQL instance URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#cloud_sql_instance GoogleNetworkManagementConnectivityTest#cloud_sql_instance}
    */
    readonly cloudSqlInstance?: string;
    /**
    * A cluster URI for Google Kubernetes Engine cluster control plane.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#gke_master_cluster GoogleNetworkManagementConnectivityTest#gke_master_cluster}
    */
    readonly gkeMasterCluster?: string;
    /**
    * A Compute Engine instance URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#instance GoogleNetworkManagementConnectivityTest#instance}
    */
    readonly instance?: string;
    /**
    * The IP address of the endpoint, which can be an external or internal IP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#ip_address GoogleNetworkManagementConnectivityTest#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * A VPC network URI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#network GoogleNetworkManagementConnectivityTest#network}
    */
    readonly network?: string;
    /**
    * Type of the network where the endpoint is located. Possible values: ["GCP_NETWORK", "NON_GCP_NETWORK"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#network_type GoogleNetworkManagementConnectivityTest#network_type}
    */
    readonly networkType?: string;
    /**
    * The IP protocol port of the endpoint. Only applicable when protocol is
    * TCP or UDP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#port GoogleNetworkManagementConnectivityTest#port}
    */
    readonly port?: number;
    /**
    * Project ID where the endpoint is located.
    * The project ID can be derived from the URI if you provide a endpoint or
    * network URI.
    * The following are two cases where you may need to provide the project ID:
    * 1. Only the IP address is specified, and the IP address is within a Google
    * Cloud project.
    * 2. When you are using Shared VPC and the IP address that you provide is
    * from the service project. In this case, the network that the IP address
    * resides in is defined in the host project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#project_id GoogleNetworkManagementConnectivityTest#project_id}
    */
    readonly projectId?: string;
    /**
    * app_engine_version block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#app_engine_version GoogleNetworkManagementConnectivityTest#app_engine_version}
    */
    readonly appEngineVersion?: GoogleNetworkManagementConnectivityTestSourceAppEngineVersion;
    /**
    * cloud_function block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#cloud_function GoogleNetworkManagementConnectivityTest#cloud_function}
    */
    readonly cloudFunction?: GoogleNetworkManagementConnectivityTestSourceCloudFunction;
    /**
    * cloud_run_revision block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#cloud_run_revision GoogleNetworkManagementConnectivityTest#cloud_run_revision}
    */
    readonly cloudRunRevision?: GoogleNetworkManagementConnectivityTestSourceCloudRunRevision;
}
export declare function googleNetworkManagementConnectivityTestSourceToTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceOutputReference | GoogleNetworkManagementConnectivityTestSource): any;
export declare function googleNetworkManagementConnectivityTestSourceToHclTerraform(struct?: GoogleNetworkManagementConnectivityTestSourceOutputReference | GoogleNetworkManagementConnectivityTestSource): any;
export declare class GoogleNetworkManagementConnectivityTestSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkManagementConnectivityTestSource | undefined;
    set internalValue(value: GoogleNetworkManagementConnectivityTestSource | undefined);
    private _cloudSqlInstance?;
    get cloudSqlInstance(): string;
    set cloudSqlInstance(value: string);
    resetCloudSqlInstance(): void;
    get cloudSqlInstanceInput(): string | undefined;
    private _gkeMasterCluster?;
    get gkeMasterCluster(): string;
    set gkeMasterCluster(value: string);
    resetGkeMasterCluster(): void;
    get gkeMasterClusterInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    resetInstance(): void;
    get instanceInput(): string | undefined;
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _networkType?;
    get networkType(): string;
    set networkType(value: string);
    resetNetworkType(): void;
    get networkTypeInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _appEngineVersion;
    get appEngineVersion(): GoogleNetworkManagementConnectivityTestSourceAppEngineVersionOutputReference;
    putAppEngineVersion(value: GoogleNetworkManagementConnectivityTestSourceAppEngineVersion): void;
    resetAppEngineVersion(): void;
    get appEngineVersionInput(): GoogleNetworkManagementConnectivityTestSourceAppEngineVersion | undefined;
    private _cloudFunction;
    get cloudFunction(): GoogleNetworkManagementConnectivityTestSourceCloudFunctionOutputReference;
    putCloudFunction(value: GoogleNetworkManagementConnectivityTestSourceCloudFunction): void;
    resetCloudFunction(): void;
    get cloudFunctionInput(): GoogleNetworkManagementConnectivityTestSourceCloudFunction | undefined;
    private _cloudRunRevision;
    get cloudRunRevision(): GoogleNetworkManagementConnectivityTestSourceCloudRunRevisionOutputReference;
    putCloudRunRevision(value: GoogleNetworkManagementConnectivityTestSourceCloudRunRevision): void;
    resetCloudRunRevision(): void;
    get cloudRunRevisionInput(): GoogleNetworkManagementConnectivityTestSourceCloudRunRevision | undefined;
}
export interface GoogleNetworkManagementConnectivityTestTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#create GoogleNetworkManagementConnectivityTest#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#delete GoogleNetworkManagementConnectivityTest#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#update GoogleNetworkManagementConnectivityTest#update}
    */
    readonly update?: string;
}
export declare function googleNetworkManagementConnectivityTestTimeoutsToTerraform(struct?: GoogleNetworkManagementConnectivityTestTimeouts | cdktf.IResolvable): any;
export declare function googleNetworkManagementConnectivityTestTimeoutsToHclTerraform(struct?: GoogleNetworkManagementConnectivityTestTimeouts | cdktf.IResolvable): any;
export declare class GoogleNetworkManagementConnectivityTestTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkManagementConnectivityTestTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetworkManagementConnectivityTestTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test google_network_management_connectivity_test}
*/
export declare class GoogleNetworkManagementConnectivityTest extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_management_connectivity_test";
    /**
    * Generates CDKTF code for importing a GoogleNetworkManagementConnectivityTest resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleNetworkManagementConnectivityTest to import
    * @param importFromId The id of the existing GoogleNetworkManagementConnectivityTest that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleNetworkManagementConnectivityTest to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_management_connectivity_test google_network_management_connectivity_test} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleNetworkManagementConnectivityTestConfig
    */
    constructor(scope: Construct, id: string, config: GoogleNetworkManagementConnectivityTestConfig);
    private _bypassFirewallChecks?;
    get bypassFirewallChecks(): boolean | cdktf.IResolvable;
    set bypassFirewallChecks(value: boolean | cdktf.IResolvable);
    resetBypassFirewallChecks(): void;
    get bypassFirewallChecksInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    resetProtocol(): void;
    get protocolInput(): string | undefined;
    private _relatedProjects?;
    get relatedProjects(): string[];
    set relatedProjects(value: string[]);
    resetRelatedProjects(): void;
    get relatedProjectsInput(): string[] | undefined;
    private _roundTrip?;
    get roundTrip(): boolean | cdktf.IResolvable;
    set roundTrip(value: boolean | cdktf.IResolvable);
    resetRoundTrip(): void;
    get roundTripInput(): boolean | cdktf.IResolvable | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _destination;
    get destination(): GoogleNetworkManagementConnectivityTestDestinationOutputReference;
    putDestination(value: GoogleNetworkManagementConnectivityTestDestination): void;
    get destinationInput(): GoogleNetworkManagementConnectivityTestDestination | undefined;
    private _source;
    get source(): GoogleNetworkManagementConnectivityTestSourceOutputReference;
    putSource(value: GoogleNetworkManagementConnectivityTestSource): void;
    get sourceInput(): GoogleNetworkManagementConnectivityTestSource | undefined;
    private _timeouts;
    get timeouts(): GoogleNetworkManagementConnectivityTestTimeoutsOutputReference;
    putTimeouts(value: GoogleNetworkManagementConnectivityTestTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleNetworkManagementConnectivityTestTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
