/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleNetworkSecurityMirroringDeploymentGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided description of the deployment group.
    * Used as additional context for the deployment group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#description GoogleNetworkSecurityMirroringDeploymentGroup#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#id GoogleNetworkSecurityMirroringDeploymentGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels are key/value pairs that help to organize and filter resources.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#labels GoogleNetworkSecurityMirroringDeploymentGroup#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The cloud location of the deployment group, currently restricted to 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#location GoogleNetworkSecurityMirroringDeploymentGroup#location}
    */
    readonly location: string;
    /**
    * The ID to use for the new deployment group, which will become the final
    * component of the deployment group's resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#mirroring_deployment_group_id GoogleNetworkSecurityMirroringDeploymentGroup#mirroring_deployment_group_id}
    */
    readonly mirroringDeploymentGroupId: string;
    /**
    * The network that will be used for all child deployments, for example:
    * 'projects/{project}/global/networks/{network}'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#network GoogleNetworkSecurityMirroringDeploymentGroup#network}
    */
    readonly network: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#project GoogleNetworkSecurityMirroringDeploymentGroup#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#timeouts GoogleNetworkSecurityMirroringDeploymentGroup#timeouts}
    */
    readonly timeouts?: GoogleNetworkSecurityMirroringDeploymentGroupTimeouts;
}
export interface GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroups {
}
export declare function googleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroupsToTerraform(struct?: GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroups): any;
export declare function googleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroupsToHclTerraform(struct?: GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroups): any;
export declare class GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroupsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroups | undefined;
    set internalValue(value: GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroups | undefined);
    get name(): string;
}
export declare class GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroupsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroupsOutputReference;
}
export interface GoogleNetworkSecurityMirroringDeploymentGroupLocations {
}
export declare function googleNetworkSecurityMirroringDeploymentGroupLocationsToTerraform(struct?: GoogleNetworkSecurityMirroringDeploymentGroupLocations): any;
export declare function googleNetworkSecurityMirroringDeploymentGroupLocationsToHclTerraform(struct?: GoogleNetworkSecurityMirroringDeploymentGroupLocations): any;
export declare class GoogleNetworkSecurityMirroringDeploymentGroupLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityMirroringDeploymentGroupLocations | undefined;
    set internalValue(value: GoogleNetworkSecurityMirroringDeploymentGroupLocations | undefined);
    get location(): string;
    get state(): string;
}
export declare class GoogleNetworkSecurityMirroringDeploymentGroupLocationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityMirroringDeploymentGroupLocationsOutputReference;
}
export interface GoogleNetworkSecurityMirroringDeploymentGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#create GoogleNetworkSecurityMirroringDeploymentGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#delete GoogleNetworkSecurityMirroringDeploymentGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#update GoogleNetworkSecurityMirroringDeploymentGroup#update}
    */
    readonly update?: string;
}
export declare function googleNetworkSecurityMirroringDeploymentGroupTimeoutsToTerraform(struct?: GoogleNetworkSecurityMirroringDeploymentGroupTimeouts | cdktf.IResolvable): any;
export declare function googleNetworkSecurityMirroringDeploymentGroupTimeoutsToHclTerraform(struct?: GoogleNetworkSecurityMirroringDeploymentGroupTimeouts | cdktf.IResolvable): any;
export declare class GoogleNetworkSecurityMirroringDeploymentGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkSecurityMirroringDeploymentGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetworkSecurityMirroringDeploymentGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group google_network_security_mirroring_deployment_group}
*/
export declare class GoogleNetworkSecurityMirroringDeploymentGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_security_mirroring_deployment_group";
    /**
    * Generates CDKTF code for importing a GoogleNetworkSecurityMirroringDeploymentGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleNetworkSecurityMirroringDeploymentGroup to import
    * @param importFromId The id of the existing GoogleNetworkSecurityMirroringDeploymentGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleNetworkSecurityMirroringDeploymentGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_deployment_group google_network_security_mirroring_deployment_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleNetworkSecurityMirroringDeploymentGroupConfig
    */
    constructor(scope: Construct, id: string, config: GoogleNetworkSecurityMirroringDeploymentGroupConfig);
    private _connectedEndpointGroups;
    get connectedEndpointGroups(): GoogleNetworkSecurityMirroringDeploymentGroupConnectedEndpointGroupsList;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _locations;
    get locations(): GoogleNetworkSecurityMirroringDeploymentGroupLocationsList;
    private _mirroringDeploymentGroupId?;
    get mirroringDeploymentGroupId(): string;
    set mirroringDeploymentGroupId(value: string);
    get mirroringDeploymentGroupIdInput(): string | undefined;
    get name(): string;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleNetworkSecurityMirroringDeploymentGroupTimeoutsOutputReference;
    putTimeouts(value: GoogleNetworkSecurityMirroringDeploymentGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleNetworkSecurityMirroringDeploymentGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
