/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleNetworkSecurityMirroringEndpointGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided description of the endpoint group.
    * Used as additional context for the endpoint group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#description GoogleNetworkSecurityMirroringEndpointGroup#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#id GoogleNetworkSecurityMirroringEndpointGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels are key/value pairs that help to organize and filter resources.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#labels GoogleNetworkSecurityMirroringEndpointGroup#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The cloud location of the endpoint group, currently restricted to 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#location GoogleNetworkSecurityMirroringEndpointGroup#location}
    */
    readonly location: string;
    /**
    * The deployment group that this DIRECT endpoint group is connected to, for example:
    * 'projects/123456789/locations/global/mirroringDeploymentGroups/my-dg'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#mirroring_deployment_group GoogleNetworkSecurityMirroringEndpointGroup#mirroring_deployment_group}
    */
    readonly mirroringDeploymentGroup: string;
    /**
    * The ID to use for the endpoint group, which will become the final component
    * of the endpoint group's resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#mirroring_endpoint_group_id GoogleNetworkSecurityMirroringEndpointGroup#mirroring_endpoint_group_id}
    */
    readonly mirroringEndpointGroupId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#project GoogleNetworkSecurityMirroringEndpointGroup#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#timeouts GoogleNetworkSecurityMirroringEndpointGroup#timeouts}
    */
    readonly timeouts?: GoogleNetworkSecurityMirroringEndpointGroupTimeouts;
}
export interface GoogleNetworkSecurityMirroringEndpointGroupAssociations {
}
export declare function googleNetworkSecurityMirroringEndpointGroupAssociationsToTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupAssociations): any;
export declare function googleNetworkSecurityMirroringEndpointGroupAssociationsToHclTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupAssociations): any;
export declare class GoogleNetworkSecurityMirroringEndpointGroupAssociationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityMirroringEndpointGroupAssociations | undefined;
    set internalValue(value: GoogleNetworkSecurityMirroringEndpointGroupAssociations | undefined);
    get name(): string;
    get network(): string;
    get state(): string;
}
export declare class GoogleNetworkSecurityMirroringEndpointGroupAssociationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityMirroringEndpointGroupAssociationsOutputReference;
}
export interface GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocations {
}
export declare function googleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocationsToTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocations): any;
export declare function googleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocationsToHclTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocations): any;
export declare class GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocations | undefined;
    set internalValue(value: GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocations | undefined);
    get location(): string;
    get state(): string;
}
export declare class GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocationsOutputReference;
}
export interface GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroups {
}
export declare function googleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsToTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroups): any;
export declare function googleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsToHclTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroups): any;
export declare class GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroups | undefined;
    set internalValue(value: GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroups | undefined);
    private _locations;
    get locations(): GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsLocationsList;
    get name(): string;
}
export declare class GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsOutputReference;
}
export interface GoogleNetworkSecurityMirroringEndpointGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#create GoogleNetworkSecurityMirroringEndpointGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#delete GoogleNetworkSecurityMirroringEndpointGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#update GoogleNetworkSecurityMirroringEndpointGroup#update}
    */
    readonly update?: string;
}
export declare function googleNetworkSecurityMirroringEndpointGroupTimeoutsToTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupTimeouts | cdktf.IResolvable): any;
export declare function googleNetworkSecurityMirroringEndpointGroupTimeoutsToHclTerraform(struct?: GoogleNetworkSecurityMirroringEndpointGroupTimeouts | cdktf.IResolvable): any;
export declare class GoogleNetworkSecurityMirroringEndpointGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkSecurityMirroringEndpointGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetworkSecurityMirroringEndpointGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group google_network_security_mirroring_endpoint_group}
*/
export declare class GoogleNetworkSecurityMirroringEndpointGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_security_mirroring_endpoint_group";
    /**
    * Generates CDKTF code for importing a GoogleNetworkSecurityMirroringEndpointGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleNetworkSecurityMirroringEndpointGroup to import
    * @param importFromId The id of the existing GoogleNetworkSecurityMirroringEndpointGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleNetworkSecurityMirroringEndpointGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_network_security_mirroring_endpoint_group google_network_security_mirroring_endpoint_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleNetworkSecurityMirroringEndpointGroupConfig
    */
    constructor(scope: Construct, id: string, config: GoogleNetworkSecurityMirroringEndpointGroupConfig);
    private _associations;
    get associations(): GoogleNetworkSecurityMirroringEndpointGroupAssociationsList;
    private _connectedDeploymentGroups;
    get connectedDeploymentGroups(): GoogleNetworkSecurityMirroringEndpointGroupConnectedDeploymentGroupsList;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _mirroringDeploymentGroup?;
    get mirroringDeploymentGroup(): string;
    set mirroringDeploymentGroup(value: string);
    get mirroringDeploymentGroupInput(): string | undefined;
    private _mirroringEndpointGroupId?;
    get mirroringEndpointGroupId(): string;
    set mirroringEndpointGroupId(value: string);
    get mirroringEndpointGroupIdInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleNetworkSecurityMirroringEndpointGroupTimeoutsOutputReference;
    putTimeouts(value: GoogleNetworkSecurityMirroringEndpointGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleNetworkSecurityMirroringEndpointGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
