/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleRedisClusterUserCreatedConnectionsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#id GoogleRedisClusterUserCreatedConnections#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Redis cluster these endpoints should be added to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#name GoogleRedisClusterUserCreatedConnections#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#project GoogleRedisClusterUserCreatedConnections#project}
    */
    readonly project?: string;
    /**
    * The name of the region of the Redis cluster these endpoints should be added to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#region GoogleRedisClusterUserCreatedConnections#region}
    */
    readonly region: string;
    /**
    * cluster_endpoints block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#cluster_endpoints GoogleRedisClusterUserCreatedConnections#cluster_endpoints}
    */
    readonly clusterEndpoints?: GoogleRedisClusterUserCreatedConnectionsClusterEndpoints[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#timeouts GoogleRedisClusterUserCreatedConnections#timeouts}
    */
    readonly timeouts?: GoogleRedisClusterUserCreatedConnectionsTimeouts;
}
export interface GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection {
    /**
    * The IP allocated on the consumer network for the PSC forwarding rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#address GoogleRedisClusterUserCreatedConnections#address}
    */
    readonly address: string;
    /**
    * The URI of the consumer side forwarding rule.
    * Format:
    * projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#forwarding_rule GoogleRedisClusterUserCreatedConnections#forwarding_rule}
    */
    readonly forwardingRule: string;
    /**
    * The consumer network where the IP address resides, in the form of
    * projects/{project_id}/global/networks/{network_id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#network GoogleRedisClusterUserCreatedConnections#network}
    */
    readonly network: string;
    /**
    * The consumer project_id where the forwarding rule is created from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#project_id GoogleRedisClusterUserCreatedConnections#project_id}
    */
    readonly projectId?: string;
    /**
    * The PSC connection id of the forwarding rule connected to the
    * service attachment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#psc_connection_id GoogleRedisClusterUserCreatedConnections#psc_connection_id}
    */
    readonly pscConnectionId: string;
    /**
    * The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#service_attachment GoogleRedisClusterUserCreatedConnections#service_attachment}
    */
    readonly serviceAttachment: string;
}
export declare function googleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionToTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference | GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection): any;
export declare function googleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionToHclTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference | GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection): any;
export declare class GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection | undefined;
    set internalValue(value: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection | undefined);
    private _address?;
    get address(): string;
    set address(value: string);
    get addressInput(): string | undefined;
    get connectionType(): string;
    private _forwardingRule?;
    get forwardingRule(): string;
    set forwardingRule(value: string);
    get forwardingRuleInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _pscConnectionId?;
    get pscConnectionId(): string;
    set pscConnectionId(value: string);
    get pscConnectionIdInput(): string | undefined;
    get pscConnectionStatus(): string;
    private _serviceAttachment?;
    get serviceAttachment(): string;
    set serviceAttachment(value: string);
    get serviceAttachmentInput(): string | undefined;
}
export interface GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections {
    /**
    * psc_connection block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#psc_connection GoogleRedisClusterUserCreatedConnections#psc_connection}
    */
    readonly pscConnection?: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection;
}
export declare function googleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsToTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable): any;
export declare function googleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsToHclTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable): any;
export declare class GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable | undefined);
    private _pscConnection;
    get pscConnection(): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference;
    putPscConnection(value: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection): void;
    resetPscConnection(): void;
    get pscConnectionInput(): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection | undefined;
}
export declare class GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsOutputReference;
}
export interface GoogleRedisClusterUserCreatedConnectionsClusterEndpoints {
    /**
    * connections block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#connections GoogleRedisClusterUserCreatedConnections#connections}
    */
    readonly connections?: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | cdktf.IResolvable;
}
export declare function googleRedisClusterUserCreatedConnectionsClusterEndpointsToTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable): any;
export declare function googleRedisClusterUserCreatedConnectionsClusterEndpointsToHclTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable): any;
export declare class GoogleRedisClusterUserCreatedConnectionsClusterEndpointsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleRedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleRedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable | undefined);
    private _connections;
    get connections(): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnectionsList;
    putConnections(value: GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | cdktf.IResolvable): void;
    resetConnections(): void;
    get connectionsInput(): cdktf.IResolvable | GoogleRedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | undefined;
}
export declare class GoogleRedisClusterUserCreatedConnectionsClusterEndpointsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleRedisClusterUserCreatedConnectionsClusterEndpoints[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsOutputReference;
}
export interface GoogleRedisClusterUserCreatedConnectionsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#create GoogleRedisClusterUserCreatedConnections#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#delete GoogleRedisClusterUserCreatedConnections#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#update GoogleRedisClusterUserCreatedConnections#update}
    */
    readonly update?: string;
}
export declare function googleRedisClusterUserCreatedConnectionsTimeoutsToTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable): any;
export declare function googleRedisClusterUserCreatedConnectionsTimeoutsToHclTerraform(struct?: GoogleRedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable): any;
export declare class GoogleRedisClusterUserCreatedConnectionsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleRedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleRedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections google_redis_cluster_user_created_connections}
*/
export declare class GoogleRedisClusterUserCreatedConnections extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_redis_cluster_user_created_connections";
    /**
    * Generates CDKTF code for importing a GoogleRedisClusterUserCreatedConnections resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleRedisClusterUserCreatedConnections to import
    * @param importFromId The id of the existing GoogleRedisClusterUserCreatedConnections that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleRedisClusterUserCreatedConnections to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_redis_cluster_user_created_connections google_redis_cluster_user_created_connections} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleRedisClusterUserCreatedConnectionsConfig
    */
    constructor(scope: Construct, id: string, config: GoogleRedisClusterUserCreatedConnectionsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _clusterEndpoints;
    get clusterEndpoints(): GoogleRedisClusterUserCreatedConnectionsClusterEndpointsList;
    putClusterEndpoints(value: GoogleRedisClusterUserCreatedConnectionsClusterEndpoints[] | cdktf.IResolvable): void;
    resetClusterEndpoints(): void;
    get clusterEndpointsInput(): cdktf.IResolvable | GoogleRedisClusterUserCreatedConnectionsClusterEndpoints[] | undefined;
    private _timeouts;
    get timeouts(): GoogleRedisClusterUserCreatedConnectionsTimeoutsOutputReference;
    putTimeouts(value: GoogleRedisClusterUserCreatedConnectionsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleRedisClusterUserCreatedConnectionsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
