/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleStorageControlOrganizationIntelligenceConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edition configuration of the Storage Intelligence resource. Valid values are INHERIT, DISABLED, TRIAL and STANDARD.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#edition_config GoogleStorageControlOrganizationIntelligenceConfig#edition_config}
    */
    readonly editionConfig?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#id GoogleStorageControlOrganizationIntelligenceConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Identifier of the GCP Organization. For GCP org, this field should be organization number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#name GoogleStorageControlOrganizationIntelligenceConfig#name}
    */
    readonly name: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#filter GoogleStorageControlOrganizationIntelligenceConfig#filter}
    */
    readonly filter?: GoogleStorageControlOrganizationIntelligenceConfigFilter;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#timeouts GoogleStorageControlOrganizationIntelligenceConfig#timeouts}
    */
    readonly timeouts?: GoogleStorageControlOrganizationIntelligenceConfigTimeouts;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig {
}
export declare function googleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare function googleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfig | undefined);
    get effectiveEdition(): string;
    get intelligenceConfig(): string;
}
export declare class GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigOutputReference;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigTrialConfig {
}
export declare function googleStorageControlOrganizationIntelligenceConfigTrialConfigToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigTrialConfig): any;
export declare function googleStorageControlOrganizationIntelligenceConfigTrialConfigToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigTrialConfig): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigTrialConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigTrialConfig | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigTrialConfig | undefined);
    get expireTime(): string;
}
export declare class GoogleStorageControlOrganizationIntelligenceConfigTrialConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleStorageControlOrganizationIntelligenceConfigTrialConfigOutputReference;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#bucket_id_regexes GoogleStorageControlOrganizationIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function googleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare function googleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#locations GoogleStorageControlOrganizationIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function googleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare function googleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#bucket_id_regexes GoogleStorageControlOrganizationIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function googleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare function googleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#locations GoogleStorageControlOrganizationIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function googleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare function googleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigFilter {
    /**
    * excluded_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#excluded_cloud_storage_buckets GoogleStorageControlOrganizationIntelligenceConfig#excluded_cloud_storage_buckets}
    */
    readonly excludedCloudStorageBuckets?: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets;
    /**
    * excluded_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#excluded_cloud_storage_locations GoogleStorageControlOrganizationIntelligenceConfig#excluded_cloud_storage_locations}
    */
    readonly excludedCloudStorageLocations?: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations;
    /**
    * included_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#included_cloud_storage_buckets GoogleStorageControlOrganizationIntelligenceConfig#included_cloud_storage_buckets}
    */
    readonly includedCloudStorageBuckets?: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets;
    /**
    * included_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#included_cloud_storage_locations GoogleStorageControlOrganizationIntelligenceConfig#included_cloud_storage_locations}
    */
    readonly includedCloudStorageLocations?: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations;
}
export declare function googleStorageControlOrganizationIntelligenceConfigFilterToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilter): any;
export declare function googleStorageControlOrganizationIntelligenceConfigFilterToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigFilterOutputReference | GoogleStorageControlOrganizationIntelligenceConfigFilter): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigFilter | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigFilter | undefined);
    private _excludedCloudStorageBuckets;
    get excludedCloudStorageBuckets(): GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference;
    putExcludedCloudStorageBuckets(value: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets): void;
    resetExcludedCloudStorageBuckets(): void;
    get excludedCloudStorageBucketsInput(): GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    private _excludedCloudStorageLocations;
    get excludedCloudStorageLocations(): GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference;
    putExcludedCloudStorageLocations(value: GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations): void;
    resetExcludedCloudStorageLocations(): void;
    get excludedCloudStorageLocationsInput(): GoogleStorageControlOrganizationIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    private _includedCloudStorageBuckets;
    get includedCloudStorageBuckets(): GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference;
    putIncludedCloudStorageBuckets(value: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets): void;
    resetIncludedCloudStorageBuckets(): void;
    get includedCloudStorageBucketsInput(): GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    private _includedCloudStorageLocations;
    get includedCloudStorageLocations(): GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference;
    putIncludedCloudStorageLocations(value: GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations): void;
    resetIncludedCloudStorageLocations(): void;
    get includedCloudStorageLocationsInput(): GoogleStorageControlOrganizationIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
}
export interface GoogleStorageControlOrganizationIntelligenceConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#create GoogleStorageControlOrganizationIntelligenceConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#delete GoogleStorageControlOrganizationIntelligenceConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#update GoogleStorageControlOrganizationIntelligenceConfig#update}
    */
    readonly update?: string;
}
export declare function googleStorageControlOrganizationIntelligenceConfigTimeoutsToTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare function googleStorageControlOrganizationIntelligenceConfigTimeoutsToHclTerraform(struct?: GoogleStorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleStorageControlOrganizationIntelligenceConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleStorageControlOrganizationIntelligenceConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config google_storage_control_organization_intelligence_config}
*/
export declare class GoogleStorageControlOrganizationIntelligenceConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_control_organization_intelligence_config";
    /**
    * Generates CDKTF code for importing a GoogleStorageControlOrganizationIntelligenceConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleStorageControlOrganizationIntelligenceConfig to import
    * @param importFromId The id of the existing GoogleStorageControlOrganizationIntelligenceConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleStorageControlOrganizationIntelligenceConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_organization_intelligence_config google_storage_control_organization_intelligence_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleStorageControlOrganizationIntelligenceConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleStorageControlOrganizationIntelligenceConfigConfig);
    private _editionConfig?;
    get editionConfig(): string;
    set editionConfig(value: string);
    resetEditionConfig(): void;
    get editionConfigInput(): string | undefined;
    private _effectiveIntelligenceConfig;
    get effectiveIntelligenceConfig(): GoogleStorageControlOrganizationIntelligenceConfigEffectiveIntelligenceConfigList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _trialConfig;
    get trialConfig(): GoogleStorageControlOrganizationIntelligenceConfigTrialConfigList;
    get updateTime(): string;
    private _filter;
    get filter(): GoogleStorageControlOrganizationIntelligenceConfigFilterOutputReference;
    putFilter(value: GoogleStorageControlOrganizationIntelligenceConfigFilter): void;
    resetFilter(): void;
    get filterInput(): GoogleStorageControlOrganizationIntelligenceConfigFilter | undefined;
    private _timeouts;
    get timeouts(): GoogleStorageControlOrganizationIntelligenceConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleStorageControlOrganizationIntelligenceConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleStorageControlOrganizationIntelligenceConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
