/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleStorageControlProjectIntelligenceConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Edition configuration of the Storage Intelligence resource. Valid values are INHERIT, TRIAL, DISABLED and STANDARD.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#edition_config GoogleStorageControlProjectIntelligenceConfig#edition_config}
    */
    readonly editionConfig?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#id GoogleStorageControlProjectIntelligenceConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Identifier of the GCP project. For GCP project, this field can be project name or project number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#name GoogleStorageControlProjectIntelligenceConfig#name}
    */
    readonly name: string;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#filter GoogleStorageControlProjectIntelligenceConfig#filter}
    */
    readonly filter?: GoogleStorageControlProjectIntelligenceConfigFilter;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#timeouts GoogleStorageControlProjectIntelligenceConfig#timeouts}
    */
    readonly timeouts?: GoogleStorageControlProjectIntelligenceConfigTimeouts;
}
export interface GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfig {
}
export declare function googleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfigToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare function googleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfigToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfig): any;
export declare class GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfig | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfig | undefined);
    get effectiveEdition(): string;
    get intelligenceConfig(): string;
}
export declare class GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfigOutputReference;
}
export interface GoogleStorageControlProjectIntelligenceConfigTrialConfig {
}
export declare function googleStorageControlProjectIntelligenceConfigTrialConfigToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigTrialConfig): any;
export declare function googleStorageControlProjectIntelligenceConfigTrialConfigToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigTrialConfig): any;
export declare class GoogleStorageControlProjectIntelligenceConfigTrialConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigTrialConfig | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigTrialConfig | undefined);
    get expireTime(): string;
}
export declare class GoogleStorageControlProjectIntelligenceConfigTrialConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleStorageControlProjectIntelligenceConfigTrialConfigOutputReference;
}
export interface GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#bucket_id_regexes GoogleStorageControlProjectIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function googleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBucketsToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare function googleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBucketsToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets): any;
export declare class GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#locations GoogleStorageControlProjectIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function googleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocationsToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare function googleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocationsToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations): any;
export declare class GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets {
    /**
    * List of bucket id regexes to exclude in the storage intelligence plan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#bucket_id_regexes GoogleStorageControlProjectIntelligenceConfig#bucket_id_regexes}
    */
    readonly bucketIdRegexes: string[];
}
export declare function googleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBucketsToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare function googleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBucketsToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets): any;
export declare class GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined);
    private _bucketIdRegexes?;
    get bucketIdRegexes(): string[];
    set bucketIdRegexes(value: string[]);
    get bucketIdRegexesInput(): string[] | undefined;
}
export interface GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations {
    /**
    * List of locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#locations GoogleStorageControlProjectIntelligenceConfig#locations}
    */
    readonly locations: string[];
}
export declare function googleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocationsToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare function googleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocationsToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference | GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations): any;
export declare class GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations | undefined);
    private _locations?;
    get locations(): string[];
    set locations(value: string[]);
    get locationsInput(): string[] | undefined;
}
export interface GoogleStorageControlProjectIntelligenceConfigFilter {
    /**
    * excluded_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#excluded_cloud_storage_buckets GoogleStorageControlProjectIntelligenceConfig#excluded_cloud_storage_buckets}
    */
    readonly excludedCloudStorageBuckets?: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets;
    /**
    * excluded_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#excluded_cloud_storage_locations GoogleStorageControlProjectIntelligenceConfig#excluded_cloud_storage_locations}
    */
    readonly excludedCloudStorageLocations?: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations;
    /**
    * included_cloud_storage_buckets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#included_cloud_storage_buckets GoogleStorageControlProjectIntelligenceConfig#included_cloud_storage_buckets}
    */
    readonly includedCloudStorageBuckets?: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets;
    /**
    * included_cloud_storage_locations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#included_cloud_storage_locations GoogleStorageControlProjectIntelligenceConfig#included_cloud_storage_locations}
    */
    readonly includedCloudStorageLocations?: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations;
}
export declare function googleStorageControlProjectIntelligenceConfigFilterToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterOutputReference | GoogleStorageControlProjectIntelligenceConfigFilter): any;
export declare function googleStorageControlProjectIntelligenceConfigFilterToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigFilterOutputReference | GoogleStorageControlProjectIntelligenceConfigFilter): any;
export declare class GoogleStorageControlProjectIntelligenceConfigFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigFilter | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigFilter | undefined);
    private _excludedCloudStorageBuckets;
    get excludedCloudStorageBuckets(): GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBucketsOutputReference;
    putExcludedCloudStorageBuckets(value: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets): void;
    resetExcludedCloudStorageBuckets(): void;
    get excludedCloudStorageBucketsInput(): GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageBuckets | undefined;
    private _excludedCloudStorageLocations;
    get excludedCloudStorageLocations(): GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocationsOutputReference;
    putExcludedCloudStorageLocations(value: GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations): void;
    resetExcludedCloudStorageLocations(): void;
    get excludedCloudStorageLocationsInput(): GoogleStorageControlProjectIntelligenceConfigFilterExcludedCloudStorageLocations | undefined;
    private _includedCloudStorageBuckets;
    get includedCloudStorageBuckets(): GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBucketsOutputReference;
    putIncludedCloudStorageBuckets(value: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets): void;
    resetIncludedCloudStorageBuckets(): void;
    get includedCloudStorageBucketsInput(): GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageBuckets | undefined;
    private _includedCloudStorageLocations;
    get includedCloudStorageLocations(): GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocationsOutputReference;
    putIncludedCloudStorageLocations(value: GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations): void;
    resetIncludedCloudStorageLocations(): void;
    get includedCloudStorageLocationsInput(): GoogleStorageControlProjectIntelligenceConfigFilterIncludedCloudStorageLocations | undefined;
}
export interface GoogleStorageControlProjectIntelligenceConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#create GoogleStorageControlProjectIntelligenceConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#delete GoogleStorageControlProjectIntelligenceConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#update GoogleStorageControlProjectIntelligenceConfig#update}
    */
    readonly update?: string;
}
export declare function googleStorageControlProjectIntelligenceConfigTimeoutsToTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare function googleStorageControlProjectIntelligenceConfigTimeoutsToHclTerraform(struct?: GoogleStorageControlProjectIntelligenceConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleStorageControlProjectIntelligenceConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageControlProjectIntelligenceConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleStorageControlProjectIntelligenceConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config google_storage_control_project_intelligence_config}
*/
export declare class GoogleStorageControlProjectIntelligenceConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_control_project_intelligence_config";
    /**
    * Generates CDKTF code for importing a GoogleStorageControlProjectIntelligenceConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleStorageControlProjectIntelligenceConfig to import
    * @param importFromId The id of the existing GoogleStorageControlProjectIntelligenceConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleStorageControlProjectIntelligenceConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_storage_control_project_intelligence_config google_storage_control_project_intelligence_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleStorageControlProjectIntelligenceConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleStorageControlProjectIntelligenceConfigConfig);
    private _editionConfig?;
    get editionConfig(): string;
    set editionConfig(value: string);
    resetEditionConfig(): void;
    get editionConfigInput(): string | undefined;
    private _effectiveIntelligenceConfig;
    get effectiveIntelligenceConfig(): GoogleStorageControlProjectIntelligenceConfigEffectiveIntelligenceConfigList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _trialConfig;
    get trialConfig(): GoogleStorageControlProjectIntelligenceConfigTrialConfigList;
    get updateTime(): string;
    private _filter;
    get filter(): GoogleStorageControlProjectIntelligenceConfigFilterOutputReference;
    putFilter(value: GoogleStorageControlProjectIntelligenceConfigFilter): void;
    resetFilter(): void;
    get filterInput(): GoogleStorageControlProjectIntelligenceConfigFilter | undefined;
    private _timeouts;
    get timeouts(): GoogleStorageControlProjectIntelligenceConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleStorageControlProjectIntelligenceConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleStorageControlProjectIntelligenceConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
