/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleTpuV2QueuedResourceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#id GoogleTpuV2QueuedResource#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The immutable name of the Queued Resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#name GoogleTpuV2QueuedResource#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#project GoogleTpuV2QueuedResource#project}
    */
    readonly project?: string;
    /**
    * The GCP location for the Queued Resource. If it is not provided, the provider zone is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#zone GoogleTpuV2QueuedResource#zone}
    */
    readonly zone?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#timeouts GoogleTpuV2QueuedResource#timeouts}
    */
    readonly timeouts?: GoogleTpuV2QueuedResourceTimeouts;
    /**
    * tpu block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#tpu GoogleTpuV2QueuedResource#tpu}
    */
    readonly tpu?: GoogleTpuV2QueuedResourceTpu;
}
export interface GoogleTpuV2QueuedResourceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#create GoogleTpuV2QueuedResource#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#delete GoogleTpuV2QueuedResource#delete}
    */
    readonly delete?: string;
}
export declare function googleTpuV2QueuedResourceTimeoutsToTerraform(struct?: GoogleTpuV2QueuedResourceTimeouts | cdktf.IResolvable): any;
export declare function googleTpuV2QueuedResourceTimeoutsToHclTerraform(struct?: GoogleTpuV2QueuedResourceTimeouts | cdktf.IResolvable): any;
export declare class GoogleTpuV2QueuedResourceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTpuV2QueuedResourceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTpuV2QueuedResourceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
export interface GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig {
    /**
    * Allows the TPU node to send and receive packets with non-matching destination or source
    * IPs. This is required if you plan to use the TPU workers to forward routes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#can_ip_forward GoogleTpuV2QueuedResource#can_ip_forward}
    */
    readonly canIpForward?: boolean | cdktf.IResolvable;
    /**
    * Indicates that external IP addresses would be associated with the TPU workers. If set to
    * false, the specified subnetwork or network should have Private Google Access enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#enable_external_ips GoogleTpuV2QueuedResource#enable_external_ips}
    */
    readonly enableExternalIps?: boolean | cdktf.IResolvable;
    /**
    * The name of the network for the TPU node. It must be a preexisting Google Compute Engine
    * network. If none is provided, "default" will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#network GoogleTpuV2QueuedResource#network}
    */
    readonly network?: string;
    /**
    * Specifies networking queue count for TPU VM instance's network interface.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#queue_count GoogleTpuV2QueuedResource#queue_count}
    */
    readonly queueCount?: number;
    /**
    * The name of the subnetwork for the TPU node. It must be a preexisting Google Compute
    * Engine subnetwork. If none is provided, "default" will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#subnetwork GoogleTpuV2QueuedResource#subnetwork}
    */
    readonly subnetwork?: string;
}
export declare function googleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfigToTerraform(struct?: GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfigOutputReference | GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig): any;
export declare function googleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfigToHclTerraform(struct?: GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfigOutputReference | GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig): any;
export declare class GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig | undefined;
    set internalValue(value: GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig | undefined);
    private _canIpForward?;
    get canIpForward(): boolean | cdktf.IResolvable;
    set canIpForward(value: boolean | cdktf.IResolvable);
    resetCanIpForward(): void;
    get canIpForwardInput(): boolean | cdktf.IResolvable | undefined;
    private _enableExternalIps?;
    get enableExternalIps(): boolean | cdktf.IResolvable;
    set enableExternalIps(value: boolean | cdktf.IResolvable);
    resetEnableExternalIps(): void;
    get enableExternalIpsInput(): boolean | cdktf.IResolvable | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _queueCount?;
    get queueCount(): number;
    set queueCount(value: number);
    resetQueueCount(): void;
    get queueCountInput(): number | undefined;
    private _subnetwork?;
    get subnetwork(): string;
    set subnetwork(value: string);
    resetSubnetwork(): void;
    get subnetworkInput(): string | undefined;
}
export interface GoogleTpuV2QueuedResourceTpuNodeSpecNode {
    /**
    * TPU accelerator type for the TPU. If not specified, this defaults to 'v2-8'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#accelerator_type GoogleTpuV2QueuedResource#accelerator_type}
    */
    readonly acceleratorType?: string;
    /**
    * Text description of the TPU.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#description GoogleTpuV2QueuedResource#description}
    */
    readonly description?: string;
    /**
    * Runtime version for the TPU.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#runtime_version GoogleTpuV2QueuedResource#runtime_version}
    */
    readonly runtimeVersion: string;
    /**
    * network_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#network_config GoogleTpuV2QueuedResource#network_config}
    */
    readonly networkConfig?: GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig;
}
export declare function googleTpuV2QueuedResourceTpuNodeSpecNodeToTerraform(struct?: GoogleTpuV2QueuedResourceTpuNodeSpecNodeOutputReference | GoogleTpuV2QueuedResourceTpuNodeSpecNode): any;
export declare function googleTpuV2QueuedResourceTpuNodeSpecNodeToHclTerraform(struct?: GoogleTpuV2QueuedResourceTpuNodeSpecNodeOutputReference | GoogleTpuV2QueuedResourceTpuNodeSpecNode): any;
export declare class GoogleTpuV2QueuedResourceTpuNodeSpecNodeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTpuV2QueuedResourceTpuNodeSpecNode | undefined;
    set internalValue(value: GoogleTpuV2QueuedResourceTpuNodeSpecNode | undefined);
    private _acceleratorType?;
    get acceleratorType(): string;
    set acceleratorType(value: string);
    resetAcceleratorType(): void;
    get acceleratorTypeInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _runtimeVersion?;
    get runtimeVersion(): string;
    set runtimeVersion(value: string);
    get runtimeVersionInput(): string | undefined;
    private _networkConfig;
    get networkConfig(): GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfigOutputReference;
    putNetworkConfig(value: GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig): void;
    resetNetworkConfig(): void;
    get networkConfigInput(): GoogleTpuV2QueuedResourceTpuNodeSpecNodeNetworkConfig | undefined;
}
export interface GoogleTpuV2QueuedResourceTpuNodeSpec {
    /**
    * Unqualified node identifier used to identify the node in the project once provisioned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#node_id GoogleTpuV2QueuedResource#node_id}
    */
    readonly nodeId?: string;
    /**
    * The parent resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#parent GoogleTpuV2QueuedResource#parent}
    */
    readonly parent: string;
    /**
    * node block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#node GoogleTpuV2QueuedResource#node}
    */
    readonly nodeAttribute: GoogleTpuV2QueuedResourceTpuNodeSpecNode;
}
export declare function googleTpuV2QueuedResourceTpuNodeSpecToTerraform(struct?: GoogleTpuV2QueuedResourceTpuNodeSpec | cdktf.IResolvable): any;
export declare function googleTpuV2QueuedResourceTpuNodeSpecToHclTerraform(struct?: GoogleTpuV2QueuedResourceTpuNodeSpec | cdktf.IResolvable): any;
export declare class GoogleTpuV2QueuedResourceTpuNodeSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTpuV2QueuedResourceTpuNodeSpec | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTpuV2QueuedResourceTpuNodeSpec | cdktf.IResolvable | undefined);
    private _nodeId?;
    get nodeId(): string;
    set nodeId(value: string);
    resetNodeId(): void;
    get nodeIdInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _node;
    get nodeAttribute(): GoogleTpuV2QueuedResourceTpuNodeSpecNodeOutputReference;
    putNodeAttribute(value: GoogleTpuV2QueuedResourceTpuNodeSpecNode): void;
    get nodeAttributeInput(): GoogleTpuV2QueuedResourceTpuNodeSpecNode | undefined;
}
export declare class GoogleTpuV2QueuedResourceTpuNodeSpecList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTpuV2QueuedResourceTpuNodeSpec[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTpuV2QueuedResourceTpuNodeSpecOutputReference;
}
export interface GoogleTpuV2QueuedResourceTpu {
    /**
    * node_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#node_spec GoogleTpuV2QueuedResource#node_spec}
    */
    readonly nodeSpec?: GoogleTpuV2QueuedResourceTpuNodeSpec[] | cdktf.IResolvable;
}
export declare function googleTpuV2QueuedResourceTpuToTerraform(struct?: GoogleTpuV2QueuedResourceTpuOutputReference | GoogleTpuV2QueuedResourceTpu): any;
export declare function googleTpuV2QueuedResourceTpuToHclTerraform(struct?: GoogleTpuV2QueuedResourceTpuOutputReference | GoogleTpuV2QueuedResourceTpu): any;
export declare class GoogleTpuV2QueuedResourceTpuOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTpuV2QueuedResourceTpu | undefined;
    set internalValue(value: GoogleTpuV2QueuedResourceTpu | undefined);
    private _nodeSpec;
    get nodeSpec(): GoogleTpuV2QueuedResourceTpuNodeSpecList;
    putNodeSpec(value: GoogleTpuV2QueuedResourceTpuNodeSpec[] | cdktf.IResolvable): void;
    resetNodeSpec(): void;
    get nodeSpecInput(): cdktf.IResolvable | GoogleTpuV2QueuedResourceTpuNodeSpec[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource google_tpu_v2_queued_resource}
*/
export declare class GoogleTpuV2QueuedResource extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_tpu_v2_queued_resource";
    /**
    * Generates CDKTF code for importing a GoogleTpuV2QueuedResource resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleTpuV2QueuedResource to import
    * @param importFromId The id of the existing GoogleTpuV2QueuedResource that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleTpuV2QueuedResource to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.30.0/docs/resources/google_tpu_v2_queued_resource google_tpu_v2_queued_resource} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleTpuV2QueuedResourceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleTpuV2QueuedResourceConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleTpuV2QueuedResourceTimeoutsOutputReference;
    putTimeouts(value: GoogleTpuV2QueuedResourceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleTpuV2QueuedResourceTimeouts | undefined;
    private _tpu;
    get tpu(): GoogleTpuV2QueuedResourceTpuOutputReference;
    putTpu(value: GoogleTpuV2QueuedResourceTpu): void;
    resetTpu(): void;
    get tpuInput(): GoogleTpuV2QueuedResourceTpu | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
